<?php
session_start();

// If session variable 'username' is not set or is 'Guest', redirect to login page
if (!isset($_SESSION['username']) || $_SESSION['username'] === "Guest") {
    header("Location: /login.php");
    exit();
}

// Check if the session is inactive for more than 10 seconds
if (isset($_SESSION['last_activity']) && (time() - $_SESSION['last_activity'] > 900)) {
    // Session has been inactive for more than 10 seconds
    session_unset();     // Unset $_SESSION variable for the run-time
    session_destroy();   // Destroy the session data on the server
    header("Location: /login.php"); // Redirect to login page
    exit(); // Ensure no further execution of the script
}

// Update last activity time stamp
$_SESSION['last_activity'] = time();

$username = $_SESSION['username']; // Username is already checked above and is not 'Guest'

// Check if 'client_id' is in the URL query parameter
if (isset($_GET['client_id'])) {
    // Store the 'client_id' from the URL in a variable
    $id = $_GET['client_id'];
} else {
    // Set a default value or handle the case where 'client_id' is not provided in the URL
    $id = 'default_value';
}
$username = isset($_SESSION['username']) ? $_SESSION['username'] : "Guest";
include_once '../config_current.php';

/// Get Username
$query = "SELECT nme, job_title FROM account_users WHERE email = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param('s', $username);
$stmt->execute();

$result = $stmt->get_result();
$row = $result->fetch_assoc();

if ($row) {
    $truename = $row['nme'];
    $jobtitle = $row['job_title'];
} else {
    $truename = "Unknown";
}

$stmt->close();

// Suppose 'case_details' is your table name and it contains relevant information about the case
$case_query = "SELECT * FROM client_core WHERE id = ?";
$case_stmt = $conn->prepare($case_query);
$case_stmt->bind_param('i', $id); // assuming client_id is an integer field
$case_stmt->execute();

$case_result = $case_stmt->get_result();
$case_details = $case_result->fetch_assoc(); // fetches the row as an associative array

// print_r($case_details); exit;

$case_stmt->close();

?>

<!DOCTYPE html>
<html>

<head>
    <title>Address | Case <?php echo $case_details['id']; ?></title>
    <?php include 'layouts/head.php'; ?>
    <?php include 'layouts/head-style.php'; ?>
</head>

<body>
    <?php include 'layouts/body.php'; ?>

    <div id="layout-wrapper">
        <?php include 'layouts/vertical-menu.php'; ?>
        <div class="main-content">
            <div class="page-content">
                <div class="container-fluid">
                     <h3 class="fs-2">Audit Logs:</h3>
                          <table class="table mb-0" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                            <thead class="table-light" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                <tr speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                    <th speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">Descriptions</th>
                                    <th speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">By</th>
                                    <th speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">When</th>
                                </tr>
                            </thead>
                            <tbody id="correspondenceTable">
                            </tbody>
                        </table>
                    </div>
                    </div>
                    </div>
                    </div>
