<?php
session_start();

// If session variable 'username' is not set or is 'Guest', redirect to login page
if (!isset($_SESSION['username']) || $_SESSION['username'] === "Guest") {
    header("Location: /login.php");
    exit();
}

// Check if the session is inactive for more than 10 seconds
if (isset($_SESSION['last_activity']) && (time() - $_SESSION['last_activity'] > 900)) {
    // Session has been inactive for more than 10 seconds
    session_unset();     // Unset $_SESSION variable for the run-time
    session_destroy();   // Destroy the session data on the server
    header("Location: /login.php"); // Redirect to login page
    exit(); // Ensure no further execution of the script
}

// Update last activity time stamp
$_SESSION['last_activity'] = time();

$username = $_SESSION['username']; // Username is already checked above and is not 'Guest'

// Check if 'client_id' is in the URL query parameter
if (isset($_GET['client_id'])) {
    // Store the 'client_id' from the URL in a variable
    $id = $_GET['client_id'];
} else {
    // Set a default value or handle the case where 'client_id' is not provided in the URL
    $id = 'default_value';
}
$username = isset($_SESSION['username']) ? $_SESSION['username'] : "Guest";
include_once '../config_current.php';

/// Get Username
$query = "SELECT nme, job_title FROM account_users WHERE email = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param('s', $username);
$stmt->execute();

$result = $stmt->get_result();
$row = $result->fetch_assoc();

if ($row) {
    $truename = $row['nme'];
    $jobtitle = $row['job_title'];
} else {
    $truename = "Unknown";
}

$stmt->close();

// Suppose 'case_details' is your table name and it contains relevant information about the case
$case_query = "SELECT * FROM client_core WHERE id = ?";
$case_stmt = $conn->prepare($case_query);
$case_stmt->bind_param('i', $id); // assuming client_id is an integer field
$case_stmt->execute();

$case_result = $case_stmt->get_result();
$case_details = $case_result->fetch_assoc(); // fetches the row as an associative array

$case_stmt->close();


//DEBT DATA
$sql = "SELECT
    cc.id,
    cc.cid,
    cc.`creditor-name`,
    cc.`creditor-address`,
    cc.`creditor-email`,
    cc.`creditor-phone`,
    cc.`creditor-paydayloan`,
    cc.`account-reference`,
    cc.blnce,
    cc.red,
    cc.reddate,
    cc.repmnt,
    cc.proRtaPrcntge,
    cc.rspnsblty,
    cc.`pydycmpt-req`,
    cc.`crdtagrmnt-req`,
    cc.`crdtagrmnt-chse1`,
    cc.`crdtagrmnt-chse2`,
    cc.`crdtagrmnt-chse3`,
    cc.`crdtAgrmntRcvd`,
    cc.`crdtAgrmntDoc`,
    cc.stts,
    (cc.blnce - cc.red) AS newbalance,
    Created.nme AS Created_By,
    DATE_FORMAT(cc.`created-when`, '%d/%m/%Y %I:%i %p') AS Created_When,
    Updated.nme AS Updated_By,
    DATE_FORMAT(cc.`updated-when`, '%d/%m/%Y %I:%i %p') AS Updated_When
FROM client_creditors cc
LEFT JOIN account_users AS Created ON cc.`created-by` = Created.id
LEFT JOIN account_users AS Updated ON cc.`updated-by` = Updated.id
WHERE cc.cid = ?";

// Build parameters and types
$params = [];
$types  = "";
$params[] = $id;
$types   .= "i";

if (!empty($singleCreditorId)) {
    $sql .= " AND cc.id = ?";
    $params[] = $singleCreditorId;
    $types   .= "i";
}



$stmt = $conn->prepare($sql);
if (!$stmt) {
    die("Error preparing statement: " . $conn->error);
}
$stmt->bind_param($types, ...$params);
$stmt->execute();

// Get the result
$result = $stmt->get_result();


?>

<!-- HTML and PHP code to display the table -->
<!DOCTYPE html>
<html>
<head>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.0/css/bootstrap.min.css">

    <title>Balance Sheet | Case <?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?></title>

    <?php include 'layouts/head.php'; ?>
    <?php include 'layouts/head-style.php'; ?>
</head>
<body>
    <?php include 'layouts/body.php'; ?>

    <div id="layout-wrapper">
        <?php include 'layouts/vertical-menu.php'; ?>
        <div class="main-content">
            <div class="page-content">
                <div class="container-fluid">
                    <!-- Start Page Content here -->
                    <div class="row">
                        <div class="col-12">
                            <div class="card">
                                <div class="card-body">
                                    <div class="row">
                                        <div class="col-12">
                                            <button id="refreshTableButton" class="btn btn-info waves-effect waves-light mb-3 pull-right" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                                <i class="bx bx-loader bx-spin font-size-16 align-middle me-2" speechify-initial-font-family="boxicons" speechify-initial-font-size="16px"></i>Refresh Table
                                            </button>
                                            <br>
                                            <button id="createLiabilityBtn" class="btn btn-success mb-3" data-toggle="modal" data-target="#addLiabilityModal">Create Liability</button>
                                            <button id="proRataButton" class="btn btn-warning mb-3">Pro rata Liabilities</button>

                                            <br>
                                            <button id="showLiabilitiesButton" class="btn btn-danger mb-3">Mark Inactive</button>
                                            <button id="showUnmarkInactive" class="btn btn-success mb-3">Remove Inactive</button>
                                            <button id="showmarkCCR" class="btn btn-warning mb-3">Mark CCR</button>
                                            <button id="removeCCR" class="btn btn-secondary mb-3">Remove CCR</button>
                                            <button id="showmarkFF" class="btn btn-warning mb-3">Mark FF</button>
                                            <button id="removeFF" class="btn btn-secondary mb-3">Remove FF</button>
                                            <button id="showmarkSol" class="btn btn-warning mb-3">Mark Solicitor</button>
                                            <button id="showremoveSol" class="btn btn-secondary mb-3">Remove Solicitor</button>
                                            <button id="showIVA" class="btn btn-danger mb-3">Mark IVA</button>
                                            <button id="removeIVA" class="btn btn-success mb-3">Remove IVA</button>
                            
                                             <!-- Document Creation  -->
                                <button type="button" class="btn btn-info mb-3" style="font-family: 'Poppins', sans-serif; font-size: 13px;" data-toggle="modal" data-target="#documentTemplatesModal">
                                    Send Liability Letters
                                </button>
                                
                               <!-- Document Templates Modal (without fade) -->
                            <div class="modal" id="documentTemplatesModal" tabindex="-1" role="dialog" aria-labelledby="documentTemplatesModalLabel" aria-hidden="true">
                                <div class="modal-dialog" role="document">
                                    <div class="modal-content">
                                        <div class="modal-header">
                                            <h5 class="modal-title" id="documentTemplatesModalLabel">Document Templates</h5>
                                            <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                                <span aria-hidden="true">&times;</span>
                                            </button>
                                        </div>
                                       <form action="/client/docsgen/debt" method="get" id="debtForm">
                                        <div class="modal-body">
                                            <?php
                                            $debtlist = mysqli_query($conn, "SELECT id,crdtr FROM case_debts WHERE cse ='$id'");
                                            while ($debtdata = mysqli_fetch_array($debtlist)) {
                                                $debtid =  $debtdata['crdtr'];
                                                $clientdebtid =  $debtdata['id'];
                                                $creaditordatafec = mysqli_query($conn, "SELECT id, nme, prfrrdCrrspndnceMthd FROM creditor_maintenance WHERE id ='$debtid'");
                                                $getcreditdata = mysqli_fetch_array($creaditordatafec);

                                                echo '<input type="checkbox" name="selected_debts[]" value="' . $clientdebtid . '" data-debtid="' . $clientdebtid . '"> ' . $getcreditdata['nme'] . '<br>';
                                            }
                                            ?>
                                            <label for="documentTemplate">Choose a Document Template:</label>
                                            <input type="hidden" value="<?php echo $id; ?>" name="id">
                                            <select id="documentTemplate" name="docid" class="form-control">
                                                <?php foreach ($documentTemplates as $template) : ?>
                                                    <option value="<?= htmlspecialchars($template['id']) ?>"><?= htmlspecialchars($template['name']) ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </div>
                                        <div class="modal-footer">
                                            <button type="button" class="btn btn-primary" onclick="submitForm()">Send</button>
                                        </div>
                                    </form>

                                    <script>
                                    function submitForm() {
                                        var form = document.getElementById('debtForm');
                                        var selectedCheckboxes = document.querySelectorAll('input[type="checkbox"]:checked');
                                        
                                        selectedCheckboxes.forEach(function(checkbox) {
                                            var debtid = checkbox.getAttribute('data-debtid');
                                            var hiddenInput = document.createElement('input');
                                            hiddenInput.type = 'hidden';
                                            hiddenInput.name = 'debtid[]';
                                            hiddenInput.value = debtid;
                                            form.appendChild(hiddenInput);
                                        });
                                        
                                        form.submit();
                                    }
                                    </script>



                                    </div>
                                </div>
                            </div>
                                            
                                        </div>
                                    </div>

                                    <h4 class="card-title">Balance Sheet<span id="activeLiabilitiesCount">Loading...</span></h4>
                                            <script>
                                // Example script to fetch the count of active liabilities
                                document.addEventListener('DOMContentLoaded', function () {
                                    fetchActiveLiabilitiesCount();
                                    function fetchActiveLiabilitiesCount() {
                                        fetch('/client/Get/getcreditorcount.php?id=<?= $caseID ?>')
                                            .then(response => response.json())
                                            .then(data => {
                                                document.getElementById('activeLiabilitiesCount').textContent =
                                                    ' (' + data.count + ' Active Liabilities)';
                                            })
                                            .catch(error => {
                                                console.error('Error fetching active liabilities:', error);
                                                document.getElementById('activeLiabilitiesCount').textContent =
                                                    ' (Error fetching count)';
                                            });
                                    }
                                });
                                </script>

                                    <div class="table-responsive">
                                         <style>
                                                .light-purple {
                                                    background-color: #e6e6fa; /* light purple color */
                                                }
                                                .light-green {
                                                    background-color: #90ee90; /* light green color */
                                                }
                                                .light-grey {
                                                    background-color: #FF9992; /* light grey color */
                                                }
                                                .light-yellow {
                                                    background-color: #FFF792; /* light yellow color */
                                                }
                                                .light-blue {
                                                    background-color: #35E1FC; /* light yellow color */
                                                }
                                                .light-red {
                                                    background-color: #FFB6FD; /* light yellow color */
                                                }
                                                .light-orange {
                                                    background-color: #FAD797; /* light yellow color */
                                                }
                                                .light-pink {
                                                    background-color: #F0A8D0; /* light yellow color */
                                                }
                                            </style>
                                        <table class="table mb-0" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                        <thead class="table-light" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                        <tr>
                                            <th>Liability</th>
                                            <th>Account Reference</th>
                                            <th>Balance</th>
                                            <th>Repayment</th>
                                            <th>Pro-Rata (%)</th>
                                            <th>Responsibility</th>
                                            <th>Status</th>
                                            <th>Accepted Date</th>
                                            <th>Action</th>
                                            
                                        </tr>
                                        </thead>
                                       <tbody>
<?php
// Prepare totals
$totalActiveBalance = 0;
$totalRepayment     = 0;

while ($row = $result->fetch_assoc()):
    // Convert some date fields as in your original "view_single" logic
    if (!empty($row["crdtagrmnt-req"])) {
        $row["crdtagrmnt-req"] = date("Y-m-d", strtotime($row["crdtagrmnt-req"]));
    }
    if (!empty($row["crdtagrmnt-chse1"])) {
        $row["crdtagrmnt-chse1"] = date("Y-m-d", strtotime($row["crdtagrmnt-chse1"]));
    }
    if (!empty($row["crdtagrmnt-chse2"])) {
        $row["crdtagrmnt-chse2"] = date("Y-m-d", strtotime($row["crdtagrmnt-chse2"]));
    }
    if (!empty($row["crdtagrmnt-chse3"])) {
        $row["crdtagrmnt-chse3"] = date("Y-m-d", strtotime($row["crdtagrmnt-chse3"]));
    }
    if (!empty($row["crdtAgrmntRcvd"])) {
        $row["crdtAgrmntRcvd"] = date("Y-m-d", strtotime($row["crdtAgrmntRcvd"]));
    }

    // Example: Summing the main balance
    $balance   = (float) $row['blnce'];
    $repayment = (float) $row['repmnt']; // or 'proRta' if used

    $totalActiveBalance += $balance;
    $totalRepayment     += $repayment;

    // Row color logic if you have some flags/fields in your table
    // (You can add more conditions, e.g. if ($row['keInctve'] !== null) { $rowClass = 'light-grey'; })
    $rowClass = '';
?>
                                            <tr class="<?php echo $rowClass; ?>">
                                                <td><?php echo htmlspecialchars($row['creditor-name']); ?></td>
                                                <td><?php echo htmlspecialchars($row['account-reference']); ?></td>
                                                <td>£<?php echo number_format($balance, 2); ?></td>
                                                <td>£<?php echo number_format($repayment, 2); ?></td>
                                                <td><?php echo htmlspecialchars($row['proRtaPrcntge'] ?? ''); ?>%</td>
                                                <td><?php echo htmlspecialchars($row['rspnsblty'] ?? ''); ?></td>
                                                <td><?php echo htmlspecialchars($row['stts'] ?? ''); ?></td>
                                                <td>
                                                    <?php
                                                    // If you want to show "accepted date" from a specific field:
                                                    // e.g. $row['keDMPPmntAccptd'] 
                                                    // echo !empty($row['keDMPPmntAccptd'])
                                                    //   ? date("d/m/Y", strtotime($row['keDMPPmntAccptd']))
                                                    //   : '';
                                                    ?>
                                                </td>
                                                <td>
                                                    <!-- Example action buttons -->
                                                    <button class="btn btn-primary open-modal" data-id="<?php echo $row['id']; ?>">
                                                        View
                                                    </button>
                                                    <button class="btn btn-info open-additional-modal" data-id="<?php echo $row['id']; ?>">
                                                        Additional Notes
                                                    </button>
                                                </td>
                                            </tr>
<?php endwhile; ?>
                                        </tbody>
                                        <tfoot>
                                        <tr>
                                            <th>Total</th>
                                            <td></td> <!-- assuming there's a column before the balances that should be empty for totals -->
                                            <td><b>£<?php echo number_format($totalActiveBalance, 2); ?></b></td>
                                            <td><b>£<?php echo number_format($totalRepayment, 2); ?></b></td>
                                            <td colspan="3"></td> <!-- assuming there are 3 more columns that should be empty for totals -->
                                        </tr>
                                        </tfoot>
                                    </table>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <!-- End Page Content here -->
                </div>
            </div>
        </div>
    </div>

<!-- Include jQuery and Bootstrap -->
<script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
<script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.0/js/bootstrap.min.js"></script>


<!-- The modal structure with tabs -->
<div class="modal fade" id="debtDetailsModal" tabindex="-1" role="dialog" aria-labelledby="debtDetailsModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-lg" role="document">
        <div class="modal-content">
            
            <!-- Create Liability -->
            <div class="modal-header">
                <h5 class="modal-title mb-3" id="debtDetailsModalLabel">Creditor Information</h5>

                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>

        
            


            <!-- Modal body with tabbed content -->
            <div class="modal-body">
                <!-- Nav tabs -->
                <ul class="nav nav-tabs" id="debtDetailsTabs" role="tablist">
                    <li class="nav-item">
                        <a class="nav-link active" id="details-tab" data-toggle="tab" href="#details" role="tab" aria-controls="details" aria-selected="true">Details</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="keyevents-tab" data-toggle="tab" href="#keyevents" role="tab" aria-controls="keyevents" aria-selected="false">Key Events</a>
                    </li>
                     <li class="nav-item">
                        <a class="nav-link" id="previous-tab" data-toggle="tab" href="#previous" role="tab" aria-controls="previous" aria-selected="false">Previous Information</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="contact-tab" data-toggle="tab" href="#contact" role="tab" aria-controls="contact" aria-selected="false">Contact</a>
                    </li>
                </ul>

                <!-- Tab panes -->
                <div class="tab-content">
                    <!-- Details Tab -->
                    <div class="tab-pane fade show active" id="details" role="tabpanel" aria-labelledby="details-tab">
                        <!-- Content for Details tab -->
                        <br>
                        <div class="form-group row">
                            <label class="col-sm-4 col-form-label">Creditor Name:</label>
                            <div class="col-sm-8">
                                <input type="text" class="form-control" id="crdtr" value="<?php echo htmlspecialchars($creditorDetails['nme']); ?>" readonly>
                                <input type="hidden" class="form-control" id="id" value="<?php echo htmlspecialchars($creditorDetails['id']); ?>" readonly>
                            </div>
                        </div>
                        
                        <div class="form-group row">
                            <label class="col-sm-4 col-form-label">Account Reference Number:</label>
                            <div class="col-sm-8">
                            <input type="text" class="form-control" id="accntRfrnce" value="<?php echo htmlspecialchars($debtDetails['accntRfrnce']); ?>">
                            </div>
                        </div>
                        <div class="form-group row">
                            <label class="col-sm-4 col-form-label">Responsibility:</label>
                            <div class="col-sm-8">
                                <input type="text" class="form-control" id="rspnsblty" value="<?php echo htmlspecialchars($debtDetails['rspnsblty']); ?>">
                            </div>
                        </div>

                        <!-- Estimated, Confirmed, Active Balances and Repayment Amount -->
                        <!-- I've assumed these to be input fields, adjust accordingly -->
                        <div class="form-row">
                            <div class="form-group col-md-6">
                                <label for="estimatedBalance">Estimated Balance (£):</label>
                                <input type="text" class="form-control" id="estmtdBlnce" value="£<?php echo number_format($debtDetails['estmtdBlnce'], 2); ?>">
                            </div>
                            <div class="form-group col-md-6">
                                <label for="confirmedBalance">Confirmed Balance (£):</label>
                                <input type="text" class="form-control" id="cnfrmdBlnce" value="£<?php echo number_format($debtDetails['cnfrmdBlnce'], 2); ?>">
                            </div>
                        </div>
                        <div class="form-row">
                            <div class="form-group col-md-6">
                                <label for="activeBalance">Active Balance (£):</label>
                                <input type="text" class="form-control" id="actveBlnce" value="£<?php echo number_format($debtDetails['actveBlnce'], 2); ?>">
                            </div>
                            <div class="form-group col-md-6">
                                <label for="repaymentAmount">Repayment Amount (£):</label>
                                <input type="text" class="form-control" id="rePmnt" value="£<?php echo number_format($debtDetails['rePmnt'], 2); ?>">
                            </div>
                        </div>
                    </div>    

                    
                    <!-- Key Events Tab -->
                    <div class="tab-pane fade" id="keyevents" role="tabpanel" aria-labelledby="keyevents-tab">
                        <!-- Content for Key Events tab -->
                        <br>
                        <div class="form-row">
                            <div class="form-group col-md-6">
                                <label for="balanceRequested">Balance Requested:</label>
                                <input type="date" class="form-control" id="keBlnceRqstd" value="<?php echo htmlspecialchars($debtDetails['keBlnceRqstd']); ?>">
                            </div>
                            <div class="form-group col-md-6">
                                <label for="paymentProposed">Payment Proposed:</label>
                                <input type="date" class="form-control" id="keDMPPmntPrpsd" value="<?php echo htmlspecialchars($debtDetails['keDMPPmntPrpsd']); ?>">
                            </div>
                        </div>
                        <div class="form-row">
                            <div class="form-group col-md-6">
                                <label for="holdPayments">Hold Payments:</label>
                                <input type="date" class="form-control" id="keHldPmnts" value="<?php echo htmlspecialchars($debtDetails['keHldPmnts']); ?>">
                            </div>
                            <div class="form-group col-md-6">
                                <label for="fullAndFinalProposal">Full and Final Proposal:</label>
                                <input type="date" class="form-control" id="keFllAndFnlPrpsl" value="<?php echo htmlspecialchars($debtDetails['keFllAndFnlPrpsl']); ?>">
                            </div>
                        </div>
                        <div class="form-row">
                            <div class="form-group col-md-6">
                                <label for="inactive">Inactive:</label>
                                <input type="date" class="form-control" id="keInctve" value="<?php echo htmlspecialchars($debtDetails['keInctve']); ?>">
                            </div>
                            <div class="form-group col-md-6">
                                <label for="review">Review:</label>
                                <input type="date" class="form-control" id="rvw" value="<?php echo htmlspecialchars($debtDetails['rvw']); ?>">
                            </div>
                        </div>    
                        <div class="form-row">    
                            <div class="form-group col-md-6">
                                <label for="review">Payment Accepted:</label>
                                <input type="date" class="form-control" id="keDMPPmntAccptd" value="<?php echo htmlspecialchars($debtDetails['keDMPPmntAccptd']); ?>">
                            </div>
                            <div class="form-group col-md-6">
                                <label for="review">Full & Final Offer:</label>
                                <input type="number" class="form-control" id="fllAndFnlBlnce" value="<?php echo htmlspecialchars($debtDetails['fllAndFnlBlnce']); ?>">
                            </div>
                             <div class="form-group col-md-6">
                                <label for="review">Auto Accepted:</label>
                                <input type="date" class="form-control" id="auto_proposal_accepted" value="<?php echo htmlspecialchars($debtDetails['auto_proposal_accepted']); ?>">
                            </div>
                        </div>
                        
                        <h6>CCR Information</h6>
                        <div class="form-row">
                            <div class="form-group col-md-4">
                                <label for="initialLetter">Initial Letter:</label>
                                <input type="date" class="form-control" id="keccr_initial_snt" value="<?php echo htmlspecialchars($debtDetails['keccr_initial_snt']); ?>">
                            </div>
                            <div class="form-group col-md-4">
                                <label for="ccrChase1">CCR Chase 1:</label>
                                <input type="date" class="form-control" id="keccr_chse1" value="<?php echo htmlspecialchars($debtDetails['keccr_chse1']); ?>">
                            </div>
                            <div class="form-group col-md-4">
                                <label for="ccrChase2">CCR Chase 2:</label>
                                <input type="date" class="form-control" id="keccr_chse2" value="<?php echo htmlspecialchars($debtDetails['keccr_chse2']); ?>">
                            </div>
                        </div>
                    </div>
                    
                    <!-- Previous Debt -->
                    <div class="tab-pane fade" id="previous" role="tabpanel" aria-labelledby="previous-tab">
                        <br>
                        <!-- Content for Contact tab -->
                        <div class="form-row">
                            <div class="form-group col-md-6">
                                <label for="orgnlCrdtrNme">Creditor Name:</label>
                                <input type="text" class="form-control" id="orgnlCrdtrNme">
                            </div>
                            <div class="form-group col-md-6">
                                <label for="orgnlCrdtrAddrss">Creditor Address:</label>
                                <input type="text" class="form-control" id="orgnlCrdtrAddrss">
                            </div>
                        </div>
                        <div class="form-row">
                            <div class="form-group col-md-12">
                                <label for="orgnlAccntRfrnce">Original Account Reference:</label>
                                <input type="text" class="form-control" id="orgnlAccntRfrnce">
                            </div>
                                                    </div>
                        
                    </div>    
                    
                    <!-- Contact Tab -->
                    <div class="tab-pane fade" id="contact" role="tabpanel" aria-labelledby="contact-tab">
                        <br>
                        <!-- Content for Contact tab -->
                        <div class="form-row">
                            <div class="form-group col-md-6">
                                <label for="creditorNameContact">Creditor Name:</label>
                                <input type="text" class="form-control" id="creditorNameContact" readonly>
                            </div>
                            <div class="form-group col-md-6">
                                <label for="creditorAddress">Creditor Address:</label>
                                <input type="text" class="form-control" id="creditorAddress" readonly>
                            </div>
                        </div>
                        <div class="form-row">
                            <div class="form-group col-md-6">
                                <label for="telephoneNumber1">Telephone Number 1:</label>
                                <input type="tel" class="form-control" id="telephoneNumber1" readonly>
                            </div>
                            <div class="form-group col-md-6">
                                <label for="telephoneNumber2">Telephone Number 2:</label>
                                <input type="tel" class="form-control" id="telephoneNumber2" readonly>
                            </div>
                        </div>
                        <div class="form-row">
                            <div class="form-group col-md-4">
                                <label for="emailAddress">Email Address 1:</label>
                                <input type="email" class="form-control" id="emailAddress" readonly>
                            </div>
                            <div class="form-group col-md-4">
                                <label for="emailAddress">Email Address 2:</label>
                                <input type="email" class="form-control" id="emailAddress2" readonly>
                            </div>
                            <div class="form-group col-md-4">
                                <label for="emailAddress">Email Address 3:</label>
                                <input type="email" class="form-control" id="emailAddress3" readonly>
                            </div>
                        </div>    
                        
                        
                        <div class="form-row">
                            <div class="form-group col-md-4">
                                <label for="accountName">Account Name:</label>
                                <input type="text" class="form-control" id="accountName" readonly>
                            </div>
                            <div class="form-group col-md-4">
                                <label for="accountNumber">Account Number:</label>
                                <input type="text" class="form-control" id="accountNumber" readonly>
                            </div>
                            <div class="form-group col-md-4">
                                <label for="sortCode">Sort Code:</label>
                                <input type="text" class="form-control" id="sortCode" readonly>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <!-- Modal Footer -->
            <div class="modal-footer">
                <button type="button" class="btn btn-success">Save Changes</button>
                <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
                <button
                    id="alternativepayment"
                    class="btn btn-warning mb-3 ml-auto"
                    data-toggle="modal"
                    data-target="#alternativePaymentModal">
                    Set Alternative Payments
                </button>
                <button
                    id="removealternativepayment"
                    class="btn btn-danger mb-3 ml-auto"
                    data-toggle="modal"
                    data-target="#RemovealternativePaymentModal">
                    Remove Alternative Payments
                </button>


                <button id="ChangeLiabilityButton" class="btn btn-warning mb-3 ml-auto"
                        data-toggle="modal" data-target="#changeLiabilityModal"
                        data-id="">
                    Change Liability
                </button>
                <!-- Add this JavaScript code after the modal HTML and input element -->




                            </div>
                
                        </div>
                    </div>
                </div>
                


                     <!-- Modal for adding liabilities -->
                    <div class="modal fade" id="addLiabilityModal" tabindex="-1" role="dialog"
                        aria-labelledby="addLiabilityModalLabel" aria-hidden="true">
                        <div class="modal-dialog" role="document">
                            <div class="modal-content">
                                <div class="modal-header">
                                    <h5 class="modal-title" id="addLiabilityModalLabel">Create Liability</h5>
                                    <input type="hidden" name="case_reference_number" value="<?php echo htmlspecialchars($newCaseId); ?>">
                                </div>
                                <div class="modal-body">
                                    <div class="form-group">
                                        <label for="creditorName">Creditor Name</label>
                                        <input type="text" class="form-control" id="creditorName" name="creditorName"
                                            placeholder="Search creditor...">
                                        <!-- You may add an input field for storing the creditor ID here -->
                                        <input type="hidden" class="form-control" id="creditorId" name="creditorId">
                                        <div id="creditorNameSuggestions"></div>
                                    </div>
                                    <br>
                                    <!-- Account Reference Number input -->
                                    <div class="form-group">
                                        <label for="accountRefNumber">Account Reference Number</label>
                                        <input type="text" class="form-control" id="accountRefNumber"
                                            name="accountRefNumber" placeholder="Enter account reference number">
                                    </div>
                                    <br>
                                    <!-- Outstanding Amount input -->
                                    <div class="form-group">
                                        <label for="outstandingAmount">Outstanding Amount £</label>
                                        <input type="text" class="form-control" id="outstandingAmount"
                                            name="outstandingAmount" placeholder="Enter outstanding amount">
                                    </div>
                                    <br>
                                    <!-- Account Holder select -->
                                    <div class="form-group">
                                        <label for="accountHolder">Account Holder</label>
                                        <select class="form-control" id="accountHolder" name="accountHolder">
                                            <option value="1">Applicant One</option>
                                            <option value="2">Applicant Two</option>
                                            <!-- Add other options as needed -->
                                        </select>
                                    </div>
                                    <br>
                                    <!-- Credit Type select -->
                                    <div class="form-group">
                                        <label for="creditType">Credit Type</label>
                                        <select class="form-control" id="creditType" name="creditType">
                                            <option value="0">Unspecified</option>
                                            <option value="1">Credit card</option>
                                            <option value="2">Unsecured loan</option>
                                            <option value="3">Store card</option>
                                            <option value="4">HP</option>
                                            <option value="5">Arrears</option>
                                            <option value="7">Catalog</option>
                                            <option value="8">Solicitor</option>
                                            <option value="9">Debt collector</option>
                                            <option value="10">Mobile phone</option>
                                            <option value="11">Overdraft</option>
                                            <option value="6">Other</option>
                                        </select>
                                    </div>


                                    <br>
                                    <button type="button" class="btn btn-success" id="addLiabilityButton">Add Liability</button>
                                </div>
                            </div>
                        </div>
                    </div>
                    </form>
                </div> <!-- End of container-fluid -->
            </div>
        </div>
    </div>

    <!-- Modal for setting Alternative Payments -->
<div class="modal fade" id="alternativePaymentModal" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title" id="myModalLabel">Set Alternative Payments</h4>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
                </div>
                <div class="modal-body">
        <label for="alternativePaymentAmount">Enter Amount:</label>
        <input type="text" id="alternativePaymentAmount" class="form-control">
        
        <!-- Hidden input field to store the creditor ID -->
        <input type="hidden" id="creditorIdInput" name="creditorIdInput">
        
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
                    <button type="button" class="btn btn-success" id="saveAlternativePayment">Save</button>
                </div>
            </div>
        </div>
    </div>


    <!-- Modal for Removing Alternative Payments -->
<div class="modal fade" id="RemovealternativePaymentModal" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title" id="myModalLabel">Remove Alternative Payments</h4>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
                </div>
                <div class="modal-body">
        <label>Are you sure you want remove the Alternative Payment?</label>

        
        <!-- Hidden input field to store the creditor ID -->
        <input type="hidden" id="creditorIdInput" name="creditorIdInput">
        
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-danger" data-dismiss="modal">No</button>
                    <button type="button" class="btn btn-success" id="removeAlternativePayment">Yes</button>
                </div>
            </div>
        </div>
    </div>
<script>
 // Add an event listener to the "Set Alternative Payments" button
document.getElementById("removealternativepayment").addEventListener("click", function () {
    // Get the value from the hidden input field with id "id"
    var creditorId = document.getElementById("id").value;

    // Set the value of the "creditorIdInput" hidden input field with the retrieved value
    document.getElementById("creditorIdInput").value = creditorId;

    // Show the modal
    $('#RemovealternativePaymentModal').modal('show');
});

// Add an event listener to the "Save" button in the modal
document.getElementById("removeAlternativePayment").addEventListener("click", function () {
    // Get the entered alternative payment amount
    // Get the creditor ID from the hidden input field
    var creditorId = document.getElementById("creditorIdInput").value;

    // Log the values to the console
    console.log("Creditor ID:", creditorId);

    // Make an AJAX request to send the data to your server-side script for updating the database
    $.ajax({
        type: 'POST',
        url: '/client/Updates/remove_alternative_payment.php', // Replace with the actual URL of your script
        data: {
            creditorId: creditorId,
        },
        dataType: 'json',
        success: function (response) {
            if (response.success) {
                // Update was successful, you can handle it here (e.g., display a success message)
                console.log('Alternative Payment Removed successfully');
                // Close the modal
                $('#alternativePaymentModal').modal('hide');
                // Reload the page or perform any necessary actions
                location.reload();
            } else {
                // Update failed, you can handle errors here
                console.error('Failed to update Alternative Payment');
            }
        },
        error: function () {
            // AJAX request failed, handle the error here
            console.error('Error: AJAX request failed');
        }
    });
});

                </script>


 <script>
 // Add an event listener to the "Set Alternative Payments" button
document.getElementById("alternativepayment").addEventListener("click", function () {
    // Get the value from the hidden input field with id "id"
    var creditorId = document.getElementById("id").value;

    // Set the value of the "creditorIdInput" hidden input field with the retrieved value
    document.getElementById("creditorIdInput").value = creditorId;

    // Show the modal
    $('#alternativePaymentModal').modal('show');
});

// Add an event listener to the "Save" button in the modal
document.getElementById("saveAlternativePayment").addEventListener("click", function () {
    // Get the entered alternative payment amount
    var alternativePaymentAmount = document.getElementById("alternativePaymentAmount").value; // Corrected line

    // Get the creditor ID from the hidden input field
    var creditorId = document.getElementById("creditorIdInput").value;

    // Log the values to the console
    console.log("Creditor ID:", creditorId);
    console.log("Alternative Payment Amount:", alternativePaymentAmount);

    // Make an AJAX request to send the data to your server-side script for updating the database
    $.ajax({
        type: 'POST',
        url: '/client/Updates/save_alternative_payment.php', // Replace with the actual URL of your script
        data: {
            creditorId: creditorId,
            alternativePaymentAmount: alternativePaymentAmount
        },
        dataType: 'json',
        success: function (response) {
            if (response.success) {
                // Update was successful, you can handle it here (e.g., display a success message)
                console.log('Alternative Payment updated successfully');
                // Close the modal
                $('#alternativePaymentModal').modal('hide');
                // Reload the page or perform any necessary actions
                location.reload();
            } else {
                // Update failed, you can handle errors here
                console.error('Failed to update Alternative Payment');
            }
        },
        error: function () {
            // AJAX request failed, handle the error here
            console.error('Error: AJAX request failed');
        }
    });
});


                </script>

    
<!-- Modal for Changing liabilities -->
<div class="modal fade" id="changeLiabilityModal" tabindex="-1" role="dialog"
    aria-labelledby="changeLiabilityModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="changeLiabilityModalLabel">Change Liability</h5>
            </div>
            <div class="modal-body">
                <div class="form-group">
                    <!--<label for="currentLiabilityInput">Current Liability ID</label>-->
                    <input type="hidden" class="form-control" id="currentLiabilityInput" name="currentLiabilityInput">
                </div>
                <br>
                <div class="form-group">
                    <label for="credName">Creditor Name</label>
                    <input type="text" class="form-control" id="credName" name="credName"
                        placeholder="Search creditor...">
                    <!-- You may add an input field for storing the creditor ID here -->
                    <input type="hidden" class="form-control" id="credID" name="credID">
                    <div id="creditorNameSuggestions2"></div>
                </div>
                <br>
                <!-- Account Reference Number input -->
                <div class="form-group">
                    <label for="RefNumber">Account Reference Number</label>
                    <input type="text" class="form-control" id="RefNumber"
                        name="RefNumber" placeholder="Enter account reference number">
                </div>
                <br>
                <button type="button" class="btn btn-success" id="changeLiabilityButtonAccept">Change Liability</button>
            </div>
        </div>
    </div>
</div>
<script>
    // Get references to the input and button elements
    var input = document.getElementById("id");
    var changeLiabilityButtonAccept = document.getElementById("ChangeLiabilityButton");
    var currentLiabilityInput = document.getElementById("currentLiabilityInput");

    // Add an event listener to the button to update data-id
    changeLiabilityButtonAccept.addEventListener("click", function () {
        // Get the value from the input
        var inputValue = input.value;

        // Log the value to the console
        console.log("Passed data:", inputValue);

        // Set the value of the "Current Liability ID" field in the modal
        currentLiabilityInput.value = inputValue;

        // Show the modal
        $('#changeLiabilityModal').modal('show');
    });
    
    // JavaScript function to update the liability information on the server
    function updateLiability() {
    // Get the new liability information from the modal inputs
    var currentLiabilityID = document.getElementById('currentLiabilityInput').value;
    var newCreditorName = document.getElementById('credName').value;
    var newCreditorID = document.getElementById('credID').value;
    var newRefNumber = document.getElementById('RefNumber').value;
    
    // Create an AJAX request to update the liability information
    $.ajax({
        type: 'POST',
        url: '/client/Updates/replace_liability.php', // Replace with the actual URL of your update script
        data: {
            currentLiabilityID: currentLiabilityID,
            newCreditorName: newCreditorName,
            newCreditorID: newCreditorID,
            newRefNumber: newRefNumber
        },
        dataType: 'json',
        success: function (response) {
            if (response.success) {
                // Update was successful, you can handle it here (e.g., display a success message)
                console.log('Liability updated successfully');
                // Close the modal
                $('#changeLiabilityModal').modal('hide');
                // Reload the page
                location.reload();
            } else {
                // Update failed, you can handle errors here
                console.error('Failed to update liability');
            }
        },
        error: function () {
            // AJAX request failed, handle the error here
            console.error('Error: AJAX request failed');
        }
    });
}

// Add an event listener to the "Change Liability" button inside the modal
document.getElementById('changeLiabilityButtonAccept').addEventListener('click', function () {
    // Call the updateLiability function when the button is clicked
    updateLiability();
});


</script>


<!-- Button to trigger the modal -->
<button class="open-additional-modal btn btn-info waves-effect waves-light" data-id="<?php echo $debtRow['id']; ?>">Additional Notes</button>

<!-- Include jQuery and Bootstrap's JS -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>

<script>
$(document).ready(function(){
    $('.open-additional-modal').click(function() {
        var debtId = $(this).data('id');
        $('#additionalNotesModal'+debtId).modal('show');

        // Fetch existing notes from the server
        $.ajax({
            url: '/client/Get/get_notes',
            method: 'POST',
            data: { id: debtId },
            success: function(response) {
                $('#additionalNotesTextArea'+debtId).val(response);
            }
        });

    });
    
});

// Save notes
// $('#saveNotesButton').click(function() {
function saveNotes(debtId){
   
    var newNotes = $('#additionalNotesTextArea'+debtId).val();
    $.ajax({
        url: '/client/Updates/save_notes',
        method: 'POST',
        data: { id: debtId, notes: newNotes },
        success: function(response) {
            if(response.trim() == "Success") {
                alert('Notes saved successfully!');
                $('#additionalNotesModal'+debtId).modal('hide');
                
            } else {
                alert('Failed to save notes.');
            }
        }
    });
// });
} 
</script>


    
    <!-- Mark Inactive Modal  -->
<div id="liabilitiesModal" class="modal fade" tabindex="-1" role="dialog">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title">Mark Liabilities Inactive</h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
        <!-- Here, you will display the list of liabilities with checkboxes -->
        <ul id="liabilitiesList">
          <!-- Liabilities with checkboxes will be added here dynamically -->
        </ul>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
        <button id="markInactiveButton" class="btn btn-success">Mark Liability as Inactive</button>
      </div>
    </div>
  </div>
</div>

    <!-- Remove Inactive Modal  -->
<div id="removeinactiveModal" class="modal fade" tabindex="-1" role="dialog">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title">Remove Liabilities Inactive</h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
        <!-- Here, you will display the list of liabilities with checkboxes -->
        <ul id="liabilitiesList2">
          <!-- Liabilities with checkboxes will be added here dynamically -->
        </ul>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
        <button id="removeInactiveButton" class="btn btn-success">Remove Liability as Inactive</button>
      </div>
    </div>
  </div>
</div>


    <!-- CCR to Solicitors  -->
<div id="CCRSolicitorsModal" class="modal fade" tabindex="-1" role="dialog">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title">Transfer Libaility to Nominated Solictor</h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
        <!-- Here, you will display the list of liabilities with checkboxes -->
        <ul id="liabilitiesList3">
          <!-- Liabilities with checkboxes will be added here dynamically -->
        </ul>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
        <button id="CCRSolicitorsButton" class="btn btn-success">Remove Liability as Inactive</button>
      </div>
    </div>
  </div>
</div>


    <!-- Mark IVA  -->
<div id="IVAModal" class="modal fade" tabindex="-1" role="dialog">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title">Mark Liability as on IVA</h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
        <!-- Here, you will display the list of liabilities with checkboxes -->
        <ul id="liabilitiesList4">
          <!-- Liabilities with checkboxes will be added here dynamically -->
        </ul>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
        <button id="IVAButton" class="btn btn-success">Mark Liability as on IVA</button>
      </div>
    </div>
  </div>
</div>

    <!-- Remove IVA Mark  -->
<div id="RemoveIVAModal" class="modal fade" tabindex="-1" role="dialog">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title">Remove Liability as on IVA</h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
        <!-- Here, you will display the list of liabilities with checkboxes -->
        <ul id="liabilitiesList5">
          <!-- Liabilities with checkboxes will be added here dynamically -->
        </ul>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
        <button id="RemoveIVAButton" class="btn btn-success">Remove Liability as on IVA</button>
      </div>
    </div>
  </div>
</div>

    <!-- Mark CCR  -->
<div id="CCRModalAdd" class="modal fade" tabindex="-1" role="dialog">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title">Mark CCR</h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
        <!-- Here, you will display the list of liabilities with checkboxes -->
        <ul id="liabilitiesList6">
          <!-- Liabilities with checkboxes will be added here dynamically -->
        </ul>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
        <button id="CCRButton" class="btn btn-success">Mark CCR</button>
      </div>
    </div>
  </div>
</div>

    <!-- Remove CCR  -->
<div id="CCRModalRemove" class="modal fade" tabindex="-1" role="dialog">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title">Remove CCR</h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
        <!-- Here, you will display the list of liabilities with checkboxes -->
        <ul id="liabilitiesList8">
          <!-- Liabilities with checkboxes will be added here dynamically -->
        </ul>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
        <button id="RemoveCCRButton" class="btn btn-success">Remove CCR</button>
      </div>
    </div>
  </div>
</div>

   <!-- Mark Solicitor  -->
<div id="MarkSolicitor" class="modal fade" tabindex="-1" role="dialog">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title">Mark Solicitor</h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
        <!-- Here, you will display the list of liabilities with checkboxes -->
        <ul id="liabilitiesList9">
          <!-- Liabilities with checkboxes will be added here dynamically -->
        </ul>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
        <button id="MarkSolicitorButton" class="btn btn-success">Mark as with Solicitors</button>
      </div>
    </div>
  </div>
</div>

  <!-- Remove Mark Solicitor  -->
<div id="RemoveSolicitor" class="modal fade" tabindex="-1" role="dialog">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title">Remove Solicitor Mark</h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
        <!-- Here, you will display the list of liabilities with checkboxes -->
        <ul id="liabilitiesList10">
          <!-- Liabilities with checkboxes will be added here dynamically -->
        </ul>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
        <button id="RemoveSolicitorButton" class="btn btn-success">Remove Solicitor Mark</button>
      </div>
    </div>
  </div>
</div>


    <!-- Mark FF  -->
<div id="FFModalAdd" class="modal fade" tabindex="-1" role="dialog">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title">Mark Full & FInal</h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
        <!-- Here, you will display the list of liabilities with checkboxes -->
        <ul id="liabilitiesList11">
          <!-- Liabilities with checkboxes will be added here dynamically -->
        </ul>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
        <button id="FFButton" class="btn btn-success">Mark Full & FInal</button>
      </div>
    </div>
  </div>
</div>

    <!-- Remove FF  -->
<div id="FFModalRemove" class="modal fade" tabindex="-1" role="dialog">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title">Remove Full & FInal</h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
        <!-- Here, you will display the list of liabilities with checkboxes -->
        <ul id="liabilitiesList12">
          <!-- Liabilities with checkboxes will be added here dynamically -->
        </ul>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
        <button id="RemoveFFButton" class="btn btn-success">Remove Full & FInal</button>
      </div>
    </div>
  </div>
</div>


<!-- Include jQuery -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

<!-- Include Bootstrap JavaScript -->
<script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
<script>
// Assuming you're using jQuery for simplicity
$(document).ready(function() {
    $('.open-modal').on('click', function() {
        var debtId = $(this).data('id'); // Get the data-id attribute of the clicked element
        $.ajax({
            url: '/client/Get/debtDetails.php',
            type: 'GET',
            data: { id: debtId },
            dataType: 'json',
            success: function(debtDetails) {
                // Tab 1
                $('#accntRfrnce').val(debtDetails.accntRfrnce);
                $('#id').val(debtDetails.id);
                
                // Access creditor details using debtDetails.creditorDetails
                $('#crdtr').val(debtDetails.creditorDetails.nme);

                $('#rspnsblty').val(debtDetails.rspnsblty);
                $('#estmtdBlnce').val(debtDetails.estmtdBlnce);
                $('#cnfrmdBlnce').val(debtDetails.cnfrmdBlnce);
                $('#actveBlnce').val(debtDetails.actveBlnce);
                $('#rePmnt').val(debtDetails.rePmnt);
                
                // Tab 2
                $('#keBlnceRqstd').val(debtDetails.keBlnceRqstd);
                $('#keDMPPmntPrpsd').val(debtDetails.keDMPPmntPrpsd);
                $('#keHldPmnts').val(debtDetails.keHldPmnts);
                $('#keFllAndFnlPrpsl').val(debtDetails.keFllAndFnlPrpsl);
                $('#keInctve').val(debtDetails.keInctve);
                $('#rvw').val(debtDetails.rvw);
                $('#fllAndFnlBlnce').val(debtDetails.fllAndFnlBlnce);
                $('#auto_proposal_accepted').val(debtDetails.auto_proposal_accepted);
                $('#keDMPPmntAccptd').val(debtDetails.keDMPPmntAccptd);
                $('#keccr_initial_snt').val(debtDetails.keccr_initial_snt);
                $('#keccr_chse1').val(debtDetails.keccr_chse1);
                $('#keccr_chse2').val(debtDetails.keccr_chse2);

                // Tab 3
                $('#creditorNameContact').val(debtDetails.creditorDetails.nme);
                $('#creditorAddress').val(debtDetails.creditorDetails.Addrss);
                $('#telephoneNumber1').val(debtDetails.creditorDetails.tlphne1);
                $('#telephoneNumber2').val(debtDetails.creditorDetails.tlphne2);
                $('#emailAddress').val(debtDetails.creditorDetails.emlAddrss1);
                $('#emailAddress2').val(debtDetails.creditorDetails.emlAddrss2);
                $('#emailAddress3').val(debtDetails.creditorDetails.emlAddrss3);
                $('#accountName').val(debtDetails.creditorDetails.accntNme);
                $('#accountNumber').val(debtDetails.creditorDetails.accntNmbr);
                $('#sortCode').val(debtDetails.creditorDetails.srtcde);
                
                // Previous Name
                $('#orgnlCrdtrNme').val(debtDetails.orgnlCrdtrNme);
                $('#orgnlCrdtrAddrss').val(debtDetails.orgnlCrdtrAddrss);
                $('#orgnlAccntRfrnce').val(debtDetails.orgnlAccntRfrnce);

                // Finally, show the modal
                $('#debtDetailsModal').modal('show');
            }
        });
    });
});

// Function to update proRtaPrcntge and proRta
function updateProRata(id) {
    // Add a console log to check if the function is called with the correct id
    console.log('Updating proRata for id:', id);

    // Update the database using AJAX with only the id
    $.ajax({
        url: '/client/Updates/updateProRata.php',
        type: 'POST',
        data: { id: id },
        success: function(response) {
            if (response === 'success') {
                // Reload the page to reflect the updated data
                location.reload();
            
            }
        },
        error: function(jqXHR, textStatus, errorThrown) {
            console.log('AJAX Error:', textStatus, errorThrown);
            alert('AJAX Error: ' + textStatus);
        }
    });
}

// Attach a click event handler to the button
$('#proRataButton').on('click', function() {
    // Confirm with the user before performing the update
    if (confirm('Are you sure you want to update pro rata liabilities?')) {
        updateProRata(<?php echo $id; ?>); // Pass the id to the function
    }
});
$(document).ready(function () {
    // Show the modal when "Create Liability" button is clicked
    $("#createLiabilityBtn").click(function () {
        $("#addLiabilityModal").modal("show");
    });

    // Implement AJAX search for creditor names
    $("#creditorName").on("input", function () {
        var keyword = $(this).val();
        if (keyword.length >= 2) {
            $.ajax({
                type: "POST",
                url: "/create/get/search_creditor.php", // Replace with the actual PHP script for searching creditors
                data: { keyword: keyword },
                success: function (data) {
                    $("#creditorNameSuggestions").html(data);
                }
            });
        } else {
            $("#creditorNameSuggestions").html("");
        }
    });

    // Handle the click event on creditor suggestions
    $("#creditorNameSuggestions").on("click", ".creditor-suggestion", function () {
        var selectedCreditorName = $(this).text();
        var selectedCreditorId = $(this).data("creditor-id");
        $("#creditorName").val(selectedCreditorName);
        $("#creditorId").val(selectedCreditorId);
        $("#creditorNameSuggestions").html("");
    });

    // Handle the button click for adding a liability
    $("#addLiabilityButton").click(function () {
        var creditorId = $("#creditorId").val();
        var creditorName = $("#creditorName").val();
        var accountRefNumber = $("#accountRefNumber").val();
        var outstandingAmount = parseFloat($("#outstandingAmount").val());
        var accountHolder = $("#accountHolder").val();
        var creditType = $("#creditType").val();

        // You can perform validation here to ensure required fields are filled

        // Create an AJAX request to save the liability data to the database
$.ajax({
    type: "POST",
    url: "/client/Updates/save_liability.php", // Replace with the actual PHP script for saving liabilities
    data: {
        id: <?php echo $id; ?>, // Include the 'id' here
        creditorId: creditorId,
        accountRefNumber: accountRefNumber,
        outstandingAmount: outstandingAmount,
        accountHolder: accountHolder,
        creditType: creditType
    },
    success: function () {
        // Hide the modal
        $("#addLiabilityModal").modal("hide");
        
        // Reload the current page
        location.reload();
    },
    error: function () {
        // Handle the error case if saving the liability fails
        alert("Failed to save liability. Please try again.");
        
        // Log a message to check if this block is reached
        console.log("Reload page");
        
        // Reload the current page
        location.reload();
    }
});

    });
});
/// Mark Inactive

document.addEventListener('DOMContentLoaded', function () {
  // Get a reference to the button and modal
  const showLiabilitiesButton = document.getElementById('showLiabilitiesButton');
  const liabilitiesModal = document.getElementById('liabilitiesModal');
  const liabilitiesList = document.getElementById('liabilitiesList');
  const markInactiveButton = document.getElementById('markInactiveButton');

  // Add a click event listener to the button
  showLiabilitiesButton.addEventListener('click', function () {


    // Make an AJAX request to fetch liabilities
    fetch(`/client/Get/fetch_liability.php?caseId=<?php echo $id; ?>`)
      .then(response => response.json())
      .then(data => {
        // Clear any previous items in the list
        liabilitiesList.innerHTML = '';

        // Populate the list with liabilities and checkboxes
        data.forEach(liability => {
          const listItem = document.createElement('li');
          const checkbox = document.createElement('input');
          checkbox.type = 'checkbox';
          checkbox.name = 'liability';
          checkbox.value = liability.id; // Use a unique identifier for each liability
          listItem.appendChild(checkbox);
          listItem.appendChild(document.createTextNode(` ${liability.nme} - ${liability.accntRfrnce}`));
          liabilitiesList.appendChild(listItem);
        });

        // Show the modal
        $(liabilitiesModal).modal('show');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });

  // Add a click event listener to the "Mark Liability as Inactive" button
  markInactiveButton.addEventListener('click', function () {
    // Get the selected liabilities
    const selectedLiabilities = Array.from(document.querySelectorAll('input[name="liability"]:checked'))
      .map(checkbox => checkbox.value);

    // Make an AJAX request to update the selected liabilities
    fetch('/client/Updates/update_liabilities.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({ selectedLiabilities }),
    })
      .then(response => response.json())
      .then(data => {
        if (data.success) {
          // Handle success (e.g., display a success message)
          console.log(data.message);
        } else {
          // Handle failure (e.g., display an error message)
          console.error(data.message);
        }

        // Close the modal
        $(liabilitiesModal).modal('hide');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });
});


/// Remove Inactive Mark

document.addEventListener('DOMContentLoaded', function () {
  // Get a reference to the button and modal
  const showUnmarkInactive = document.getElementById('showUnmarkInactive');
  const removeinactiveModal = document.getElementById('removeinactiveModal');
  const liabilitiesList2 = document.getElementById('liabilitiesList2');
  const removeInactiveButton = document.getElementById('removeInactiveButton');

  // Add a click event listener to the button
  showUnmarkInactive.addEventListener('click', function () {


    // Make an AJAX request to fetch liabilities
    fetch(`/client/Get/fetch_liability.php?caseId=<?php echo $id; ?>`)
      .then(response => response.json())
      .then(data => {
        // Clear any previous items in the list
        liabilitiesList2.innerHTML = '';

        // Populate the list with liabilities and checkboxes
        data.forEach(liability => {
          const listItem = document.createElement('li');
          const checkbox = document.createElement('input');
          checkbox.type = 'checkbox';
          checkbox.name = 'liability';
          checkbox.value = liability.id; // Use a unique identifier for each liability
          listItem.appendChild(checkbox);
          listItem.appendChild(document.createTextNode(` ${liability.nme} - ${liability.accntRfrnce}`));
          liabilitiesList2.appendChild(listItem);
        });

        // Show the modal
        $(removeinactiveModal).modal('show');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });

  // Add a click event listener to the "Mark Liability as Inactive" button
  removeInactiveButton.addEventListener('click', function () {
    // Get the selected liabilities
    const selectedLiabilities = Array.from(document.querySelectorAll('input[name="liability"]:checked'))
      .map(checkbox => checkbox.value);

    // Make an AJAX request to update the selected liabilities
    fetch('/client/Updates/remove_inactive_marker.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({ selectedLiabilities }),
    })
      .then(response => response.json())
      .then(data => {
        if (data.success) {
          // Handle success (e.g., display a success message)
          console.log(data.message);
        } else {
          // Handle failure (e.g., display an error message)
          console.error(data.message);
        }

        // Close the modal
        $(removeinactiveModal).modal('hide');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });
});

/// CCR to Solicitors

document.addEventListener('DOMContentLoaded', function () {
  // Get a reference to the button and modal
  const showCCRSolicitors = document.getElementById('showCCRSolicitors');
  const CCRSolicitorsModal = document.getElementById('CCRSolicitorsModal');
  const liabilitiesList3 = document.getElementById('liabilitiesList3');
  const CCRSolicitorsButton = document.getElementById('CCRSolicitorsButton');

  // Add a click event listener to the button
  showCCRSolicitors.addEventListener('click', function () {


    // Make an AJAX request to fetch liabilities
    fetch(`/client/Get/fetch_liability.php?caseId=<?php echo $id; ?>`)
      .then(response => response.json())
      .then(data => {
        // Clear any previous items in the list
        liabilitiesList3.innerHTML = '';

        // Populate the list with liabilities and checkboxes
        data.forEach(liability => {
          const listItem = document.createElement('li');
          const checkbox = document.createElement('input');
          checkbox.type = 'checkbox';
          checkbox.name = 'liability';
          checkbox.value = liability.id; // Use a unique identifier for each liability
          listItem.appendChild(checkbox);
          listItem.appendChild(document.createTextNode(` ${liability.nme} - ${liability.accntRfrnce}`));
          liabilitiesList3.appendChild(listItem);
        });

        // Show the modal
        $(CCRSolicitorsModal).modal('show');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });

  // Add a click event listener to the "Mark Liability as Inactive" button
  CCRSolicitorsButton.addEventListener('click', function () {
    // Get the selected liabilities
    const selectedLiabilities = Array.from(document.querySelectorAll('input[name="liability"]:checked'))
      .map(checkbox => checkbox.value);

    // Make an AJAX request to update the selected liabilities
    fetch('/client/Updates/remove_inactive_marker.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({ selectedLiabilities }),
    })
      .then(response => response.json())
      .then(data => {
        if (data.success) {
          // Handle success (e.g., display a success message)
          console.log(data.message);
        } else {
          // Handle failure (e.g., display an error message)
          console.error(data.message);
        }

        // Close the modal
        $(CCRSolicitorsModal).modal('hide');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });
});


/// Mark as IVA

document.addEventListener('DOMContentLoaded', function () {
  // Get a reference to the button and modal
  const showIVA = document.getElementById('showIVA');
  const IVAModal = document.getElementById('IVAModal');
  const liabilitiesList3 = document.getElementById('liabilitiesList3');
  const IVAButton = document.getElementById('IVAButton');

  // Add a click event listener to the button
  showIVA.addEventListener('click', function () {


    // Make an AJAX request to fetch liabilities
    fetch(`/client/Get/fetch_liability.php?caseId=<?php echo $id; ?>`)
      .then(response => response.json())
      .then(data => {
        // Clear any previous items in the list
        liabilitiesList3.innerHTML = '';

        // Populate the list with liabilities and checkboxes
        data.forEach(liability => {
          const listItem = document.createElement('li');
          const checkbox = document.createElement('input');
          checkbox.type = 'checkbox';
          checkbox.name = 'liability';
          checkbox.value = liability.id; // Use a unique identifier for each liability
          listItem.appendChild(checkbox);
          listItem.appendChild(document.createTextNode(` ${liability.nme} - ${liability.accntRfrnce}`));
          liabilitiesList4.appendChild(listItem);
        });

        // Show the modal
        $(IVAModal).modal('show');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });

  // Add a click event listener to the "Mark Liability as Inactive" button
  IVAButton.addEventListener('click', function () {
    // Get the selected liabilities
    const selectedLiabilities = Array.from(document.querySelectorAll('input[name="liability"]:checked'))
      .map(checkbox => checkbox.value);

    // Make an AJAX request to update the selected liabilities
    fetch('/client/Updates/update_iva.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({ selectedLiabilities }),
    })
      .then(response => response.json())
      .then(data => {
        if (data.success) {
          // Handle success (e.g., display a success message)
          console.log(data.message);
        } else {
          // Handle failure (e.g., display an error message)
          console.error(data.message);
        }

        // Close the modal
        $(IVAModal).modal('hide');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });
});

/// Remove IVA Mark

document.addEventListener('DOMContentLoaded', function () {
  // Get a reference to the button and modal
  const removeIVA = document.getElementById('removeIVA');
  const RemoveIVAModal = document.getElementById('RemoveIVAModal');
  const liabilitiesList4 = document.getElementById('liabilitiesList4');
  const RemoveIVAButton = document.getElementById('RemoveIVAButton');

  // Add a click event listener to the button
  removeIVA.addEventListener('click', function () {


    // Make an AJAX request to fetch liabilities
    fetch(`/client/Get/fetch_liability.php?caseId=<?php echo $id; ?>`)
      .then(response => response.json())
      .then(data => {
        // Clear any previous items in the list
        liabilitiesList3.innerHTML = '';

        // Populate the list with liabilities and checkboxes
        data.forEach(liability => {
          const listItem = document.createElement('li');
          const checkbox = document.createElement('input');
          checkbox.type = 'checkbox';
          checkbox.name = 'liability';
          checkbox.value = liability.id; // Use a unique identifier for each liability
          listItem.appendChild(checkbox);
          listItem.appendChild(document.createTextNode(` ${liability.nme} - ${liability.accntRfrnce}`));
          liabilitiesList5.appendChild(listItem);
        });

        // Show the modal
        $(RemoveIVAModal).modal('show');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });

  // Add a click event listener to the "Mark Liability as Inactive" button
  RemoveIVAButton.addEventListener('click', function () {
    // Get the selected liabilities
    const selectedLiabilities = Array.from(document.querySelectorAll('input[name="liability"]:checked'))
      .map(checkbox => checkbox.value);

    // Make an AJAX request to update the selected liabilities
    fetch('/client/Updates/remove_iva.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({ selectedLiabilities }),
    })
      .then(response => response.json())
      .then(data => {
        if (data.success) {
          // Handle success (e.g., display a success message)
          console.log(data.message);
        } else {
          // Handle failure (e.g., display an error message)
          console.error(data.message);
        }

        // Close the modal
        $(RemoveIVAModal).modal('hide');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });
});

/// Mark as CCR

document.addEventListener('DOMContentLoaded', function () {
  // Get a reference to the button and modal
  const showmarkCCR = document.getElementById('showmarkCCR');
  const CCRModalAdd = document.getElementById('CCRModalAdd');
  const liabilitiesList6 = document.getElementById('liabilitiesList6');
  const CCRButton = document.getElementById('CCRButton');

  // Add a click event listener to the button
  showmarkCCR.addEventListener('click', function () {


    // Make an AJAX request to fetch liabilities
    fetch(`/client/Get/fetch_liability.php?caseId=<?php echo $id; ?>`)
      .then(response => response.json())
      .then(data => {
        // Clear any previous items in the list
        liabilitiesList6.innerHTML = '';

        // Populate the list with liabilities and checkboxes
        data.forEach(liability => {
          const listItem = document.createElement('li');
          const checkbox = document.createElement('input');
          checkbox.type = 'checkbox';
          checkbox.name = 'liability';
          checkbox.value = liability.id; // Use a unique identifier for each liability
          listItem.appendChild(checkbox);
          listItem.appendChild(document.createTextNode(` ${liability.nme} - ${liability.accntRfrnce}`));
          liabilitiesList6.appendChild(listItem);
        });

        // Show the modal
        $(CCRModalAdd).modal('show');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });

  // Add a click event listener to the "Mark Liability as Inactive" button
  CCRButton.addEventListener('click', function () {
    // Get the selected liabilities
    const selectedLiabilities = Array.from(document.querySelectorAll('input[name="liability"]:checked'))
      .map(checkbox => checkbox.value);

    // Make an AJAX request to update the selected liabilities
    fetch('/client/Updates/update_ccr.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({ selectedLiabilities }),
    })
      .then(response => response.json())
      .then(data => {
        if (data.success) {
          // Handle success (e.g., display a success message)
          console.log(data.message);
        } else {
          // Handle failure (e.g., display an error message)
          console.error(data.message);
        }

        // Close the modal
        $(CCRModalAdd).modal('hide');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });
});

/// Remove as CCR

document.addEventListener('DOMContentLoaded', function () {
  // Get a reference to the button and modal
  const removeCCR = document.getElementById('removeCCR');
  const CCRModalRemove = document.getElementById('CCRModalRemove');
  const liabilitiesList8 = document.getElementById('liabilitiesList8');
  const RemoveCCRButton = document.getElementById('RemoveCCRButton');

  // Add a click event listener to the button
  removeCCR.addEventListener('click', function () {


    // Make an AJAX request to fetch liabilities
    fetch(`/client/Get/fetch_liability.php?caseId=<?php echo $id; ?>`)
      .then(response => response.json())
      .then(data => {
        // Clear any previous items in the list
        liabilitiesList8.innerHTML = '';

        // Populate the list with liabilities and checkboxes
        data.forEach(liability => {
          const listItem = document.createElement('li');
          const checkbox = document.createElement('input');
          checkbox.type = 'checkbox';
          checkbox.name = 'liability';
          checkbox.value = liability.id; // Use a unique identifier for each liability
          listItem.appendChild(checkbox);
          listItem.appendChild(document.createTextNode(` ${liability.nme} - ${liability.accntRfrnce}`));
          liabilitiesList8.appendChild(listItem);
        });

        // Show the modal
        $(CCRModalRemove).modal('show');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });

  // Add a click event listener to the "Mark Liability as Inactive" button
  RemoveCCRButton.addEventListener('click', function () {
    // Get the selected liabilities
    const selectedLiabilities = Array.from(document.querySelectorAll('input[name="liability"]:checked'))
      .map(checkbox => checkbox.value);

    // Make an AJAX request to update the selected liabilities
    fetch('/client/Updates/remove_ccr.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({ selectedLiabilities }),
    })
      .then(response => response.json())
      .then(data => {
        if (data.success) {
          // Handle success (e.g., display a success message)
          console.log(data.message);
        } else {
          // Handle failure (e.g., display an error message)
          console.error(data.message);
        }

        // Close the modal
        $(CCRModalRemove).modal('hide');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });
});

/// Mark as FF

document.addEventListener('DOMContentLoaded', function () {
  // Get a reference to the button and modal
  const showmarkFF = document.getElementById('showmarkFF');
  const FFModalAdd = document.getElementById('FFModalAdd');
  const liabilitiesList11 = document.getElementById('liabilitiesList11');
  const FFButton = document.getElementById('FFButton');

  // Add a click event listener to the button
  showmarkFF.addEventListener('click', function () {


    // Make an AJAX request to fetch liabilities
    fetch(`/client/Get/fetch_liability.php?caseId=<?php echo $id; ?>`)
      .then(response => response.json())
      .then(data => {
        // Clear any previous items in the list
        liabilitiesList11.innerHTML = '';

        // Populate the list with liabilities and checkboxes
        data.forEach(liability => {
          const listItem = document.createElement('li');
          const checkbox = document.createElement('input');
          checkbox.type = 'checkbox';
          checkbox.name = 'liability';
          checkbox.value = liability.id; // Use a unique identifier for each liability
          listItem.appendChild(checkbox);
          listItem.appendChild(document.createTextNode(` ${liability.nme} - ${liability.accntRfrnce}`));
          liabilitiesList11.appendChild(listItem);
        });

        // Show the modal
        $(FFModalAdd).modal('show');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });

  // Add a click event listener to the "Mark Liability as Inactive" button
  FFButton.addEventListener('click', function () {
    // Get the selected liabilities
    const selectedLiabilities = Array.from(document.querySelectorAll('input[name="liability"]:checked'))
      .map(checkbox => checkbox.value);

    // Make an AJAX request to update the selected liabilities
    fetch('/client/Updates/update_ff.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({ selectedLiabilities }),
    })
      .then(response => response.json())
      .then(data => {
        if (data.success) {
          // Handle success (e.g., display a success message)
          console.log(data.message);
        } else {
          // Handle failure (e.g., display an error message)
          console.error(data.message);
        }

        // Close the modal
        $(FFModalAdd).modal('hide');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });
});

/// Remove as FF

document.addEventListener('DOMContentLoaded', function () {
  // Get a reference to the button and modal
  const removeFF = document.getElementById('removeFF');
  const FFModalRemove = document.getElementById('FFModalRemove');
  const liabilitiesList12 = document.getElementById('liabilitiesList12');
  const RemoveFFButton = document.getElementById('RemoveFFButton');

  // Add a click event listener to the button
  removeFF.addEventListener('click', function () {


    // Make an AJAX request to fetch liabilities
    fetch(`/client/Get/fetch_liability.php?caseId=<?php echo $id; ?>`)
      .then(response => response.json())
      .then(data => {
        // Clear any previous items in the list
        liabilitiesList12.innerHTML = '';

        // Populate the list with liabilities and checkboxes
        data.forEach(liability => {
          const listItem = document.createElement('li');
          const checkbox = document.createElement('input');
          checkbox.type = 'checkbox';
          checkbox.name = 'liability';
          checkbox.value = liability.id; // Use a unique identifier for each liability
          listItem.appendChild(checkbox);
          listItem.appendChild(document.createTextNode(` ${liability.nme} - ${liability.accntRfrnce}`));
          liabilitiesList12.appendChild(listItem);
        });

        // Show the modal
        $(FFModalRemove).modal('show');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });

  // Add a click event listener to the "Mark Liability as Inactive" button
  RemoveFFButton.addEventListener('click', function () {
    // Get the selected liabilities
    const selectedLiabilities = Array.from(document.querySelectorAll('input[name="liability"]:checked'))
      .map(checkbox => checkbox.value);

    // Make an AJAX request to update the selected liabilities
    fetch('/client/Updates/remove_ff.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({ selectedLiabilities }),
    })
      .then(response => response.json())
      .then(data => {
        if (data.success) {
          // Handle success (e.g., display a success message)
          console.log(data.message);
        } else {
          // Handle failure (e.g., display an error message)
          console.error(data.message);
        }

        // Close the modal
        $(FFModalRemove).modal('hide');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });
});

/// Creditor Information Modal


// Function to save changes when the "Save Changes" button is clicked
    function saveChanges() {
        // Get the values from the "Details" tab input fields
        var id = document.getElementById("id").value;
        var accntRfrnce = document.getElementById("accntRfrnce").value;
        var rspnsblty = document.getElementById("rspnsblty").value;
        var estmtdBlnce = document.getElementById("estmtdBlnce").value;
        var cnfrmdBlnce = document.getElementById("cnfrmdBlnce").value;
        var actveBlnce = document.getElementById("actveBlnce").value;
        var rePmnt = document.getElementById("rePmnt").value;

        // Get the values from the "Key Events" tab input fields
        var keBlnceRqstd = document.getElementById("keBlnceRqstd").value;
        var keDMPPmntPrpsd = document.getElementById("keDMPPmntPrpsd").value;
        var keHldPmnts = document.getElementById("keHldPmnts").value;
        var keFllAndFnlPrpsl = document.getElementById("keFllAndFnlPrpsl").value;
        var keInctve = document.getElementById("keInctve").value;
        var rvw = document.getElementById("rvw").value;
        var keDMPPmntAccptd = document.getElementById("keDMPPmntAccptd").value;
        var keccr_initial_snt = document.getElementById("keccr_initial_snt").value;
        var keccr_chse2 = document.getElementById("keccr_chse2").value;
        var keccr_chse1 = document.getElementById("keccr_chse1").value;
        var rvw = document.getElementById("rvw").value;
        var fllAndFnlBlnce = document.getElementById("fllAndFnlBlnce").value;
        var auto_proposal_accepted = document.getElementById("auto_proposal_accepted").value;

        // Create an object to hold all the data
        var data = {
            id: id,
            accntRfrnce: accntRfrnce,
            rspnsblty: rspnsblty,
            estmtdBlnce: estmtdBlnce,
            cnfrmdBlnce: cnfrmdBlnce,
            actveBlnce: actveBlnce,
            rePmnt: rePmnt,
            keBlnceRqstd: keBlnceRqstd,
            keDMPPmntPrpsd: keDMPPmntPrpsd,
            auto_proposal_accepted: auto_proposal_accepted,
            keHldPmnts: keHldPmnts,
            keFllAndFnlPrpsl: keFllAndFnlPrpsl,
            keInctve: keInctve,
            rvw: rvw,
            keDMPPmntAccptd: keDMPPmntAccptd,
            keccr_initial_snt: keccr_initial_snt,
            keccr_chse2: keccr_chse2,
            keccr_chse1: keccr_chse1,
            rvw: rvw,
            fllAndFnlBlnce: fllAndFnlBlnce
        };

        // Make an HTTP POST request to the server-side script
        fetch('/client/Updates/Update_Ind_Liability.php', {
            method: 'POST',
            body: JSON.stringify(data), // Convert data to JSON format
            headers: {
                'Content-Type': 'application/json'
            }
        })
        .then(response => response.json()) // Handle the server response if needed
        .then(responseData => {
            // Handle the response data from the server if needed
            alert("Libaility saved successfully!");
            refreshPage();
            // Close the modal or perform any other actions here
        })
        .catch(error => {
            console.error('Error:', error);
            // Handle errors here if necessary
        });
    }

    // Add a click event listener to the "Save Changes" button
    document.querySelector('#debtDetailsModal .modal-footer .btn-success').addEventListener('click', function() {
        saveChanges();
    });

// Function to refresh the current page
    function refreshPage() {
        location.reload();
    }

    // Add a click event listener to the button
    document.getElementById('refreshTableButton').addEventListener('click', function() {
        refreshPage();
    });
    
    // Change Liability Function
    
    $(document).ready(function () {
    $("#ChangeLiabilityButton").click(function () {
        $("#changeLiabilityModal").modal("show");
    });

    // Implement AJAX search for creditor names
    $("#credName").on("input", function () {
        var keyword = $(this).val();
        if (keyword.length >= 2) {
            $.ajax({
                type: "POST",
                url: "/create/get/search_creditor.php", 
                data: { keyword: keyword },
                success: function (data) {
                    $("#creditorNameSuggestions2").html(data);
                }
            });
        } else {
            $("#creditorNameSuggestions2").html("");
        }
    });

    // Handle the click event on creditor suggestions
    $("#creditorNameSuggestions2").on("click", ".creditor-suggestion", function () {
        var selectedCreditorName = $(this).text();
        var selectedCreditorId = $(this).data("creditor-id");
        $("#credName").val(selectedCreditorName);
        $("#credID").val(selectedCreditorId);
        $("#creditorNameSuggestions2").html("");
    });

    // Handle the button click for adding a liability
    $("#changeLiabilityButtonAccept").click(function () {
        var id = $("#id").val();
        var currentID = $("#currentID").val();
        var credID = $("#credID").val();
        var credName = $("#credName").val();
        var RefNumber = $("#RefNumber").val();
        var balanceAmount = parseFloat($("#balanceAmount").val());
        var ApplicantOwner = $("#ApplicantOwner").val();
        var credType = $("#credType").val();

        // You can perform validation here to ensure required fields are filled

        // Create an AJAX request to save the liability data to the database
        $.ajax({
            type: "POST",
            url: "/client/Updates/ChangeLiability.php", // Replace with the actual PHP script for saving liabilities
            data: {
                id: <?php echo $id; ?>, // Include the 'id' here
                credID: credID,
                creditorName: creditorName,
                RefNumber: RefNumber,
                balanceAmount: balanceAmount,
                ApplicantOwner: ApplicantOwner,
                credType: credType
            },
            success: function (response) {
                if (response === "success") {
                    

                    // Hide the modal
                    $("#changeLiabilityModal").modal("hide");
                            } else {
                // Handle the error case if saving the liability fails
                alert("Failed to save liability. Please try again.");
                
                // Log a message to check if this block is reached
                console.log("Reload page");
                
                // Reload the current page
                location.reload();
              }

            }
        });
    });
});

    /// Add Solicitor

document.addEventListener('DOMContentLoaded', function () {
  // Get a reference to the button and modal
  const showmarkSol = document.getElementById('showmarkSol');
  const MarkSolicitor = document.getElementById('MarkSolicitor');
  const liabilitiesList9 = document.getElementById('liabilitiesList9');
  const MarkSolicitorButton = document.getElementById('MarkSolicitorButton');

  // Add a click event listener to the button
  showmarkSol.addEventListener('click', function () {


    // Make an AJAX request to fetch liabilities
    fetch(`/client/Get/fetch_liability.php?caseId=<?php echo $id; ?>`)
      .then(response => response.json())
      .then(data => {
        // Clear any previous items in the list
        liabilitiesList9.innerHTML = '';

        // Populate the list with liabilities and checkboxes
        data.forEach(liability => {
          const listItem = document.createElement('li');
          const checkbox = document.createElement('input');
          checkbox.type = 'checkbox';
          checkbox.name = 'liability';
          checkbox.value = liability.id; // Use a unique identifier for each liability
          listItem.appendChild(checkbox);
          listItem.appendChild(document.createTextNode(` ${liability.nme} - ${liability.accntRfrnce}`));
          liabilitiesList9.appendChild(listItem);
        });

        // Show the modal
        $(MarkSolicitor).modal('show');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });

  // Add a click event listener to the "Mark Liability as Inactive" button
  MarkSolicitorButton.addEventListener('click', function () {
    // Get the selected liabilities
    const selectedLiabilities = Array.from(document.querySelectorAll('input[name="liability"]:checked'))
      .map(checkbox => checkbox.value);

    // Make an AJAX request to update the selected liabilities
    fetch('/client/Updates/update_sol.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({ selectedLiabilities }),
    })
      .then(response => response.json())
      .then(data => {
        if (data.success) {
          // Handle success (e.g., display a success message)
          console.log(data.message);
        } else {
          // Handle failure (e.g., display an error message)
          console.error(data.message);
        }

        // Close the modal
        $(MarkSolicitor).modal('hide');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });
});

    /// Remove Solicitor

document.addEventListener('DOMContentLoaded', function () {
  // Get a reference to the button and modal
  const showremoveSol = document.getElementById('showremoveSol');
  const RemoveSolicitor = document.getElementById('RemoveSolicitor');
  const liabilitiesList10 = document.getElementById('liabilitiesList10');
  const RemoveSolicitorButton = document.getElementById('RemoveSolicitorButton');

  // Add a click event listener to the button
  showremoveSol.addEventListener('click', function () {


    // Make an AJAX request to fetch liabilities
    fetch(`/client/Get/fetch_liability.php?caseId=<?php echo $id; ?>`)
      .then(response => response.json())
      .then(data => {
        // Clear any previous items in the list
        liabilitiesList10.innerHTML = '';

        // Populate the list with liabilities and checkboxes
        data.forEach(liability => {
          const listItem = document.createElement('li');
          const checkbox = document.createElement('input');
          checkbox.type = 'checkbox';
          checkbox.name = 'liability';
          checkbox.value = liability.id; // Use a unique identifier for each liability
          listItem.appendChild(checkbox);
          listItem.appendChild(document.createTextNode(` ${liability.nme} - ${liability.accntRfrnce}`));
          liabilitiesList10.appendChild(listItem);
        });

        // Show the modal
        $(RemoveSolicitor).modal('show');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });

  // Add a click event listener to the "Mark Liability as Inactive" button
  RemoveSolicitorButton.addEventListener('click', function () {
    // Get the selected liabilities
    const selectedLiabilities = Array.from(document.querySelectorAll('input[name="liability"]:checked'))
      .map(checkbox => checkbox.value);

    // Make an AJAX request to update the selected liabilities
    fetch('/client/Updates/remove_sol.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({ selectedLiabilities }),
    })
      .then(response => response.json())
      .then(data => {
        if (data.success) {
          // Handle success (e.g., display a success message)
          console.log(data.message);
        } else {
          // Handle failure (e.g., display an error message)
          console.error(data.message);
        }

        // Close the modal
        $(RemoveSolicitor).modal('hide');
      })
      .catch(error => {
        console.error('Error:', error);
      });
  });
});   
    
</script>
</body>
</html>