<?php
session_start();

// If session variable 'username' is not set or is 'Guest', redirect to login page
if (!isset($_SESSION['username']) || $_SESSION['username'] === "Guest") {
    header("Location: /login.php");
    exit();
}

// Check if the session is inactive for more than 10 seconds
if (isset($_SESSION['last_activity']) && (time() - $_SESSION['last_activity'] > 900)) {
    // Session has been inactive for more than 10 seconds
    session_unset();     // Unset $_SESSION variable for the run-time
    session_destroy();   // Destroy the session data on the server
    header("Location: /login.php"); // Redirect to login page
    exit(); // Ensure no further execution of the script
}

// Update last activity time stamp
$_SESSION['last_activity'] = time();

$username = $_SESSION['username']; // Username is already checked above and is not 'Guest'

// Check if 'client_id' is in the URL query parameter
if (isset($_GET['client_id'])) {
    // Store the 'client_id' from the URL in a variable
    $id = $_GET['client_id'];
} else {
    // Set a default value or handle the case where 'client_id' is not provided in the URL
    $id = 'default_value';
}
$username = isset($_SESSION['username']) ? $_SESSION['username'] : "Guest";
include_once '../config_current.php';

/// Get Username
$query = "SELECT nme, job_title FROM account_users WHERE email = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param('s', $username);
$stmt->execute();

$result = $stmt->get_result();
$row = $result->fetch_assoc();

if ($row) {
    $truename = $row['nme'];
    $jobtitle = $row['job_title'];
} else {
    $truename = "Unknown";
}

$stmt->close();

// Suppose 'case_details' is your table name and it contains relevant information about the case
$case_query = "SELECT * FROM client_core WHERE id = ?";
$case_stmt = $conn->prepare($case_query);
$case_stmt->bind_param('i', $id); // assuming client_id is an integer field
$case_stmt->execute();

$case_result = $case_stmt->get_result();
$case_details = $case_result->fetch_assoc(); // fetches the row as an associative array

// print_r($case_details); exit;

$case_stmt->close();


// Fetch previous addresses
$clientId = $id; // Your ClientId
$previousAddresses = [];

$query = "SELECT `pre-address` FROM `client_core` WHERE id = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $clientId);
$stmt->execute();
$result = $stmt->get_result();

while ($row = $result->fetch_assoc()) {
    $previousAddresses[] = $row;
}

$stmt->close();
?>

<!DOCTYPE html>
<html>
<head>
    <title>Address | Case <?php echo $case_details['id']; ?></title>
    <?php include 'layouts/head.php'; ?>
    <?php include 'layouts/head-style.php'; ?>
</head>
<body>
    <?php include 'layouts/body.php'; ?>

<div id="layout-wrapper">
    <?php include 'layouts/vertical-menu.php'; ?>
    <div class="main-content">
        <div class="page-content">
            <div class="container-fluid">
                <br>
                <div id="messageContainer"></div>
                <h3>Current Address</h3>
                <div class="row mb-4">
                    <div class="col-md-3">
                        <div class="form-group">
                            <label>Postcode</label>
                            <input type="text" id="Postcode" name="Postcode" class="form-control" value="<?php echo htmlspecialchars($case_details['pstCde'] ?? ''); ?>">
                        </div>
                    </div>
                    <div class="col-md-3">
                        <div class="form-group">
                            <label>Select Address</label>
                            <select id="AddressDropdown" class="form-control"></select>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="form-group">
                            <label>Address</label>
                            <textarea id="FullAddress" name="FullAddress" class="form-control" rows="5"><?php echo htmlspecialchars($case_details['fulladdress'] ?? '') . "\n" . htmlspecialchars($case_details['Address_2'] ?? '') . "\n" . htmlspecialchars($case_details['Town'] ?? '') . "\n" . htmlspecialchars($case_details['County'] ?? ''); ?></textarea>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-md-12">
                        <button id="saveButton" class="btn btn-success">Save Address Information</button>
                    </div>
                </div>
                <br>

                <h3>Previous Addresses</h3>
                <div id="addressContainer">
                    <?php foreach ($previousAddresses as $index => $address) : ?>
                    <div class="row mb-4 address-row" id="addressRow_<?php echo $index; ?>">
                        <div class="col-md-3">
                            <div class="form-group">
                                <label>Postcode</label>
                                <input type="text" name="Postcode_Pre[]" class="form-control postcode" id="Postcode_Pre_<?php echo $index; ?>" value="<?php echo htmlspecialchars($address['Postcode_Pre']); ?>">
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="form-group">
                                <label>Select Address</label>
                                <select class="form-control address-dropdown" name="AddressDropdown_Pre[]" id="AddressDropdown_Pre_<?php echo $index; ?>"></select>
                            </div>
                        </div>
                        <div class="col-md-5">
                            <div class="form-group">
                                <label>Address</label>
                                <textarea name="FullAddress_Pre[]" class="form-control full-address" id="FullAddress_Pre_<?php echo $index; ?>" rows="5"><?php echo htmlspecialchars($address['pre-address']) . "\n" . htmlspecialchars($address['Address_2_Pre']) . "\n" . htmlspecialchars($address['Town_Pre']); ?></textarea>
                            </div>
                        </div>
                        <div class="col-md-1">
                            <button type="button" class="btn btn-danger remove-address" onclick="removeAddress(this)">Delete</button>
                        </div>
                    </div>
                    <?php endforeach; ?>
                </div>
                <div class="row">
                    <div class="col-md-12">
                        <button id="addButton" class="btn btn-primary" onclick="addAddress()">Add Address</button>
                        <button id="savePreviousButton" class="btn btn-success">Save Previous Address Information</button>
                    </div>
                </div>

                <script>
                    let addressCounter = <?php echo count($previousAddresses); ?>;

                    function addAddress() {
                        var addressContainer = document.getElementById('addressContainer');
                        var newAddressRow = document.createElement('div');
                        newAddressRow.classList.add('row', 'mb-4', 'address-row');
                        newAddressRow.id = 'addressRow_' + addressCounter;
                        newAddressRow.innerHTML = `
                            <div class="col-md-3">
                                <div class="form-group">
                                    <label>Postcode</label>
                                    <input type="text" name="Postcode_Pre[]" class="form-control postcode" id="Postcode_Pre_${addressCounter}">
                                </div>
                            </div>
                            <div class="col-md-3">
                                <div class="form-group">
                                    <label>Select Address</label>
                                    <select class="form-control address-dropdown" name="AddressDropdown_Pre[]" id="AddressDropdown_Pre_${addressCounter}"></select>
                                </div>
                            </div>
                            <div class="col-md-5">
                                <div class="form-group">
                                    <label>Address</label>
                                    <textarea name="FullAddress_Pre[]" class="form-control full-address" id="FullAddress_Pre_${addressCounter}" rows="5"></textarea>
                                </div>
                            </div>
                            <div class="col-md-1">
                                <button type="button" class="btn btn-danger remove-address" onclick="removeAddress(this)">Delete</button>
                            </div>
                        `;
                        addressContainer.appendChild(newAddressRow);

                        // Add event listeners for the new elements
                        document.getElementById('Postcode_Pre_' + addressCounter).addEventListener('input', fetchAddressesPre);
                        document.getElementById('AddressDropdown_Pre_' + addressCounter).addEventListener('change', populateFullAddressPre);

                        addressCounter++;
                    }

                    function removeAddress(button) {
                        var addressRow = button.parentNode.parentNode;
                        addressRow.parentNode.removeChild(addressRow);
                    }

                    function fetchAddressesPre(event) {
                        const postcodeElement = event.target;
                        const postcode = postcodeElement.value;
                        const addressRowId = postcodeElement.id.split('_')[2];
                        const dropdown = document.getElementById('AddressDropdown_Pre_' + addressRowId);

                        if (postcode) {
                            const apiKey = 'davJcfnRhUGUad_gqpDLdw29501'; // Replace with your API key
                            fetch(`https://api.getaddress.io/find/${postcode}?api-key=${apiKey}`)
                                .then(response => response.json())
                                .then(data => {
                                    if (data.addresses && data.addresses.length > 0) {
                                        dropdown.innerHTML = '<option value="">Select an address</option>';
                                        data.addresses.forEach((address, index) => {
                                            const option = document.createElement('option');
                                            option.value = address;
                                            option.textContent = address;
                                            dropdown.appendChild(option);
                                        });
                                    } else {
                                        console.error('No addresses found or there was an error.');
                                    }
                                })
                                .catch(error => {
                                    console.error('Error:', error);
                                });
                        }
                    }

                    function populateFullAddressPre(event) {
                        const dropdownElement = event.target;
                        const selectedAddress = dropdownElement.value;
                        const addressRowId = dropdownElement.id.split('_')[2];
                        const fullAddressTextarea = document.getElementById('FullAddress_Pre_' + addressRowId);

                        if (selectedAddress) {
                            const addressParts = selectedAddress.split(', ');
                            fullAddressTextarea.value = addressParts.filter(part => part.trim() !== '').join('\n');
                        }
                    }

                    // Fetch addresses for current address
                    document.getElementById('Postcode').addEventListener('input', fetchAddresses);

                    function fetchAddresses() {
                        const postcode = document.getElementById('Postcode').value;

                        if (postcode) {
                            const apiKey = 'davJcfnRhUGUad_gqpDLdw29501'; // Replace with your API key
                            fetch(`https://api.getaddress.io/find/${postcode}?api-key=${apiKey}`)
                                .then(response => response.json())
                                .then(data => {
                                    if (data.addresses && data.addresses.length > 0) {
                                        const dropdown = document.getElementById('AddressDropdown');
                                        dropdown.innerHTML = '<option value="">Select an address</option>';
                                        data.addresses.forEach((address, index) => {
                                            const option = document.createElement('option');
                                            option.value = address;
                                            option.textContent = address;
                                            dropdown.appendChild(option);
                                        });
                                    } else {
                                        console.error('No addresses found or there was an error.');
                                    }
                                })
                                .catch(error => {
                                    console.error('Error:', error);
                                });
                        }
                    }

                    function populateFullAddress() {
                        const selectedAddress = document.getElementById('AddressDropdown').value;
                        if (selectedAddress) {
                            const addressParts = selectedAddress.split(', ');
                            document.getElementById('FullAddress').value = addressParts.filter(part => part.trim() !== '').join('\n');
                        }
                    }

                    document.getElementById('AddressDropdown').addEventListener('change', populateFullAddress);

                    document.getElementById('saveButton').addEventListener('click', saveAddressInformation);

                    function saveAddressInformation() {
                        const fullAddress = document.getElementById('FullAddress').value.trim();
                        const postcode = document.getElementById('Postcode').value.trim();

                        if (fullAddress && postcode) {
                            const addressParts = fullAddress.split('\n');
                            const postData = {
                                id: <?php echo $case_details['id']; ?>,
                                Address_1: addressParts[0] || '',
                                Address_2: addressParts[1] || '',
                                Town: addressParts.slice(2).join(', ') || '',
                                Postcode: postcode
                            };

                            fetch('/client/Updates/update_address.php', {
                                method: 'POST',
                                body: JSON.stringify(postData),
                                headers: {
                                    'Content-Type': 'application/json'
                                }
                            })
                            .then(response => response.json())
                            .then(data => {
                                if (data.success) {
                                    showSuccessMessage();
                                } else {
                                    showErrorMessage();
                                }
                            })
                            .catch(error => {
                                console.error('Error:', error);
                                showErrorMessage();
                            });
                        } else {
                            showErrorMessage('Please provide both address and postcode.');
                        }
                    }

                    function showSuccessMessage() {
                        const successAlert = document.createElement('div');
                        successAlert.classList.add('alert', 'alert-success');
                        successAlert.setAttribute('role', 'alert');
                        successAlert.textContent = 'Address information saved successfully!';
                        
                        const messageContainer = document.getElementById('messageContainer');
                        messageContainer.innerHTML = '';
                        messageContainer.appendChild(successAlert);
                    }

                    function showErrorMessage(message = 'Error: Failed to save address information.') {
                        const errorAlert = document.createElement('div');
                        errorAlert.classList.add('alert', 'alert-danger');
                        errorAlert.setAttribute('role', 'alert');
                        errorAlert.textContent = message;
                        
                        const messageContainer = document.getElementById('messageContainer');
                        messageContainer.innerHTML = '';
                        messageContainer.appendChild(errorAlert);
                    }

                    document.getElementById('savePreviousButton').addEventListener('click', savePreviousAddressInformation);

                    function savePreviousAddressInformation() {
                        const addressRows = document.querySelectorAll('.address-row');
                        const previousAddresses = [];

                        addressRows.forEach(row => {
                            const fullAddress = row.querySelector('.full-address').value.trim();
                            const postcode = row.querySelector('.postcode').value.trim();

                            if (fullAddress && postcode) {
                                const addressParts = fullAddress.split('\n');
                                previousAddresses.push({
                                    Address_1_Pre: addressParts[0] || '',
                                    Address_2_Pre: addressParts[1] || '',
                                    Town_Pre: addressParts.slice(2).join(', ') || '',
                                    Postcode_Pre: postcode
                                });
                            }
                        });

                        if (previousAddresses.length > 0) {
                            const postData = {
                                ClientId: <?php echo $case_details['id']; ?>,
                                PreviousAddresses: previousAddresses
                            };

                            fetch('/client/Updates/insert_previous_address.php', {
                                method: 'POST',
                                body: JSON.stringify(postData),
                                headers: {
                                    'Content-Type': 'application/json'
                                }
                            })
                            .then(response => response.json())
                            .then(data => {
                                if (data.success) {
                                    showSuccessMessage();
                                } else {
                                    showErrorMessage();
                                }
                            })
                            .catch(error => {
                                console.error('Error:', error);
                                showErrorMessage();
                            });
                        } else {
                            showErrorMessage('Please provide both address and postcode for previous addresses.');
                        }
                    }

                    function showSuccessMessage() {
                        const successAlert = document.createElement('div');
                        successAlert.classList.add('alert', 'alert-success');
                        successAlert.setAttribute('role', 'alert');
                        successAlert.textContent = 'Previous address information saved successfully!';
                        
                        const messageContainer = document.getElementById('messageContainer');
                        messageContainer.innerHTML = '';
                        messageContainer.appendChild(successAlert);
                    }

                    function showErrorMessage(message = 'Error: Failed to save previous address information.') {
                        const errorAlert = document.createElement('div');
                        errorAlert.classList.add('alert', 'alert-danger');
                        errorAlert.setAttribute('role', 'alert');
                        errorAlert.textContent = message;
                        
                        const messageContainer = document.getElementById('messageContainer');
                        messageContainer.innerHTML = '';
                        messageContainer.appendChild(errorAlert);
                    }
                </script>
            </div>
        </div>
    </div>
</div>
</body>
</html>
