<?php
session_start();

// If session variable 'username' is not set or is 'Guest', redirect to login page
if (!isset($_SESSION['username']) || $_SESSION['username'] === "Guest") {
    header("Location: /login.php");
    exit();
}

// Check if the session is inactive for more than 10 seconds
if (isset($_SESSION['last_activity']) && (time() - $_SESSION['last_activity'] > 900)) {
    // Session has been inactive for more than 10 seconds
    session_unset();     // Unset $_SESSION variable for the run-time
    session_destroy();   // Destroy the session data on the server
    header("Location: /login.php"); // Redirect to login page
    exit(); // Ensure no further execution of the script
}

// Update last activity time stamp
$_SESSION['last_activity'] = time();

$username = $_SESSION['username']; // Username is already checked above and is not 'Guest'

// Check if 'client_id' is in the URL query parameter
if (isset($_GET['client_id'])) {
    // Store the 'client_id' from the URL in a variable
    $id = $_GET['client_id'];
} else {
    // Set a default value or handle the case where 'client_id' is not provided in the URL
    $id = 'default_value';
}
$username = isset($_SESSION['username']) ? $_SESSION['username'] : "Guest";
include_once '../config_current.php';

/// Get Username
$query = "SELECT nme, job_title FROM account_users WHERE email = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param('s', $username);
$stmt->execute();

$result = $stmt->get_result();
$row = $result->fetch_assoc();

if ($row) {
    $truename = $row['nme'];
    $jobtitle = $row['job_title'];
} else {
    $truename = "Unknown";
}

$stmt->close();

// Suppose 'case_details' is your table name and it contains relevant information about the case
$case_query = "SELECT * FROM client_core WHERE id = ?";
$case_stmt = $conn->prepare($case_query);
$case_stmt->bind_param('i', $id); // assuming client_id is an integer field
$case_stmt->execute();
$case_result = $case_stmt->get_result();
$case_details = $case_result->fetch_assoc(); // fetches the row as an associative array
$case_stmt->close();

// Fetch case handlers from the database
$case_handler_query = "SELECT id, nme FROM account_users WHERE id NOT IN (1, 2, -1, -2, -3, -4)";
$case_handler_stmt = $conn->prepare($case_handler_query); // Prepare the query
$case_handler_stmt->execute(); // Execute the query
$case_handler_result = $case_handler_stmt->get_result(); // Get the results

if ($case_handler_result->num_rows > 0) {
    while ($case_handler_row = $case_handler_result->fetch_assoc()) {
        $case_handlers[] = $case_handler_row;
    }
}

// Make sure to close the statement if you're done with it
$case_handler_stmt->close();

?>

<!DOCTYPE html>
<html>

<head>
    <title>Agreement Details | Case <?php echo $case_details['id']; ?></title>
    <?php include 'layouts/head.php'; ?>
    <?php include 'layouts/head-style.php'; ?>
</head>

<style>
    /* Container to wrap the select and the icon */
    .select-wrapper {
        position: relative;
        display: inline-block;
        width: 100%;
    }

    /* Style the select element: remove default appearance and add right padding */
    .select-wrapper select {
        width: 100%;
        padding-right: 2.5rem;
        /* Adjust if needed to create space for the icon */
        -webkit-appearance: none;
        -moz-appearance: none;
        appearance: none;
    }

    /* Position the static down arrow icon */
    .select-arrow {
        position: absolute;
        right: 1rem;
        /* Adjust as needed */
        top: 50%;
        transform: translateY(-50%);
        pointer-events: none;
        /* Allows clicks to pass through to the select */
        font-size: 1.2rem;
        /* Adjust icon size if needed */
        color: #555;
        /* Change color as desired */
    }
</style>

<body>
    <?php include 'layouts/body.php'; ?>

    <div id="layout-wrapper">
        <?php include 'layouts/vertical-menu.php'; ?>
        <div class="main-content">
            <div class="page-content">
                <div class="container-fluid">
                    <form id="agreementForm" action="Updates/Update_Agreement_Details.php" method="post">
                        <!-- Applicant 1 Form -->
                        <div class="row">
                               <div class="row mt-3">
                            <div class="col-md-14">
                                <h3 class="fs-2">Agreement Details:</h3>
                                 <div class="row mt-3">
                                      <div class="col-md-6">
                                <div class="form-group">
                                    <label class="fs-5">Case Handler</label>
                                    <div class="select-wrapper">
                                        <select name="caseHandler" class="form-control">
                                            <!-- Default "Select one" option -->
                                            <option value="" <?php echo (empty($case_details['cc-advisor'])) ? 'selected' : ''; ?>>
                                                Select one...
                                            </option>
                                            <!-- Dynamically generate options from account_users -->
                                            <?php foreach ($case_handlers as $handler):
                                                // Check if the current handler's id matches the case's advisor id.
                                                $selected = ($case_details['cc-advisor'] == $handler['id']) ? 'selected' : '';
                                            ?>
                                                <option value="<?php echo $handler['id']; ?>" <?php echo $selected; ?>>
                                                    <?php echo htmlspecialchars($handler['nme']); ?>
                                                </option>
                                            <?php endforeach; ?>
                                        </select>
                                        <!-- Static down arrow icon using Material Symbols -->
                                        <span class="material-symbols-outlined select-arrow">keyboard_arrow_down</span>
                                    </div>
                                </div>
                                </div>
                                 <div class="col-md-6">
                                <div class="form-group">
                                    <label class="fs-5">Plan Type</label>
                                    <div class="select-wrapper">
                                        <select name="plnTpe" class="form-control">
                                            <option value="Select one..." <?php echo ($case_details['plan-type']  == 'Select one...') ? 'selected' : ''; ?>>Select one...</option>
                                            <option value="10" <?php echo ($case_details['plan-type']  == '12') ? 'selected' : ''; ?>>12 Months</option>
                                            <option value="11" <?php echo ($case_details['plan-type']  == '15') ? 'selected' : ''; ?>>15 Months</option>
                                            <option value="12" <?php echo ($case_details['plan-type']  == '18') ? 'selected' : ''; ?>>18 Months</option>
                                            <option value="13" <?php echo ($case_details['plan-type']  == '24') ? 'selected' : ''; ?>>24 Months</option>
                                        </select>
                                        <span class="material-symbols-outlined select-arrow">keyboard_arrow_down</span>
                                    </div>
                                </div>
                                </div>
                                </div>
                                <div class="row mt-1">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label class="fs-5">Next Review Date:</label>
                                            <input type="date" name="reviewDate" class="form-control" value="<?php echo ($case_details['review-dte']) ? date('Y-m-d', strtotime($case_details['review-dte'])) : ''; ?>">
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label class="fs-5">Welcome Call Date:</label>
                                            <input type="date" name="welcomeDate" class="form-control" value="<?php echo isset($case_details['courtesy-dte']) ? date('Y-m-d', strtotime($case_details['courtesy-dte'])) : ''; ?>">
                                        </div>
                                    </div>
                                </div>
                            </div>
                            </div>
                            <!-- Payment Section -->
                            <div class="row mb-4 mt-3">
                                <!-- First Column -->
                                <div class="col-md-14">
                                    <h3 class="fs-2">Payment Details:</h3>
                                    <div class="row mt-1">
                                        <div class="col-md-6">
                                            <div class="form-group">
                                                <label class="fs-5">Next Payment Date:</label>
                                                <input type="date" name="paymentDate" class="form-control" value="<?php echo isset($case_details['nxt-py-dte']) ? date('Y-m-d', strtotime($case_details['nxt-py-dte'])) : ''; ?>">
                                            </div>
                                        </div>
                                        <div class="col-md-6">
                                            <div class="form-group">
                                                <label class="fs-5">Fee Amount(PCM):</label>
                                                <input type="number" name="feeAmount" class="form-control" value="<?php echo ($case_details['monthly-fee']) ?? '0'; ?>">
                                            </div>
                                        </div>
                                    </div>
                                    <div class="row mt-1">
                                        <div class="col-md-6">
                                            <div class="form-group">
                                                <label class="fs-5">Fees as per Payment Frequency:</label>
                                                <input type="number" name="feePaymentFrqncy" class="form-control" value="<?php echo ($case_details['frequency-fee']) ?? '0'; ?>">
                                            </div>
                                        </div>
                                        <div class="col-md-6">
                                            <div class="form-group">
                                                <label class="fs-5">Payment Method:</label>
                                      <div class="select-wrapper">
                                        <select name="paymentMethod" class="form-control">
                                            <option value="Select one..." <?php echo ($case_details['payment-method']  == 'Select one...') ? 'selected' : ''; ?>>Select one...</option>
                                            <option value="bacs" <?php echo ($case_details['payment-method']  == 'transfer') ? 'selected' : ''; ?>>BACS</option>
                                            <option value="card" <?php echo ($case_details['payment-method']  == 'card') ? 'selected' : ''; ?>>Credit/Debit Card</option>
                                        </select>
                                        <span class="material-symbols-outlined select-arrow">keyboard_arrow_down</span>
                                    </div>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="row mt-1">
                                        <div class="col-md-6">
                                            <div class="form-group">
                                                <label class="fs-5">Payment Frequency:</label>
                                                             <div class="select-wrapper">
                                        <select name="paymentFrqncy" class="form-control">
                                            <option value="Select one..." <?php echo ($case_details['payment-frequency']  == 'Select one...') ? 'selected' : ''; ?>>Select one...</option>
                                            <option value="weekly" <?php echo ($case_details['payment-frequency']  == 'weekly') ? 'selected' : ''; ?>>Weekly</option>
                                            <option value="fortnightly" <?php echo ($case_details['payment-frequency']  == 'fortnight') ? 'selected' : ''; ?>>Fortnightly</option>
                                            <option value="forweekly" <?php echo ($case_details['payment-frequency']  == 'forweekly') ? 'selected' : ''; ?>>4 Weekly</option>
                                            <option value="lastday" <?php echo ($case_details['payment-frequency']  == 'lastday') ? 'selected' : ''; ?>>Last Day of Month</option>
                                        </select>
                                        <span class="material-symbols-outlined select-arrow">keyboard_arrow_down</span>
                                    </div>
                                                
                                            </div>
                                        </div>
                                        <div class="col-md-6">
                                            <div class="form-group">
                                                <label class="fs-5">Card Capture:</label>
                                                    <div class="select-wrapper">
                                        <select name="cardCapture" class="form-control">
                                            <option value="Select one..." <?php echo ($case_details['card-captured']  == 'Select one...') ? 'selected' : ''; ?>>Select one...</option>
                                            <option value="yes" <?php echo ($case_details['card-captured']  == 'yes') ? 'selected' : ''; ?>>YES</option>
                                            <option value="no" <?php echo ($case_details['card-captured']  == 'no') ? 'selected' : ''; ?>>NO</option>
                                        </select>
                                        <span class="material-symbols-outlined select-arrow">keyboard_arrow_down</span>
                                    </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <!-- Set up Fee Payments -->
                            <div class="row mb-4">
                                <!-- Setup Fee 1 Column -->
                                <div class="col-md-14">
                                    <h3 class= "fs-2">Payments Key Events:</h3>
                                    <div class="row mt-4">
                                        <div class= "col-md-6">
                                         <div class="form-group">
                                        <label class="fs-5">Initial Payment 1:</label>
                                        <input type="date" name="ip1" class="form-control" value="<?php echo isset($case_details['ip-01-when']) ? date('Y-m-d', strtotime($case_details['ip-01-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                         <div class= "col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 2:</label>
                                        <input type="date" name="ip2" class="form-control" value="<?php echo isset($case_details['ip-02-when']) ? date('Y-m-d', strtotime($case_details['ip-02-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                    </div>
                                      <div class="row mt-1">
                                        <div class= "col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 3:</label>
                                        <input type="date" name="ip3" class="form-control" value="<?php echo isset($case_details['ip-03-when']) ? date('Y-m-d', strtotime($case_details['ip-03-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                     <div class= "col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 4:</label>
                                        <input type="date" name="ip4" class="form-control" value="<?php echo isset($case_details['ip-04-when']) ? date('Y-m-d', strtotime($case_details['ip-04-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                    </div>
                                     <div class="row mt-1">
                                        <div class= "col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 5:</label>
                                        <input type="date" name="ip5" class="form-control" value="<?php echo isset($case_details['ip-05-when']) ? date('Y-m-d', strtotime($case_details['ip-05-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                      <div class= "col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 6:</label>
                                        <input type="date" name="ip6" class="form-control" value="<?php echo isset($case_details['ip-06-when']) ? date('Y-m-d', strtotime($case_details['ip-06-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                    </div>
                                       <div class="row mt-1">
                                        <div class= "col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 7:</label>
                                        <input type="date" name="ip7" class="form-control" value="<?php echo isset($case_details['ip-07-when']) ? date('Y-m-d', strtotime($case_details['ip-07-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                        <div class= "col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 8:</label>
                                        <input type="date" name="ip8" class="form-control" value="<?php echo isset($case_details['ip-08-when']) ? date('Y-m-d', strtotime($case_details['ip-08-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                </div>
                                <div class="row mt-1">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 9:</label>
                                        <input type="date" name="ip9" class="form-control" value="<?php echo isset($case_details['ip-09-when']) ? date('Y-m-d', strtotime($case_details['ip-09-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                        <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 10:</label>
                                        <input type="date" name="ip10" class="form-control" value="<?php echo isset($case_details['ip-10-when']) ? date('Y-m-d', strtotime($case_details['ip-10-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                    </div>
                                     <div class="row mt-1">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 11:</label>
                                        <input type="date" name="ip11" class="form-control" value="<?php echo isset($case_details['ip-11-when']) ? date('Y-m-d', strtotime($case_details['ip-11-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                        <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 12:</label>
                                        <input type="date" name="ip12" class="form-control" value="<?php echo isset($case_details['ip-12-when']) ? date('Y-m-d', strtotime($case_details['ip-12-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                    </div>
                                    <div class="row mt-1">
                                    <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 13:</label>
                                        <input type="date" name="ip13" class="form-control" value="<?php echo isset($case_details['ip-13-when']) ? date('Y-m-d', strtotime($case_details['ip-13-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                        <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 14:</label>
                                        <input type="date" name="ip14" class="form-control" value="<?php echo isset($case_details['ip-14-when']) ? date('Y-m-d', strtotime($case_details['ip-14-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                    </div>
                                    <div class="row mt-1">
                                        <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 15:</label>
                                        <input type="date" name="ip15" class="form-control" value="<?php echo isset($case_details['ip-15-when']) ? date('Y-m-d', strtotime($case_details['ip-15-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                       <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 16:</label>
                                        <input type="date" name="ip16" class="form-control" value="<?php echo isset($case_details['ip-16-when']) ? date('Y-m-d', strtotime($case_details['ip-16-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                    </div>
                                     <div class="row mt-1">
                                        <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 17:</label>
                                        <input type="date" name="ip17" class="form-control" value="<?php echo isset($case_details['ip-17-when']) ? date('Y-m-d', strtotime($case_details['ip-17-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                       <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 18:</label>
                                        <input type="date" name="ip18" class="form-control" value="<?php echo isset($case_details['ip-18-when']) ? date('Y-m-d', strtotime($case_details['ip-18-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                    </div>
                                     <div class="row mt-1">
                                        <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 19:</label>
                                        <input type="date" name="ip19" class="form-control" value="<?php echo isset($case_details['ip-19-when']) ? date('Y-m-d', strtotime($case_details['ip-19-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                       <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 20:</label>
                                        <input type="date" name="ip20" class="form-control" value="<?php echo isset($case_details['ip-20-when']) ? date('Y-m-d', strtotime($case_details['ip-20-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                    </div>
                                     <div class="row mt-1">
                                        <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 21:</label>
                                        <input type="date" name="ip21" class="form-control" value="<?php echo isset($case_details['ip-21-when']) ? date('Y-m-d', strtotime($case_details['ip-21-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                       <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 22:</label>
                                        <input type="date" name="ip22" class="form-control" value="<?php echo isset($case_details['ip-22-when']) ? date('Y-m-d', strtotime($case_details['ip-22-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                    </div>
                                     <div class="row mt-1">
                                        <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 23:</label>
                                        <input type="date" name="ip23" class="form-control" value="<?php echo isset($case_details['ip-23-when']) ? date('Y-m-d', strtotime($case_details['ip-23-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                       <div class="col-md-6">
                                    <div class="form-group">
                                        <label class="fs-5">Initial Payment 24:</label>
                                        <input type="date" name="ip24" class="form-control" value="<?php echo isset($case_details['ip-24-when']) ? date('Y-m-d', strtotime($case_details['ip-24-when'])) : ''; ?>">
                                    </div>
                                    </div>
                                    </div>
                                </div>
                            </div>
                            <div class="form-group text-center">
                                <button type="submit" class="btn btn-success" name="save_button">Save Agreement Details</button>
                            </div>
                    </form>
                    <!-- End of Base Applicant Form -->
                    <br>

                    <div id="alert_placeholder"></div>
                </div>
            </div>
        </div>
    </div>

    <script>
        $(document).ready(function() {
            // When the form is submitted
            $('#agreementForm').on('submit', function(e) {
                e.preventDefault();

                // Serialize the form data into a URL-encoded string
                var formData = $(this).serialize();

                // Send the form data to your server using AJAX
                $.ajax({
                    url: 'Updates/Update_Agreement_Details.php',
                    type: 'POST',
                    data: formData,
                    dataType: 'json', // Specify that you expect a JSON response
                    success: function(response) {
                        // Check if the response was successful
                        if (response.success === true) {
                            // If the response has "success" set to true, show the success alert
                            $('#alert_placeholder').html('<div class="alert alert-success" role="alert">' + response.message + '</div>');
                        } else {
                            // If the response has "success" set to false or any other value, show the warning alert
                            $('#alert_placeholder').html('<div class="alert alert-warning" role="alert">' + response.message + '</div>');
                        }
                    },
                    error: function(xhr, status, error) {
                        // If the AJAX request fails, show the warning alert
                        $('#alert_placeholder').html('<div class="alert alert-warning" role="alert">Error Updating Agreement Details</div>');
                    }
                });
            });
        });
    </script>

</body>

</html>