<?php
session_start();

// If session variable 'username' is not set or is 'Guest', redirect to login page
if (!isset($_SESSION['username']) || $_SESSION['username'] === "Guest") {
    header("Location: /login.php");
    exit();
}

// Check if the session is inactive for more than 10 seconds
if (isset($_SESSION['last_activity']) && (time() - $_SESSION['last_activity'] > 900)) {
    // Session has been inactive for more than 10 seconds
    session_unset();     // Unset $_SESSION variable for the run-time
    session_destroy();   // Destroy the session data on the server
    header("Location: /login.php"); // Redirect to login page
    exit(); // Ensure no further execution of the script
}

// Update last activity time stamp
$_SESSION['last_activity'] = time();

$username = $_SESSION['username']; // Username is already checked above and is not 'Guest'

// Check if 'client_id' is in the URL query parameter
if (isset($_GET['client_id'])) {
    // Store the 'client_id' from the URL in a variable
    $id = $_GET['client_id'];
} else {
    // Set a default value or handle the case where 'client_id' is not provided in the URL
    $id = 'default_value';
}
$username = isset($_SESSION['username']) ? $_SESSION['username'] : "Guest";
include_once '../config_current.php';

/// Get Username
$query = "SELECT nme, job_title FROM account_users WHERE email = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param('s', $username);
$stmt->execute();

$result = $stmt->get_result();
$row = $result->fetch_assoc();

if ($row) {
    $truename = $row['nme'];
    $jobtitle = $row['job_title'];
} else {
    $truename = "Unknown";
}

$stmt->close();

// Suppose 'case_details' is your table name and it contains relevant information about the case
$case_query = "SELECT * FROM client_core WHERE id = ?";
$case_stmt = $conn->prepare($case_query);
$case_stmt->bind_param('i', $id); // assuming client_id is an integer field
$case_stmt->execute();

$case_result = $case_stmt->get_result();
$case_details = $case_result->fetch_assoc(); // fetches the row as an associative array

// print_r($case_details); exit;

$case_stmt->close();

?>

<!DOCTYPE html>
<html>

<head>
    <title>Applicants | Case <?php echo $case_details['id']; ?></title>
    <?php include '../layouts/head.php'; ?>
    <?php include '../layouts/head-style.php'; ?>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.3.1/jquery.min.js"></script>
</head>

<body>
    <?php include '../layouts/body.php'; ?>

    <div id="layout-wrapper">
        <?php include 'layouts/vertical-menu.php'; ?>
        <div class="main-content">
            <div class="page-content">
                <div class="container-fluid">
                    <!-- Form for Base Applicant Details -->
                    <form id="baseApplicantForm" action="Updates/Update_Base_Applicants.php" method="post">
                        <!-- Applicant 1 Form -->
                        <div class="row mb-4">
                            <div class="col-md-6">
                                <h4>Applicant 1:</h4>
                                <div class="form-group">
                                    <label>Title</label>
                                    <select name="ttle1" class="form-control">
                                        <option value="Select one..." <?php echo ($case_details['title-1']  == 'Select one...') ? 'selected' : ''; ?>>Select one...</option>
                                        <option value="Mr" <?php echo ($case_details['title-1']  == 'Mr') ? 'selected' : ''; ?>>Mr</option>
                                        <option value="Mrs" <?php echo ($case_details['title-1']  == 'Mrs') ? 'selected' : ''; ?>>Mrs</option>
                                        <option value="Miss" <?php echo ($case_details['title-1']  == 'Miss') ? 'selected' : ''; ?>>Miss</option>
                                        <option value="Ms" <?php echo ($case_details['title-1']  == 'Ms') ? 'selected' : ''; ?>>Ms</option>
                                    </select>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>First Name</label>
                                            <input type="text" name="frstNme1" class="form-control" value="<?php echo htmlspecialchars($case_details['forename-1'] ?? ''); ?>">
                                            <input type="hidden" name="userid" class="form-control" value="<?php echo $userid ?>">

                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Surname</label>
                                            <input type="text" name="srNme1" class="form-control" value="<?php echo htmlspecialchars($case_details['surname-1'] ?? ''); ?>">
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Date Of Birth</label>
                                            <?php
                                            // Assuming $case_details['dteOfBrth1'] is in the format 'Y-m-d H:i:s'
                                            $originalDate = $case_details['dteOfBrth-1'] ?? '';

                                            // Check if the date is not empty
                                            if (!empty($originalDate)) {
                                                // Create a new DateTime object from the original date
                                                $dateObject = new DateTime($originalDate);

                                                // Format the date to 'Y-m-d' for the input element
                                                $formattedDate = $dateObject->format('Y-m-d');
                                            } else {
                                                // Set to empty string if original date is empty
                                                $formattedDate = '';
                                            }
                                            ?>

                                            <input type="date" name="dteOfBrth-1" class="form-control" value="<?php echo htmlspecialchars($formattedDate); ?>">

                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Email Address</label>
                                            <input type="email" name="emlAddrss1" class="form-control" value="<?php echo htmlspecialchars($case_details['emlAddrss-1'] ?? ''); ?>">
                                        </div>
                                    </div>

                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Mobile Number</label>
                                            <input type="number" name="mblePhone1" class="form-control" value="<?php echo htmlspecialchars($case_details['mblePhone-1'] ?? ''); ?>">
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Home Telephone Number</label>
                                            <input type="number" name="HmePhone1" class="form-control" value="<?php echo htmlspecialchars($case_details['HmePhone-1'] ?? ''); ?>">
                                        </div>
                                    </div>

                                </div>
                                <?php
                                // Assuming you have the value stored in $case_details['employment_1']
                                $employmentStatus = strtolower($case_details['employment-1'] ?? '');
                                ?>

                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Employment Status</label>
                                            <select name="employment_1" class="form-control">
                                                <option value="" <?php echo ($employmentStatus == '') ? 'selected' : ''; ?>>Select one...</option>
                                                <option value="Employed" <?php echo ($employmentStatus == 'employed') ? 'selected' : ''; ?>>Employed</option>
                                                <option value="Self Employed" <?php echo ($employmentStatus == 'self-employed') ? 'selected' : ''; ?>>Self Employed</option>
                                                <option value="Unemployed" <?php echo ($employmentStatus == 'unemployed') ? 'selected' : ''; ?>>Unemployed</option>
                                            </select>
                                        </div>
                                    </div>



                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Occupation</label>
                                            <input type="text" name="occupation_1" class="form-control" value="<?php echo htmlspecialchars($case_details['occupation-1'] ?? ''); ?>">
                                        </div>
                                    </div>
                                </div>

                            </div>
                            <!-- Applicant 2 Form -->
                            <div class="col-md-6">
                                <h4>Applicant 2:</h4>
                                <div class="form-group">
                                    <label>Title</label>
                                    <select name="ttle2" class="form-control">
                                        <option value="#" <?php echo ($case_details['title-2']  == 'Select one...') ? 'selected' : ''; ?>>Select one...</option>
                                        <option value="Mr" <?php echo ($case_details['title-2']  == 'Mr') ? 'selected' : ''; ?>>Mr</option>
                                        <option value="Mrs" <?php echo ($case_details['title-2']  == 'Mrs') ? 'selected' : ''; ?>>Mrs</option>
                                        <option value="Miss" <?php echo ($case_details['title-2']  == 'Miss') ? 'selected' : ''; ?>>Miss</option>
                                        <option value="Ms" <?php echo ($case_details['title-2']  == 'Ms') ? 'selected' : ''; ?>>Ms</option>
                                    </select>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>First Name</label>
                                            <input type="text" name="frstNme2" class="form-control" value="<?php echo htmlspecialchars($case_details['forename-2'] ?? ''); ?>">
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Surname</label>
                                            <input type="text" name="srNme2" class="form-control" value="<?php echo htmlspecialchars($case_details['surname-2'] ?? ''); ?>">
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Date Of Birth</label>
                                            <?php
                                            // Assuming $case_details['dteOfBrth2'] is in the format 'Y-m-d H:i:s'
                                            $originalDate2 = $case_details['dteOfBrth-2'] ?? '';

                                            // Check if the date is not empty
                                            if (!empty($originalDate2)) {
                                                // Create a new DateTime object from the original date
                                                $dateObject2 = new DateTime($originalDate2);

                                                // Format the date to 'Y-m-d' for the input element
                                                $formattedDate2 = $dateObject2->format('Y-m-d');
                                            } else {
                                                // Set to an empty string if the original date is empty
                                                $formattedDate2 = '';
                                            }
                                            ?>

                                            <input type="date" name="dteOfBrth2" class="form-control" value="<?php echo htmlspecialchars($formattedDate2); ?>">

                                        </div>
                                    </div>

                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Email Address</label>
                                            <input type="email" name="emlAddrss2" class="form-control" value="<?php echo htmlspecialchars($case_details['emlAddrss-2'] ?? ''); ?>">
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Mobile Number</label>
                                            <input type="number" name="mblePhone2" class="form-control" value="<?php echo htmlspecialchars($case_details['mblePhone-2'] ?? ''); ?>">
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Home Telephone Number</label>
                                            <input type="number" name="HmePhone2" class="form-control" value="<?php echo htmlspecialchars($case_details['HmePhone-2'] ?? ''); ?>">
                                        </div>
                                    </div>
                                </div>
                                <?php
                                // Assuming you have the value stored in $case_details['employment_2']
                                $employmentStatus = strtolower($case_details['employment-2'] ?? '');
                                ?>

                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Employment Status</label>
                                            <select name="employment_2" class="form-control">
                                                <option value="" <?php echo ($employmentStatus == '') ? 'selected' : ''; ?>>Select one...</option>
                                                <option value="Employed" <?php echo ($employmentStatus == 'employed') ? 'selected' : ''; ?>>Employed</option>
                                                <option value="Self Employed" <?php echo ($employmentStatus == 'self-employed') ? 'selected' : ''; ?>>Self Employed</option>
                                                <option value="Unemployed" <?php echo ($employmentStatus == 'unemployed') ? 'selected' : ''; ?>>Unemployed</option>
                                            </select>
                                        </div>
                                    </div>


                                    <div class="col-md-6">
                                        <div class="form-group">
                                            <label>Occupation</label>
                                            <input type="text" name="occupation_2" class="form-control" value="<?php echo htmlspecialchars($case_details['occupation-2'] ?? ''); ?>">
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <br>
                        </div>
                        <!-- Other Section -->
                        <div class="row mb-4">
                            <!-- First Column -->
                            <?php
                            // Assuming you have the marital status stored in $case_details['mrtlStts']
                            $maritalStatus = $case_details['mrtlStts'] ?? '';
                            ?>

                            <div class="col-md-4">
                                <h4>Other:</h4>
                                <div class="form-group">
                                    <label>Marital Status</label>
                                    <select name="marital_status" class="form-control">
                                        <option value="" <?php echo ($maritalStatus == '') ? 'selected' : ''; ?>>Select one...</option>
                                        <option value="1" <?php echo ($maritalStatus == '1') ? 'selected' : ''; ?>>Single</option>
                                        <option value="2" <?php echo ($maritalStatus == '2') ? 'selected' : ''; ?>>Married</option>
                                        <option value="3" <?php echo ($maritalStatus == '3') ? 'selected' : ''; ?>>Living Together</option>
                                        <option value="4" <?php echo ($maritalStatus == '4') ? 'selected' : ''; ?>>Living Apart</option>
                                        <option value="5" <?php echo ($maritalStatus == '5') ? 'selected' : ''; ?>>Divorced</option>
                                        <option value="6" <?php echo ($maritalStatus == '6') ? 'selected' : ''; ?>>Widow</option>
                                        <!-- If you need to add the "Unknown" option -->
                                        <option value="99" <?php echo ($maritalStatus == '99') ? 'selected' : ''; ?>>Unknown</option>
                                    </select>
                                </div>
                            </div>


                            <!-- Second Column -->
                            <?php
                            // Assuming the applicant's awareness is stored in $case_details['applcntDsNtKnw']
                            $applicantAwareness = isset($case_details['applcntDsNtKnw']) ? (int)$case_details['applcntDsNtKnw'] : '';

                            // Define the option values as integers
                            $optionYesValue = 0;
                            $optionNoValue = 1;
                            ?>

                            <div class="col-md-4">
                                <h4>-</h4>
                                <div class="form-group">
                                    <label>Partner Aware?</label>
                                    <select name="partner_aware" class="form-control">
                                        <option value="" <?php echo ($applicantAwareness === '') ? 'selected' : ''; ?>>Select one</option>
                                        <option value="<?php echo $optionYesValue; ?>" <?php echo ($applicantAwareness === $optionYesValue) ? 'selected' : ''; ?>>Yes</option>
                                        <option value="<?php echo $optionNoValue; ?>" <?php echo ($applicantAwareness === $optionNoValue) ? 'selected' : ''; ?>>No</option>
                                    </select>
                                </div>
                            </div>

                            <?php
                            // Assuming you have the marital status stored in $case_details['mrtlStts']
                            $property = $case_details['Property_Status'] ?? '';
                            ?>


                            <div class="col-md-4">
                                <h4>-</h4>
                                <div class="form-group">
                                    <label>Property Status?</label>
                                    <select name="property" class="form-control">
                                        <option value="" <?php echo ($property == '') ? 'selected' : ''; ?>>Select one...</option>
                                        <option value="1" <?php echo ($property == '1') ? 'selected' : ''; ?>>Council/ Housing Association Tennant</option>
                                        <option value="2" <?php echo ($property == '2') ? 'selected' : ''; ?>>Private Tennant</option>
                                        <option value="3" <?php echo ($property == '3') ? 'selected' : ''; ?>>Mortgage</option>
                                        <option value="4" <?php echo ($property == '4') ? 'selected' : ''; ?>>Living with Parents</option>
                                        <option value="5" <?php echo ($property == '5') ? 'selected' : ''; ?>>Other</option>
                                        <!-- If you need to add the "Unknown" option -->
                                        <option value="99" <?php echo ($property == '99') ? 'selected' : ''; ?>>Unknown</option>
                                    </select>
                                </div>
                            </div>

                        </div>


                        <!-- New Row for Three More Boxes -->
                        <div class="row mb-4">

                            <!-- Third Column -->
                            <div class="col-md-4">
                                <div class="form-group">
                                    <label>Number of Dependants</label>
                                    <input type="number" name="nmbrDpndnts" class="form-control" value="<?php echo htmlspecialchars($case_details['nmbrDpndnts'] ?? ''); ?>">
                                </div>
                            </div>

                            <!-- Fourth Column -->
                            <div class="col-md-4">
                                <div class="form-group">
                                    <label>Number of Adult Dependants</label>
                                    <input type="number" name="nmbrAdltDpndnts" class="form-control" value="<?php echo htmlspecialchars($case_details['nmbrAdltDpndnts'] ?? ''); ?>">
                                </div>
                            </div>

                            <!-- Fifth Column -->
                            <div class="col-md-4">
                                <div class="form-group">
                                    <label>Age(s) of Dependants</label>
                                    <input type="text" name="ageDpndnts" class="form-control" value="<?php echo htmlspecialchars($case_details['ageDpndnts'] ?? ''); ?>">
                                    <input type="hidden" id="id" name="id" value="<?php echo $case_details['id'] ?? ''; ?>">
                                </div>
                            </div>

                        </div>
                        <button type="submit" class="btn btn-success">Save Base Details</button>
                    </form>
                    <!-- End of Base Applicant Form -->
                    <br>

                    <div id="alert_placeholder"></div>
                </div>
            </div>
        </div>
    </div>

    <script>
        $(document).ready(function() {
            // When the form is submitted
            $('#baseApplicantForm').on('submit', function(e) {
                e.preventDefault();

                // Serialize the form data into a URL-encoded string
                var formData = $(this).serialize();

                // Send the form data to your server using AJAX
                $.ajax({
                    url: 'Updates/Update_Base_Applicants.php',
                    type: 'POST',
                    data: formData,
                    dataType: 'json', // Specify that you expect a JSON response
                    success: function(response) {
                        if (response.success === true) {
                            // If the response has "success" set to true, show the success alert
                            $('#alert_placeholder').html('<div class="alert alert-success" role="alert">' + response.message + '</div>');
                        } else {
                            // If the response has "success" set to false or any other value, show the warning alert
                            $('#alert_placeholder').html('<div class="alert alert-warning" role="alert">' + response.message + '</div>');
                        }
                    },
                    error: function(xhr, status, error) {
                        // If the AJAX request fails, show the warning alert
                        $('#alert_placeholder').html('<div class="alert alert-warning" role="alert">Error Updating Base Details</div>');
                    }
                });
            });
        });
    </script>
</body>

</html>