<?php
session_start();

// If session variable 'username' is not set or is 'Guest', redirect to login page
if (!isset($_SESSION['username']) || $_SESSION['username'] === "Guest") {
    header("Location: /login.php");
    exit();
}

// Check if the session is inactive for more than 10 seconds
if (isset($_SESSION['last_activity']) && (time() - $_SESSION['last_activity'] > 900)) {
    // Session has been inactive for more than 10 seconds
    session_unset();     // Unset $_SESSION variable for the run-time
    session_destroy();   // Destroy the session data on the server
    header("Location: /login.php"); // Redirect to login page
    exit(); // Ensure no further execution of the script
}

// Update last activity time stamp
$_SESSION['last_activity'] = time();

$username = $_SESSION['username']; // Username is already checked above and is not 'Guest'

// Check if 'client_id' is in the URL query parameter
if (isset($_GET['client_id'])) {
    // Store the 'client_id' from the URL in a variable
    $id = $_GET['client_id'];
} else {
    // Set a default value or handle the case where 'client_id' is not provided in the URL
    $id = 'default_value';
}
$username = isset($_SESSION['username']) ? $_SESSION['username'] : "Guest";
include_once '../config_current.php';

/// Get Username
$query = "SELECT nme, job_title FROM account_users WHERE email = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param('s', $username);
$stmt->execute();

$result = $stmt->get_result();
$row = $result->fetch_assoc();

if ($row) {
    $truename = $row['nme'];
    $jobtitle = $row['job_title'];
} else {
    $truename = "Unknown";
}

$stmt->close();

// Suppose 'case_details' is your table name and it contains relevant information about the case
$case_query = "SELECT * FROM client_core WHERE id = ?";
$case_stmt = $conn->prepare($case_query);
$case_stmt->bind_param('i', $id); // assuming client_id is an integer field
$case_stmt->execute();

$case_result = $case_stmt->get_result();
$case_details = $case_result->fetch_assoc(); // fetches the row as an associative array

// print_r($case_details); exit;

$case_stmt->close();

// Suppose 'case_details' is your table name and it contains relevant information about the case
$case_query = "SELECT * FROM client_core WHERE id = ?"; 
$case_stmt = $conn->prepare($case_query);
$case_stmt->bind_param('i', $id); // assuming client_id is an integer field
$case_stmt->execute();

$case_result = $case_stmt->get_result();
$case_details = $case_result->fetch_assoc(); // fetches the row as an associative array

$case_stmt->close();


?>
<!DOCTYPE html>
<html>
<head>
    <title>Bank & Card | Case <?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?></title>
    <?php include 'layouts/head.php'; ?>
    <?php include 'layouts/head-style.php'; ?>
</head>
<body>
    <style>
        /* Add this in your <head> within <style> tags or in an external CSS file */

        .credit-card {
            font-family: 'Helvetica Neue', Helvetica, sans-serif;
            width: 350px;
            height: 200px;
            background-color: #2a2a2e;
            border-radius: 8px;
            color: white;
            padding: 20px;
            box-sizing: border-box;
            margin: 20px 0;
        }

        .credit-card__logo {
            position: absolute;
            top: 20px;
            right: 20px;
            font-size: 24px;
            font-weight: bold;
        }

        .credit-card__number {
            margin-top: 50px;
            font-size: 20px;
            letter-spacing: 2px;
        }

        .credit-card__info {
            margin-top: 25px;
            display: flex;
            justify-content: space-between;
        }

        .credit-card__info_name,
        .credit-card__info_expiry {
            font-size: 16px;
        }

        .credit-card__info_label {
            font-size: 10px;
            color: #8c8c8c;
            text-transform: uppercase;
            letter-spacing: 1px;
        }

        .credit-card__number-and-logo {
            display: flex;
            align-items: center;
            justify-content: space-between;
        }

        .credit-card__small-logo {
            height: 30px; /* or the size that fits your design */
            width: auto;
            margin-left: 10px; /* Adjust the margin as needed */
        }

    </style>
    <?php include 'layouts/body.php'; ?>

    <div id="layout-wrapper">
        <?php include 'layouts/vertical-menu.php'; ?>
        <div class="main-content">
            <div class="page-content">
                <div class="container-fluid">
                    <!-- Bank Details Section -->
                    <div class="card">
                        <div class="card-body">
                            <h4 class="card-title">Bank Details:</h4>
                            <form id="bank-details-form" method="post">
                                <div class="mb-3 row">
                                    <label for="bnk" class="col-md-2 col-form-label">Bank Name:</label>
                                    <div class="col-md-10">
                                        <input type="text" name="bnk" class="form-control" value="<?php echo htmlspecialchars($case_details['bnk'] ?? ''); ?>">
                                    </div>
                                </div>
                                <div class="mb-3 row">
                                    <label for="bnkAccntNme" class="col-md-2 col-form-label">Account Name:</label>
                                    <div class="col-md-10">
                                        <input type="text" name="bnkAccntNme" class="form-control" value="<?php echo htmlspecialchars($case_details['bnkAccntNme'] ?? ''); ?>">
                                    </div>
                                </div>
                                <div class="mb-3 row">
                                    <label for="bnkAccntNmbr" class="col-md-2 col-form-label">Account Number:</label>
                                    <div class="col-md-6">
                                        <input type="text" name="bnkAccntNmbr" class="form-control" value="<?php echo htmlspecialchars($case_details['bnkAccntNmbr'] ?? ''); ?>">
                                    </div>
                                    <label for="sortCode" class="col-md-2 col-form-label">Sort Code:</label>
                                    <div class="col-md-2">
                                        <input type="text" name="bnkSrtCde" class="form-control" value="<?php echo htmlspecialchars($case_details['bnkSrtCde'] ?? ''); ?>">
                                    </div>
                                </div>
                                <div class="mb-3 row">
                                    <label for="bankAddress" class="col-md-2 col-form-label">Bank's Address:</label>
                                    <div class="col-md-10">
                                        <textarea name="bnkAddrss" rows="4" class="form-control" id="bankAddress"><?php echo htmlspecialchars($case_details['bnkAddrss'] ?? ''); ?></textarea>
                                    </div>
                                </div>

                                <div class="mb-3 row">
                                    <div class="col-md-10 offset-md-2">
                                        <button type="submit" class="btn btn-success" id="search-bank-details">Find Bank Details</button>
                                        <button type="button" class="btn btn-primary" id="save-bank-details">Save Bank Details</button>
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Include jQuery -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

    <!-- Include Bootstrap JavaScript -->
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>

    <script>
        $(document).ready(function () {
            $("#search-bank-details").click(function (event) {
                event.preventDefault();

                console.log("Form submitted"); // Debugging statement

                var sortCode = $('input[name="bnkSrtCde"]').val();

                $.ajax({
                    url: 'https://sortcodes.clientmaster.uk/api/bankdata.php',
                    type: 'POST',
                    headers: {
                        'Authorization': 'Token 5cfec6e21930a50008279dfa-lPWOBslkG7xNqZId_QGqK',  // Using Bearer Token Authorization
                    },
                    data: { sort: sortCode },
                    success: function(data) {
                        console.log("AJAX success"); // Debugging statement
                        console.log(data);

                        try {
                            if (data.status === 'success') {
                                $('#alert-placeholder').html('<div class="alert alert-success" role="alert">A simple success alert—check it out!</div>');

                                // Access the nested data within the 'response' object
                                $('input[name="bnk"]').val(data.response.bank);
                                $('textarea[name="bnkAddrss"]').val(data.response['full-address']);
                            } else {
                                $('#alert-placeholder').html('<div class="alert alert-danger" role="alert">A simple danger alert—check it out!</div>');
                            }
                        } catch (error) {
                            console.error("Error parsing JSON: " + error);
                            // Handle the error, e.g., display an error message to the user
                        }
                    },
                    error: function(xhr, status, error) {
                        console.log("AJAX error"); // Debugging statement
                        console.log(error);

                        $('#alert-placeholder').html('<div class="alert alert-danger" role="alert">An error occurred. Please try again later.</div>');
                    }
                });
            });
        });

$("#save-bank-details").click(function (event) {
    event.preventDefault();

    // Serialize the form data into a JSON object
    var formData = $("#bank-details-form").serializeArray();
    var formDataObject = {};
    $.each(formData, function (i, field) {
        formDataObject[field.name] = field.value;
    });

    // Add the id to the formDataObject
    formDataObject.id = <?php echo $id; ?>;

    // Send an AJAX POST request to update the bank details
    $.ajax({
        url: "/client/Updates/update_bank_details.php", // Replace with the URL where you handle the bank data update
        type: "POST",
        data: formDataObject,
        success: function (response) {
            // Handle the response (e.g., show a success message)
            alert("Bank details saved successfully!");
        },
        error: function (xhr, textStatus, errorThrown) {
            // Handle the error (e.g., show an error message)
            alert("Error: " + errorThrown);
        }
    });
});

    </script>
</body>
</html>
