<?php
session_start();

// If session variable 'username' is not set or is 'Guest', redirect to login page
if (!isset($_SESSION['username']) || $_SESSION['username'] === "Guest") {
    header("Location: /login.php");
    exit();
}

// Check if the session is inactive for more than 10 seconds
if (isset($_SESSION['last_activity']) && (time() - $_SESSION['last_activity'] > 900)) {
    // Session has been inactive for more than 10 seconds
    session_unset();     // Unset $_SESSION variable for the run-time
    session_destroy();   // Destroy the session data on the server
    header("Location: /login.php"); // Redirect to login page
    exit(); // Ensure no further execution of the script
}

// Update last activity time stamp
$_SESSION['last_activity'] = time();

$username = $_SESSION['username']; // Username is already checked above and is not 'Guest'

// Check if 'client_id' is in the URL query parameter
if (isset($_GET['client_id'])) {
    // Store the 'client_id' from the URL in a variable
    $id = $_GET['client_id'];
} else {
    // Set a default value or handle the case where 'client_id' is not provided in the URL
    $id = 'default_value';
}
$username = isset($_SESSION['username']) ? $_SESSION['username'] : "Guest";
include_once '../config_current.php';

/// Get Username
$query = "SELECT nme, job_title FROM account_users WHERE email = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param('s', $username);
$stmt->execute();

$result = $stmt->get_result();
$row = $result->fetch_assoc();

if ($row) {
    $truename = $row['nme'];
    $jobtitle = $row['job_title'];
} else {
    $truename = "Unknown";
}

$stmt->close();

// Suppose 'case_details' is your table name and it contains relevant information about the case
$case_query = "SELECT * FROM client_core WHERE id = ?";
$case_stmt = $conn->prepare($case_query);
$case_stmt->bind_param('i', $id); // assuming client_id is an integer field
$case_stmt->execute();
$case_result = $case_stmt->get_result();
$case_details = $case_result->fetch_assoc(); // fetches the row as an associative array
$case_stmt->close();
?>


<!-- HTML and PHP code to display the table -->
<!DOCTYPE html>
<html>
<head>
    <!-- [Bootstrap, jQuery, Popper, Bootstrap JS, and other includes] -->
    <title>Emails | Case <?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?></title>
    <?php include 'layouts/head.php'; ?>
    <?php include 'layouts/head-style.php'; ?>
</head>
<body>
    <?php include 'layouts/body.php'; ?>

    <div id="layout-wrapper">
        <?php include 'layouts/vertical-menu.php'; ?>
        <div class="main-content">
            <div class="page-content">
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-12">
                            <!-- Left sidebar -->
                            <div class="email-leftbar card">
                                <button type="button" class="btn btn-danger btn-block waves-effect waves-light" id="composeButton">
                                    Compose
                                </button>

                            </div>
                            <!-- End Left sidebar -->

                            <!-- Modal -->
                            <div class="modal fade" id="composeModal" tabindex="-1" role="dialog" aria-labelledby="composeModalTitle" aria-hidden="true">
                                <!-- ... Compose email modal content ... -->
                                <div class="modal-dialog modal-dialog-centered" role="document">
                                    <div class="modal-content">
                                        <div class="modal-header">
                                            <h5 class="modal-title" id="composeModalTitle">Compose Email</h5>
                                            <button type="button" class="btn-close" data-dismiss="modal" aria-label="Close"></button>
                                        </div>
                                        <div class="modal-body">
                                            <form id="composeForm">
                                                <div class="mb-3">
                                                    <label for="emailSubject" class="form-label">Subject:</label>
                                                    <input type="text" class="form-control" id="emailSubject" name="emailSubject" required>
                                                </div>
                                                <div class="mb-3">
                                                    <label for="emailBody" class="form-label">Body:</label>
                                                    <textarea class="form-control" id="emailBody" name="emailBody" rows="4" required></textarea>
                                                </div>
                                            </form>
                                        </div>
                                        <div class="modal-footer">
                                            <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
                                            <button type="button" class="btn btn-success" id="sendEmail">Send</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <!-- End Modal -->

                            <!-- Right Sidebar -->
                            
                                
                                <!-- Right Sidebar -->
<div class="card">
    <ul class="message-list">
        <!--<?php foreach ($emails as $email): ?>-->
            <li data-toggle="modal" data-target="#emailModal_" class="email-item" data-email-id="<?php echo $email['id']; ?>">
                <!-- Your email formatting here -->
                <div class="col-mail col-mail-1">
                    <!-- Display sender name -->
                    <a href="#" class="title"><?php echo $email['sender_name']; ?></a>
                </div>
                <div class="col-mail col-mail-2">
                    <!-- Display email subject -->
                    <a href="#" class="subject"><?php echo $email['email_subject']; ?></a>
                    <div class="date"><?php echo date('M j, Y', strtotime($email['email_datetime'])); ?></div>
                </div>
            </li>

            <!-- Modal for displaying email content -->
            <div class="modal fade" id="emailModal_<?php echo $email['id']; ?>" tabindex="-1" role="dialog" aria-labelledby="emailModalTitle_<?php echo $email['id']; ?>" aria-hidden="true">
                <div class="modal-dialog modal-dialog-centered modal-lg">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="emailModalTitle_<?php echo $email['id']; ?>">Email Content</h5>
                            <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                <span aria-hidden="true">&times;</span>
                            </button>
                        </div>
                        <div class="modal-body">
                            <!-- Email content will be loaded here dynamically -->
                            <div id="emailModalContent_<?php echo $email['id']; ?>"></div>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
                             <button type="button" class="btn btn-warning" id="markReadButton_<?php echo $email['id']; ?>">Marked as Read</button>

                        </div>
                    </div>
                </div>
            </div>
        <?php endforeach; ?>
    </ul>
</div>
<!-- End Right Sidebar -->

                        </div>
                    </div> <!-- container-fluid -->
                </div>
                <!-- End Page-content -->

                <!-- Modal -->
                <div class="modal fade" id="composemodal" tabindex="-1" role="dialog" aria-labelledby="composemodalTitle" aria-hidden="true">
                    <!-- ... Compose email modal content ... -->
                </div>
                <!-- end modal -->
            </div>
        </div>
    </div>


    <!-- jQuery library -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

    <!-- Popper.js -->
    <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.16.0/umd/popper.min.js"></script>

    <!-- Bootstrap JavaScript -->
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>

    <!-- JavaScript code to load email content on demand -->
    <script>
    $(document).ready(function() {
        
        document.getElementById('emailBody').addEventListener('input', function () {
            
            this.value = this.value.replace(/\n/g, '\n');
            
        });
        
        $(".email-item").click(function() {
            var emailId = $(this).data("email-id");

            // AJAX request to fetch email_html content
            $.ajax({
                type: "GET",
                url: "/client/Get/get_email_html.php",
                data: { id: emailId },
                success: function(response) {
                    // Inject email content into modal
                    $("#emailModalContent_" + emailId).html(response);

                    // Update timer if it exists
                    updateTimer(emailId);

                    // Show the modal
                    $("#emailModal_" + emailId).modal("show");
                },
                error: function(error) {
                    console.error(error);
                }
            });
        });
    });

    // Function to update timer in modal
    function updateTimer(emailId) {
        var countdown = 10; // Example countdown value

        var intervalId = setInterval(function() {
            var timerElement = document.getElementById("timer_" + emailId);
            if (timerElement) {
                timerElement.textContent = countdown; // Update timer text
                countdown--; // Decrease countdown value
            } else {
                clearInterval(intervalId); // Clear interval if timer element not found
            }
        }, 1000); // Update timer every second
    }
</script>

    <script>
    $(document).ready(function() {
        // Handle the click event on the "Compose Email" button
        $("#composeButton").click(function() {
            // Trigger the modal manually
            $("#composeModal").modal("show");
        });
        $("#sendEmail").click(function() {
            console.log("Button Clicked");
            // Get the email subject and body from the form
            var emailSubject = $("#emailSubject").val();
            var emailBody = $("#emailBody").val();
            
            // Additional data to send, like clientId and agentid
            var clientId = <?php echo $id; ?>;
            var agentid = <?php echo $userid; ?>;
            
            // Send the data to the server using AJAX
            $.ajax({
                type: "POST",
                url: "/client/Updates/send_email.php",
                data: {
                    clientId: clientId,
                    emailSubject: emailSubject,
                    emailBody: emailBody,
                    agentid: agentid
                },
                success: function(response) {
                    // Handle the response from the server if needed
                    console.log(response);
                    if(response == 'Email sent and database updated successfully!'){
                        
                        alert('Email Send Successfully!!');
                    } else {
                        
                        alert('Error Sending Email to Client!!!');
                    }
                    
                    // Close the modal
                    $("#composeModal").modal("hide");
                    location.reload();
                },
                error: function(error) {
                    // Handle the error if the AJAX request fails
                    console.error(error);
                }
            });
        });

        <?php foreach ($emails as $email) : ?>
        // Add a click event handler for each "Marked Read" button
        $("#markReadButton_<?php echo $email['id']; ?>").click(function () {
            var emailId = <?php echo $email['id']; ?>;

            // Make an AJAX POST request to update the database
            $.ajax({
                type: "POST",
                url: "/client/Updates/Update_Email_Status.php", // Replace with the actual PHP script URL
                data: { id: emailId },
                success: function (response) {
                    if (response === "success") {
                        // Close the modal when the update is successful
                        $("#emailModal_<?php echo $email['id']; ?>").modal("hide");

                        // Reload the page after successful update
                        location.reload();
                    } else {
                        // Handle the error scenario here
                        alert("Error marking email as read.");
                    }
                },
                error: function () {
                    // Handle AJAX error here
                    alert("Error marking email as read.");
                }
            });
        });
        <?php endforeach; ?>
    });
</script>

</body>
</html>

