<?php
session_start();

// If session variable 'username' is not set or is 'Guest', redirect to login page
if (!isset($_SESSION['username']) || $_SESSION['username'] === "Guest") {
    header("Location: /login.php");
    exit();
}

// Check if the session is inactive for more than 10 seconds 
if (isset($_SESSION['last_activity']) && (time() - $_SESSION['last_activity'] > 900)) {
    // Session has been inactive for more than 10 seconds
    session_unset();     // Unset $_SESSION variable for the run-time
    session_destroy();   // Destroy the session data on the server
    header("Location: /login.php"); // Redirect to login page
    exit(); // Ensure no further execution of the script
}

// Update last activity time stamp
$_SESSION['last_activity'] = time();

$username = $_SESSION['username']; // Username is already checked above and is not 'Guest'

// Check if 'client_id' is in the URL query parameter
if (isset($_GET['client_id'])) {
    // Store the 'client_id' from the URL in a variable
    $id = $_GET['client_id'];
} else {
    // Set a default value or handle the case where 'client_id' is not provided in the URL
    $id = 'default_value';
}
$username = isset($_SESSION['username']) ? $_SESSION['username'] : "Guest";
include_once '../config_current.php';

/// Get Username
$query = "SELECT nme, job_title FROM account_users WHERE email = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param('s', $username);
$stmt->execute();

$result = $stmt->get_result();
$row = $result->fetch_assoc();

if ($row) {
    $truename = $row['nme'];
    $jobtitle = $row['job_title'];
} else {
    $truename = "Unknown";
}

$stmt->close();

// Suppose 'case_details' is your table name and it contains relevant information about the case
$case_query = "SELECT * FROM client_core WHERE id = ?";
$case_stmt = $conn->prepare($case_query);
$case_stmt->bind_param('i', $id); // assuming client_id is an integer field
$case_stmt->execute();
$case_result = $case_stmt->get_result();
$case_details = $case_result->fetch_assoc(); // fetches the row as an associative array
$case_stmt->close();

//Correspondence List
$corss_query = "
    SELECT
        cc.id,
        cc.type,
        cc.description,
        cred.`creditor-name` AS credtior,
        cc.drctn,
        created.nme AS `By`,
        cc.`created-when` AS `When`,
        cc.`document-id`,
        Document.id AS did,
        Document.filename,
        Document.`file-template` AS template,
        Document.printed AS file_printed,
        Document.error AS file_error,
        Document.`sign-fingerprint`,
        Document.`sign-status`,
        SMS.`message-id`,
        SMS.id AS sid,
        SMS.`sms-to`,
        SMS.`sms-from`,
        SMS.`sms-body`,
        SMS.`sms-status`,
        EMAILS.id AS eid,
        EMAILS.`sent-to` AS `to`,
        EMAILS.`from-by-name`,
        EMAILS.`from-by-email`,
        EMAILS.subject,
        EMAILS.`body-plain` AS Email_message
    FROM client_correspondence AS cc
    LEFT JOIN account_users AS created 
        ON cc.`created-by` = created.id
    LEFT JOIN account_users AS Updated
        ON cc.`updated-by` = Updated.id
    LEFT JOIN client_sms AS SMS
        ON cc.`sms-id` = SMS.id
    LEFT JOIN client_emails AS EMAILS
        ON cc.`email-id` = EMAILS.id
    LEFT JOIN client_creditors AS cred 
        ON cc.credtior_id = cred.id
    LEFT JOIN client_documents AS Document 
        ON cc.`document-id` = Document.id
    WHERE cc.cid = ?
    ORDER BY cc.`created-when` DESC
";

$correspondence_stmt = $conn->prepare($corss_query);
if (!$correspondence_stmt) {
    die("Error preparing statement: " . $conn->error);
}
$correspondence_stmt->bind_param("i", $id);
$correspondence_stmt->execute();
$correspondence_result = $correspondence_stmt->get_result();
$correspondence_stmt->close();



?>


<!DOCTYPE html>
<html>

<head>
    <title>Address | Case <?php echo $case_details['id']; ?></title>
    <?php include 'layouts/head.php'; ?>
    <?php include 'layouts/head-style.php'; ?>
</head>

<body>
    <?php include 'layouts/body.php'; ?>

    <div id="layout-wrapper">
        <?php include 'layouts/vertical-menu.php'; ?>
        <div class="main-content">
            <div class="page-content">
                <div class="container-fluid">
                    <div class="table-responsive" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                        <div style="display: flex; align-items: center; justify-content: flex-start; margin-bottom:15px;">
                        <!-- Button to fetch information -->
                        <button id="fetch-info-button" type="button" class="btn btn-dark waves-effect">
                                                <i class="bx bx-hourglass bx-spin font-size-16 align-middle me-2"></i> Fetch Local Info
                                            </button>

                        <!-- Speech bubble container -->
                        <div id="speech-bubble"></div>
                        <script>
                        function fetchClientInfo() {
                            console.log("fetchClientInfo function called"); // Verify function is called

                            fetch('Conversation_Points.php?id=<?php echo $id; ?>') // Ensure PHP variable $id is defined
                                .then(response => {
                                    console.log("Fetch response received"); // Verify response is received
                                    return response.text();
                                })
                                .then(data => {
                                    console.log("Data received:", data); // Check the response content
                                    const speechBubble = document.getElementById('speech-bubble');

                                    if (speechBubble) {
                                        // Set the inner HTML, including a close button
                                        speechBubble.innerHTML = `<button id="close-btn" style="position: absolute; top: 5px; right: 5px; background: transparent; border: none; font-size: 16px; cursor: pointer;">&times;</button>` + data;

                                        // Apply inline styles to ensure visibility and set up the bubble layout
                                        speechBubble.style.display = 'block';
                                        speechBubble.style.position = 'fixed';  
                                        speechBubble.style.bottom = '50px';
                                        speechBubble.style.right = '50px';
                                        speechBubble.style.backgroundColor = '#f1f1f1';
                                        speechBubble.style.borderRadius = '10px';
                                        speechBubble.style.padding = '15px';
                                        speechBubble.style.maxWidth = '300px';
                                        speechBubble.style.maxHeight = '2000px';  // Limit height to avoid overflowing viewport
                                        speechBubble.style.overflowY = 'auto';  // Enable vertical scrolling if content exceeds maxHeight
                                        speechBubble.style.boxShadow = '0 4px 8px rgba(0, 0, 0, 0.2)';
                                        speechBubble.style.zIndex = '9999';  // Bring to the front

                                        // Attach the close function to the close button
                                        document.getElementById('close-btn').onclick = closeSpeechBubble;

                                        console.log("Speech bubble displayed with inline styles.");
                                    }

                                    // Function to close the speech bubble
                                    function closeSpeechBubble() {
                                        speechBubble.style.display = 'none';
                                        console.log("Speech bubble closed.");
                                    }

                                })
                                .catch(error => {
                                    console.error('Error fetching conversation points:', error);
                                    const speechBubble = document.getElementById('speech-bubble');
                                    if (speechBubble) {
                                        speechBubble.innerHTML = '<p>Failed to load information.</p>';
                                        speechBubble.style.display = 'block';
                                    }
                                });
                        }

                        // Attach the function to the button's onclick event
                        document.getElementById("fetch-info-button").onclick = fetchClientInfo;


                    </script>


                        <input type="text" class="form-control" id="searchInput" placeholder="Search for notes.." title="Type in a keyword" style="width: 20%; margin-right: 10px;">


                        <!--
                        <button type="button" id="generateInfoPackButton" class="btn btn-primary waves-effect waves-light" style="font-family: 'Poppins', sans-serif; font-size: 13px;" data-toggle="modal" data-target="#generateInfoPackDocument">
                            Generate Info Pack
                        </button>
                        -->
                        <!--<a href="https://cml-v3.co.uk/client/generateWordDocument?id=<?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?>" class="btn btn-primary waves-effect waves-light" style="font-family: 'Poppins', sans-serif; font-size: 13px;">Generate Information Pack</a>
                        </a>-->

                        <div style="flex-grow: 1;"></div>
                        
                            <!-- Create a Note -->
                            <form action="https://cmlapi.co.uk/System/SelectCallType.php?id=<?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?>&agentid=<?php echo htmlspecialchars($agentid); ?>" method="post" target="_blank">
                                <button type="submit" class="btn btn-success waves-effect waves-light" style="font-family: 'Poppins', sans-serif; font-size: 13px;">Create a Call Note</button>
                            </form>
                             <!-- Button to open the Note modal -->
                            <button type="button" class="btn btn-primary waves-effect waves-light" style="font-family: 'Poppins', sans-serif; font-size: 13px;" onclick="openNoteModal()">
                                Create a Note
                            </button>


                              <!-- Note Modal (without fade) -->
                            <div class="modal" id="noteModal" tabindex="-1" role="dialog" aria-labelledby="noteModalLabel" aria-hidden="true">
                                <div class="modal-dialog" role="document">
                                    <div class="modal-content">
                                        <div class="modal-header">
                                            <h5 class="modal-title" id="noteModalLabel">Create a Note</h5>
                                            <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                                <span aria-hidden="true">&times;</span>
                                            </button>
                                        </div>
                                        <div class="modal-body">
                                            <form>
                                                <!-- Hidden input fields for $userid and $id -->
                                                <input type="hidden" id="useridInput" value="<?php echo $id; ?>">
                                                <input type="hidden" id="idInput" value="<?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?>">

                                                <!-- Note creation form fields -->
                                                <div class="form-group">
                                                    <label for="noteContent">Note Content:</label>
                                                    <textarea id="noteContent" class="form-control" rows="4"></textarea>
                                                </div>
                                            </form>
                                            
                                            <!-- Speech Bubble for Professional Note Suggestion (Inside Modal) -->
                                            <div id="proNoteBubble" class="speech-bubble" style="display: none;">
                                                <p id="proNoteText"></p>
                                                <button type="button" id="useProNoteButton" class="btn btn-primary">Use Professional Note</button>
                                            </div>
                                        </div>
                                        <div class="modal-footer">
                                            <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
                                            <button type="button" id="saveNoteButton" class="btn btn-success">Save Note</button>
                                            <button type="button" id="generateProNoteButton" class="btn btn-info">Generate Professional Note</button>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <!-- CSS for Speech Bubble -->
                            <style>
                                .speech-bubble {
                                    position: absolute; /* Position inside the modal */
                                    width: 100%;
                                    padding: 15px;
                                    background-color: #f1f1f1;
                                    border-radius: 15px;
                                    box-shadow: 0px 0px 10px rgba(0,0,0,0.1);
                                    z-index: 1050; /* Ensure it's on top of modal elements */
                                    top: -20px; /* Adjust to position above textarea */
                                }
                            </style>

                            <!-- JavaScript to Generate and Display Professional Note -->
                            <script>
                                document.getElementById("generateProNoteButton").addEventListener("click", async function() {
                                    const noteContent = document.getElementById("noteContent").value;

                                    // Call OpenAI API to get a professional version of the note
                                    const response = await fetch("/generateProfessionalNote.php", {
                                        method: "POST",
                                        headers: {
                                            "Content-Type": "application/json"
                                        },
                                        body: JSON.stringify({ text: noteContent })
                                    });

                                    const result = await response.json();
                                    const professionalNote = result.professional_text;

                                    // Display the professional note in the speech bubble, positioned near the textarea
                                    const bubble = document.getElementById("proNoteBubble");
                                    document.getElementById("proNoteText").innerText = professionalNote;
                                    bubble.style.display = "block";
                                });

                                // When the user clicks to use the professional note
                                document.getElementById("useProNoteButton").addEventListener("click", function() {
                                    const professionalNote = document.getElementById("proNoteText").innerText;
                                    document.getElementById("noteContent").value = professionalNote;
                                    document.getElementById("proNoteBubble").style.display = "none"; // Hide the bubble
                                });
                            </script>



                            <!-- Button to open the Creditor Note Modal -->
                            <button type="button" class="btn btn-info waves-effect waves-light" style="font-family: 'Poppins', sans-serif; font-size: 13px;" onclick="openCreditorModal()">
                                Create a Creditor Note
                            </button>

                            <!-- Button to open the Creditor Note Modal -->
                            <button type="button" class="btn btn-warning waves-effect waves-light" style="font-family: 'Poppins', sans-serif; font-size: 13px;" onclick="openDocumentUpload()">
                                Upload Document
                            </button>


                            <!-- Note Modal (without fade) -->
                            <div class="modal" id="CreditorModal" tabindex="-1" role="dialog" aria-labelledby="CreditorModalLabel" aria-hidden="true">
                                <div class="modal-dialog" role="document">
                                    <div class="modal-content">
                                        <div class="modal-header">
                                            <h5 class="modal-title" id="CreditorModalLabel">Create a Creditor Note</h5>
                                            <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                                <span aria-hidden="true">&times;</span>
                                            </button>
                                        </div>
                                        <div class="modal-body">
                                            <form>
                                                <!-- Hidden input fields for $userid and $id -->
                                                <input type="hidden" id="useridInput" value="<?php echo $userid; ?>">
                                                <input type="hidden" id="idInput" value="<?php echo isset($_GET['cid']) ? htmlspecialchars($_GET['cid']) : ''; ?>">

                                                <!-- Add this code inside the modal-body div -->
                                                <div class="form-group">
                                                    <label for="creditorSelect">Select Creditor:</label>
                                                    <select id="creditorSelect" class="form-control">
                                                        <!-- Add option elements for creditors here -->
                                                    </select>
                                                </div>

                                                <!-- Add your Note creation form fields here -->
                                                <div class="form-group">
                                                    <label for="creditornoteContent">Notes:</label>
                                                    <textarea id="creditornoteContent" class="form-control" rows="4"></textarea>
                                                </div>
                                            </form>
                                            <!-- Speech Bubble for Professional Note Suggestion (Inside Modal) -->
                                            <div id="proCredNoteBubble" class="speech-bubble" style="display: none;">
                                                <p id="proCreditorNote"></p>
                                                <button type="button" id="useProCredButton" class="btn btn-primary">Use Professional Note</button>
                                            </div>
                                        </div>
                                        <div class="modal-footer">
                                            <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
                                            <button type="button" id="generateProCreditorNoteButton" class="btn btn-info">Generate Professional Note</button>
                                            <button type="button" id="saveCreditorNoteButton" class="btn btn-success">Save Note</button>

                                        </div>
                                    </div>
                                </div>
                            </div>

                            <!-- CSS for Speech Bubble -->
                            <style>
                                .speech-bubble {
                                    position: absolute; /* Position inside the modal */
                                    width: 100%;
                                    padding: 15px;
                                    background-color: #f1f1f1;
                                    border-radius: 15px;
                                    box-shadow: 0px 0px 10px rgba(0,0,0,0.1);
                                    z-index: 1050; /* Ensure it's on top of modal elements */
                                    top: -20px; /* Adjust to position above textarea */
                                }
                            </style>

                            <!-- JavaScript to Generate and Display Professional Note -->
                            <script>
                                document.getElementById("generateProCreditorNoteButton").addEventListener("click", async function() {
                                    const creditornoteContent = document.getElementById("creditornoteContent").value;

                                    // Call OpenAI API to get a professional version of the note
                                    const response = await fetch("/generateCreditorNote.php", {
                                        method: "POST",
                                        headers: {
                                            "Content-Type": "application/json"
                                        },
                                        body: JSON.stringify({ text: creditornoteContent })
                                    });

                                    const result = await response.json();
                                    const professionalNote = result.professional_text;

                                    // Display the professional note in the speech bubble, positioned near the textarea
                                    const bubble = document.getElementById("proCredNoteBubble");
                                    document.getElementById("proCreditorNote").innerText = professionalNote;
                                    bubble.style.display = "block";
                                });

                                // When the user clicks to use the professional note
                                document.getElementById("useProCredButton").addEventListener("click", function() {
                                    const professionalNote = document.getElementById("proCreditorNote").innerText;
                                    document.getElementById("creditornoteContent").value = professionalNote;
                                    document.getElementById("proCredNoteBubble").style.display = "none"; // Hide the bubble
                                });
                            </script>

                            <script>
                                // Define JavaScript variables and set their values using PHP
                            var userid = <?php echo json_encode($userid); ?>;
                            var id = <?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?>;

                            // Get references to the select element
                            var creditorSelect = document.getElementById("creditorSelect");

                            // Fetch the list of creditors from the database
                            var xhr = new XMLHttpRequest();
                            xhr.open('GET', `/client/Get/GetCredListCorr.php?id=${id}`, true);

                            xhr.onload = function() {
                                if (xhr.status === 200) {
                                    // Parse the JSON response
                                    var creditors = JSON.parse(xhr.responseText);

                                    // Populate the dropdown with creditor options
                                    creditors.forEach(function(creditor) {
                                        var option = document.createElement("option");
                                        option.value = creditor.id; // Use the creditor ID as the value
                                        option.text = creditor.name; // Use the creditor's friendly name as the text
                                        creditorSelect.appendChild(option);
                                    });
                                } else {
                                    // Handle errors or display appropriate messages
                                    alert('Failed to fetch creditors.');
                                }
                            };

                            xhr.onerror = function() {
                                alert('Network error occurred');
                            };

                            xhr.send();
                            </script>

                            <!-- Complaint -->
                            <button type="button" class="btn btn-danger waves-effect waves-light" style="font-family: 'Poppins', sans-serif; font-size: 13px;" onclick="openComplaintModal()">
                                Complaint
                            </button>

                            <!-- Complaint Modal (without fade) -->
                            <div class="modal" id="complaintModal" tabindex="-1" role="dialog" aria-labelledby="complaintModalLabel" aria-hidden="true">
                                <div class="modal-dialog" role="document">
                                    <div class="modal-content">
                                        <div class="modal-header">
                                            <h5 class="modal-title" id="complaintModalLabel">Log a Complaint</h5>
                                            <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                                <span aria-hidden="true">&times;</span>
                                            </button>
                                        </div>
                                        <div class="modal-body">
                                            <form id="complaintForm">
                                                <input type="hidden" id="complaintUserId" name="userId" value="<?php echo $userid; ?>">
                                                <input type="hidden" id="complaintCaseId" name="caseId" value="<?php echo $id; ?>">

                                                <div class="form-group">
                                                    <label for="complaintDetails">Details Of Complaint</label>
                                                    <textarea class="form-control" id="complaintDetails" name="complaintDetails" rows="3"></textarea>
                                                </div>

                                                <div class="form-group">
                                                    <label for="complaintAction">What Action If Any Have You Taken To Resolve The Complaint Before Logging</label>
                                                    <textarea class="form-control" id="complaintAction" name="complaintAction" rows="3"></textarea>
                                                </div>
                                            </form>
                                        </div>
                                        <div class="modal-footer">
                                            <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
                                            <button type="button" class="btn btn-success" onclick="submitComplaintForm()">Submit Complaint</button>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <script>
                            function openComplaintModal() {
                                $('#complaintModal').modal('show');
                            }

                            function submitComplaintForm() {
                                var form = document.getElementById('complaintForm');
                                var formData = new FormData(form);

                                fetch('https://hooks.zapier.com/hooks/catch/13770498/bjtf8b5/', {
                                    method: 'POST',
                                    body: formData
                                })
                                .then(response => response.json())
                                .then(data => {
                                    console.log(data);
                                    alert('Complaint submitted successfully.');
                                    $('#complaintModal').modal('hide');
                                })
                                .catch(error => {
                                    console.error(error);
                                    alert('An error occurred while submitting the complaint.');
                                });
                            }
                            </script>


                            <!-- Document Creation  -->
                                <button type="button" class="btn btn-primary waves-effect waves-light" style="font-family: 'Poppins', sans-serif; font-size: 13px;" data-toggle="modal" data-target="#documentTemplatesModal">
                                    Document
                                </button>
                                
                               <!-- Document Templates Modal (without fade) -->
                            <div class="modal" id="documentTemplatesModal" tabindex="-1" role="dialog" aria-labelledby="documentTemplatesModalLabel" aria-hidden="true">
                                <div class="modal-dialog" role="document">
                                    <div class="modal-content">
                                        <div class="modal-header">
                                            <h5 class="modal-title" id="documentTemplatesModalLabel">Document Templates</h5>
                                            <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                                <span aria-hidden="true">&times;</span>
                                            </button>
                                        </div>
                                        <form action="/client/docsgen/client" method="get">
                                        <div class="modal-body">
                                           
                                            <label for="documentTemplate">Choose a Document Template:</label>
                                            <input type="hidden" value="<?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?>" name="id">
                                            <select id="documentTemplate" name="docid" class="form-control" > <!-- onchange="openDocumentTemplate()" -->
                                                <?php foreach ($documentTemplates as $template) : ?>
                                                    <option value="<?= htmlspecialchars($template['id']) ?>"><?= htmlspecialchars($template['name']) ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </div>
                                        <div class="modal-footer">
                                            <button type="submit" class="btn btn-primary" >Send</button>
                                        </div>
                                        </form>
                                    </div>
                                </div>
                            </div>

                            <!-- SMS Button -->
                            <button class="btn btn-info waves-effect waves-light" onclick="openSmsModal()" style="font-family: 'Poppins', sans-serif; font-size: 13px; margin-left: 10px;">SMS</button>

                            
                            <!-- SMS Modal -->
                            <div class="modal" id="smsModal">
                                <div class="modal-dialog">
                                    <div class="modal-content">
                                        <div class="modal-header">
                                            <h5 class="modal-title">Send SMS</h5>
                                            <button type="button" class="close" data-dismiss="modal">&times;</button>
                                        </div>
                                        <div class="modal-body">
                                            <label for="smsTemplate">Choose a Template:</label>
                                            <select id="smsTemplate" class="form-control" onchange="updateSmsBody()">
                                                <?php foreach ($smsTemplates as $template): ?>
                                                    <option value="<?= htmlspecialchars($template['id']) ?>"><?= htmlspecialchars($template['title']) ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                            <br>
                                            <div id="smsBodyPlaceholder">
                                                <!-- SMS Body will be displayed here -->
                                            </div>
                                        </div>
                                        <div class="modal-footer">
                                            <button type="button" class="btn btn-success" onclick="sendSms()">Send</button>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            
                            <!-- Email -->
                            <button class="btn btn-info waves-effect waves-light" onclick="openEmailModal()" style="font-family: 'Poppins', sans-serif; font-size: 13px; margin-left: 10px;">Email</button>
                            
                           <!-- Email Modal -->
                            <div class="modal" id="emailModal">
                                <div class="modal-dialog">
                                    <div class="modal-content">
                                        <div class="modal-header">
                                            <h5 class="modal-title">Send Email</h5>
                                            <button type="button" class="close" data-dismiss="modal">&times;</button>
                                        </div>
                                        <div class="modal-body">
                                            <label for="emailTemplate">Choose an Email Template:</label>
                                            <select id="emailTemplate" class="form-control" onchange="updateEmailBody()">
                                                <?php foreach ($emailTemplates as $template): ?>
                                                    <option value="<?= htmlspecialchars($template['id']) ?>"><?= htmlspecialchars($template['title']) ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                            <br>
                                            <div id="emailSubject">
                                                <!-- Email Subject will be displayed here -->
                                            </div>
                                            <br>
                                            <div id="emailBodyPlaceholder">
                                                <!-- Email Body will be displayed here -->
                                            </div>
                                            <br>
                                            <div id="emailsendgrid">
                                                <!-- Email Body will be displayed here -->
                                            </div>
                                        </div>
                                        <div class="modal-footer">
                                            <button type="button" class="btn btn-success" onclick="sendEmail()">Send</button>
                                        </div>
                                    </div>
                                </div>
                            </div>


                            <!-- Upload Document Modal -->
                            <div id="openDocumentUpload" class="modal">
                                <div class="modal-dialog">
                                    <div class="modal-content">
                                        <div class="modal-header">
                                            <h5 class="modal-title">Upload Document</h5>
                                            <span class="close" onclick="closeDocumentUploadModal()">&times;</span>
                                        </div>
                                        <div class="modal-body">
                                            <!-- Add an input element to select a file -->
                                            <input type="file" id="fileInput" accept=".jpg, .jpeg, .pdf, .docx">
                                        </div>
                                        <div class="modal-footer">
                                            <button id="saveBtn" class="btn btn-success" onclick="uploadDocument()">Save</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <table class="table mb-0" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                            <thead class="table-light" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                <tr speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                    <th speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">Created</th>
                                    <th speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">Type</th>
                                    <th speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">Direction</th>
                                    <th speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">Description</th>
                                    <th speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">Creditor</th>
                                    <th speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">Created By</th>
                                    <th speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">Actions</th>
                                </tr>
                            </thead>
                            <tbody id="correspondenceTable">
                                <?php foreach ($correspondence_result as $row): ?>
                                    <tr
                                        data-file-path="<?php echo htmlspecialchars($row['file_printed'] ?? ''); ?>"
                                        data-full-description="<?php echo htmlspecialchars($row['description'] ?? ''); ?>"
                                        data-sms-body="<?php echo htmlspecialchars($row['sms-body'] ?? ''); ?>"
                                        data-email-message="<?php echo htmlspecialchars($row['Email_message'] ?? ''); ?>"
                                        data-document-filename="<?php echo htmlspecialchars($row['filename'] ?? ''); ?>"
                                        data-created-by-name="<?php echo htmlspecialchars($row['By'] ?? ''); ?>"
                                        data-creditor-name="<?php echo htmlspecialchars($row['credtior'] ?? ''); ?>">
                                        <td> <?php
                                                if (isset($row['When'])) {
                                                    $date = DateTime::createFromFormat('Y-m-d H:i:s', $row['When']);
                                                    if ($date) {
                                                        echo htmlspecialchars($date->format('d/m/Y h:i A'));
                                                    } else {
                                                        echo 'Invalid Date';
                                                    }
                                                } else {
                                                    echo 'Date Not Set';
                                                }
                                                ?></td>
                                        <td>
                                            <?php
                                            switch ($row['type'] ?? '') {
                                                case 1:
                                                    echo 'Documents';
                                                    break;
                                                case 4:
                                                    echo 'Upload';
                                                    break;
                                                case 5:
                                                    echo 'Note';
                                                    break;
                                                case 6:
                                                    echo 'Tell a Colleague';
                                                    break;
                                                case 7:
                                                    echo 'SMS';
                                                    break;
                                                case 8:
                                                    echo 'Email';
                                                    break;
                                                case 9:
                                                    echo 'Creditor Note';
                                                    break;
                                                default:
                                                    echo htmlspecialchars(strtoupper($row['type'] ?? 'N/A'));
                                            }
                                            ?>
                                        </td>
                                        <td>
                                            <?php
                                            echo ($row['drctn'] ?? '') === 'out'
                                                ? '<i class="bx bx-right-arrow-alt"></i>'
                                                : '<i class="bx bx-left-arrow-alt"></i>';
                                            ?>
                                        </td>
                                        <td data-full-description="<?php echo htmlspecialchars($row['description'] ?? ''); ?>">
                                            <?php
                                            $cleaned_description = strip_tags($row['description'] ?? '');
                                            echo (!empty(trim($cleaned_description)))
                                                ? ((strlen($cleaned_description) > 60) ? substr($cleaned_description, 0, 20) . '...' : $cleaned_description)
                                                : 'N/A';
                                            ?>
                                        </td>
                                        <td data-creditor-name="<?php echo htmlspecialchars($row['creditor'] ?? ''); ?>">
                                            <?php echo htmlspecialchars($row['creditor'] ?? 'N/A'); ?>
                                        </td>
                                        <td data-created-by-name="<?php echo htmlspecialchars($row['By'] ?? ''); ?>">
                                            <?php echo htmlspecialchars($row['By'] ?? 'N/A'); ?>
                                        </td>
                                        <td>
                                            <button class="btn btn-primary openModal" data-id="<?php echo $row['id'] ?? '';  ?>">Open</button>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                        <div class="modal fade" id="detailModal" tabindex="-1" aria-labelledby="detailModalLabel" aria-hidden="true">
                            <div class="modal-dialog modal-lg modal-dialog-centered">
                                <div class="modal-content">
                                    <div class="modal-header">
                                        <h5 class="modal-title" id="detailModalLabel">Case Note</h5>
                                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                            <span aria-hidden="true">&times;</span>
                                        </button>
                                    </div>
                                    <div class="modal-body">
                                        <p><strong>Note Type:</strong> <span id="modal-note-type"></span></p>
                                        <p><strong>Created:</strong> <span id="modal-crtdwhn"></span></p>
                                        <p><strong>Description:</strong> <span id="modal-dscrptn"></span></p>
                                        <p><strong>User:</strong> <span id="modal-created_by_name"></span></p>
                                        <p><strong>Creditor:</strong> <span id="modal-creditor-name"></span></p>

                                        <form method="POST" action="generate_signed_url.php" target="_blank" id="modal-open-document-form">
                                            <input type="hidden" name="filePath" id="modal-file-path">
                                            <button type="submit" class="btn btn-primary">Open Document</button>
                                        </form>
                                        <br>
                                        <br>
                                        <form method="POST" action="./docsgen/edit_docgen.php?id=<?php echo $id;  ?>" target="_blank" id="modal-open-document-form">
                                            <input type="hidden" name="documentTempId" id="documentTempId">
                                            <input type="hidden" name="documentdbtId" id="documentdbtId">
                                            <input type="hidden" name="modal-file-path111" id="modal-file-path111">
                                            <span style="color: red;">*Only regenerate the document if there is no LOA*</span><br>
                                            <button type="submit" class="btn btn-primary">Re-Create Document</button>
                                        </form>

                                        <br>
                                        <form method="POST" action="send_signable.php" target="_blank" id="modal-open-signable-form">
                                            <input type="hidden" name="filePath2" id="modal-file-path2">
                                            <button type="submit" class="btn btn-warning">Send to Signable</button>
                                        </form>
                                        <br>
                                        <form method="POST" action="send_signable_loa.php" target="_blank" id="modal-open-loa-form">
                                            <input type="hidden" name="filePath8" id="modal-file-path8">

                                            <input type="hidden" name="documentdbtId8" id="documentdbtId8">

                                            <button type="submit" class="btn btn-warning">Send LOA Signable</button>
                                        </form>
                                        <br>
                                        <form method="POST" action="send_postal.php" target="_blank" id="modal-open-postal-form">
                                            <input type="hidden" name="filePath3" id="modal-file-path3">
                                            <button type="submit" class="btn btn-info">Send Postal Document</button>
                                        </form>
                                        <br>
                                        <form method="POST" action="View_Uploaded_Mail.php" target="_blank" id="modal-open-upload-image">
                                            <input type="hidden" name="filePath4" id="modal-file-path4">
                                            <button type="submit" class="btn btn-warning">View Uploaded Document</button>
                                        </form>
                                        <br>
                                        <br>
                                        <form method="POST" action="send_woodlands_signable.php" target="_blank" id="modal-open-signable-ccr">
                                            <input type="hidden" name="documentdbtId6" id="documentdbtId6">
                                            <input type="hidden" name="filePath6" id="modal-file-path6">
                                            <button type="submit" class="btn btn-warning">Send Woodlands Signable</button>
                                        </form>
                                        <br>
                                        <form method="POST" action="send_woodlands_postal.php" target="_blank" id="modal-open-postal-ccr">
                                            <input type="hidden" name="filePath7" id="modal-file-path7">
                                            <button type="submit" class="btn btn-info">Send Woodlands Postal Document</button>
                                        </form>
                                        <form method="POST" action="open_email_document.php" target="_blank" id="modal-open-EmailDocument-form">
                                            <input type="hidden" name="filePath5" id="modal-file-path5">
                                            <button type="submit" class="btn btn-primary">Open Email Document</button>
                                        </form>
                                    </div>
                                    <div class="modal-footer">
                                        <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
                                    </div>
                                </div>
                            </div>
                        </div>

                    </div>
                </div>
            </div>
        </div>
    </div>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
    <script>
        $(document).ready(function() {
            $('.openModal').on('click', function() {
                var tr = $(this).closest('tr');

                // Get the note type from the second cell (index 1)
                var noteType = tr.find('td:eq(1)').text().trim();
                var noteTypeLower = noteType.toLowerCase();
                $('#modal-note-type').text(noteType);

                // Get the created date from the first cell (index 0)
                var createdWhen = tr.find('td:eq(0)').text().trim();
                $('#modal-crtdwhn').text(createdWhen);

                // Determine which full content to show based on the note type
                var fullContent = '';
                if (noteTypeLower === 'sms') {
                    // Use SMS body if available
                    fullContent = tr.data('sms-body') || tr.data('full-description') || '';
                } else if (noteTypeLower === 'email') {
                    // Use email message if available
                    fullContent = tr.data('email-message') || tr.data('full-description') || '';
                } else if (noteTypeLower === 'documents' || noteTypeLower === 'upload') {
                    // For documents, display the document filename (or any document details you want)
                    fullContent = 'Document Filename: ' + (tr.data('document-filename') || 'N/A');
                } else {
                    // Default: use the full description
                    fullContent = tr.data('full-description') || '';
                }
                $('#modal-dscrptn').html(fullContent);

                // Populate the Created By field from data attribute (if set) or from column 6 (index 5)
                var createdBy = tr.data('created-by-name') || tr.find('td:eq(5)').text().trim();
                $('#modal-created_by_name').text(createdBy);

                // Populate the Creditor field from data attribute (if set) or from column 5 (index 4)
                var creditorName = tr.data('creditor-name') || tr.find('td:eq(4)').text().trim();
                $('#modal-creditor-name').text(creditorName);

                // Optionally, show/hide additional modal forms based on note type
                // (Adjust the conditions as needed.)
                if (noteType === "Upload") {
                    $('#modal-open-upload-image').show();
                } else {
                    $('#modal-open-upload-image').hide();
                }

                if (noteType === "Documents") {
                    $('#modal-open-document-form').show();
                } else {
                    $('#modal-open-document-form').hide();
                }

                if (noteType === "Email") {
                    $('#modal-open-EmailDocument-form').show();
                } else {
                    $('#modal-open-EmailDocument-form').hide();
                }

                // Show or hide the entire form based on the type of the note
                var noteType = tr.find('td:eq(1)').text().trim();
                if (noteType === "Upload") {
                    $('#modal-open-upload-image').show();
                } else {
                    $('#modal-open-upload-image').hide();
                }
                // Show or hide the entire form based on the type of the note
                var noteType = tr.find('td:eq(1)').text().trim();
                if (noteType === "Documents") {
                    $('#modal-open-document-form').show();
                } else {
                    $('#modal-open-document-form').hide();
                }

                // Show or hide the entire form based on the type of the note
                var noteType = tr.find('td:eq(1)').text().trim();
                if (noteType === "Email") {
                    $('#modal-open-EmailDocument-form').show();
                } else {
                    $('#modal-open-EmailDocument-form').hide();
                }

                // Show or hide the entire form based on the type of description
                var dscrptn = tr.find('td:eq(3)').text().trim();
                if (dscrptn.toLowerCase() === "information pack") {
                    $('#modal-open-signable-form').show();
                } else {
                    $('#modal-open-signable-form').hide();
                }

                // Show or hide the entire form based on the type of description
                var dscrptn = tr.find('td:eq(3)').text().trim();
                if (dscrptn.toLowerCase() === "clear start (loa) - signable") {
                    $('#modal-open-loa-form').show();
                } else {
                    $('#modal-open-loa-form').hide();
                }

                // Show or hide the entire form based on the type of description
                var dscrptn = tr.find('td:eq(3)').text().trim();
                if (dscrptn.toLowerCase() === "information pack") {
                    $('#modal-open-postal-form').show();
                } else {
                    $('#modal-open-postal-form').hide();
                }

                // Show or hide the entire form based on the type of description
                var dscrptn = tr.find('td:eq(3)').text().trim();
                if (dscrptn.toLowerCase() === "ccr information pack (woodlands)") {
                    $('#modal-open-signable-ccr').show();
                } else {
                    $('#modal-open-signable-ccr').hide();
                }

                // Show or hide the entire form based on the type of description
                var dscrptn = tr.find('td:eq(3)').text().trim();
                if (dscrptn.toLowerCase() === "ccr information pack (woodlands)") {
                    $('#modal-open-postal-ccr').show();
                } else {
                    $('#modal-open-postal-ccr').hide();
                }

                // (If you have additional forms to show/hide based on description content, include that logic here.)

                // Finally, show the modal
                $('#detailModal').modal('show');
            });
            // Click event for the "Open Document" button inside the modal
            $('#modal-open-document').on('click', function() {
                var filePath = $(this).data('file-path');
                if (filePath) {
                    window.open(filePath, '_blank');
                }
            });
            // Click event for the "Open Document" button inside the modal
            $('#modal-open-signable').on('click', function() {
                var filePath2 = $(this).data('file-path');
                if (filePath2) {
                    window.open(filePath, '_blank');
                }
            });
            // Click event for the "Open Document" button inside the modal
            $('#modal-open-postal').on('click', function() {
                var filePath3 = $(this).data('file-path');
                if (filePath3) {
                    window.open(filePath, '_blank');
                }
            });
            // Click event for the "Open Document" button inside the modal
            $('#modal-open-upload-image').on('click', function() {
                var filePath4 = $(this).data('file-path');
                if (filePath4) {
                    window.open(filePath, '_blank');
                }
            });
            // Click event for the "Open Document" button inside the modal
            $('#modal-open-EmailDocument').on('click', function() {
                var filePath5 = $(this).data('file-path');
                if (filePath5) {
                    window.open(filePath, '_blank');
                }
            });
        });
        
        // JavaScript function to open the Note modal and set hidden input values
function openNoteModal() {


    // Set the hidden input values in the modal
    document.getElementById("useridInput").value = userid;
    document.getElementById("idInput").value = id;

    // Open the modal
    var modal = new bootstrap.Modal(document.getElementById("noteModal"));
    modal.show();

    // Add an event listener to the "Save Note" button
    var saveButton = document.getElementById("saveNoteButton");
    saveButton.addEventListener("click", function() {
        // Get the form data
        var noteContent = document.getElementById("noteContent").value;

        // Create a FormData object to send the data
        var formData = new FormData();
        formData.append("userid", userid);
        formData.append("id", id);
        formData.append("noteContent", noteContent);

        // Send the form data to your PHP script using a fetch request
        fetch("/client/Updates/create_note.php", {
            method: "POST",
            body: formData
        })
        .then(response => response.text())
        .then(data => {
            // Handle the response data (e.g., display a success message)
            console.log(data);
            // Close the modal if needed
            modal.hide();
            // Reload the page after the modal is closed
            location.reload();
        })
        .catch(error => {
            // Handle errors (e.g., display an error message)
            console.error(error);
        });
    });
}
    </script>

</body>

</html>