<?php
session_start();

// If session variable 'username' is not set or is 'Guest', redirect to login page
if (!isset($_SESSION['username']) || $_SESSION['username'] === "Guest") {
    header("Location: /login.php");
    exit();
}

// Check if the session is inactive for more than 10 seconds
if (isset($_SESSION['last_activity']) && (time() - $_SESSION['last_activity'] > 900)) {
    // Session has been inactive for more than 10 seconds
    session_unset();     // Unset $_SESSION variable for the run-time
    session_destroy();   // Destroy the session data on the server
    header("Location: /login.php"); // Redirect to login page
    exit(); // Ensure no further execution of the script
}

// Update last activity time stamp
$_SESSION['last_activity'] = time();

$username = $_SESSION['username']; // Username is already checked above and is not 'Guest'

// Check if 'client_id' is in the URL query parameter
if (isset($_GET['client_id'])) {
    // Store the 'client_id' from the URL in a variable
    $id = $_GET['client_id'];
} else {
    // Set a default value or handle the case where 'client_id' is not provided in the URL
    $id = 'default_value';
}
$username = isset($_SESSION['username']) ? $_SESSION['username'] : "Guest";
include_once '../config_current.php';

/// Get Username
$query = "SELECT nme, job_title FROM account_users WHERE email = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param('s', $username);
$stmt->execute();

$result = $stmt->get_result();
$row = $result->fetch_assoc();

if ($row) {
    $truename = $row['nme'];
    $jobtitle = $row['job_title'];
} else {
    $truename = "Unknown";
}

$stmt->close();

// Suppose 'case_details' is your table name and it contains relevant information about the case
$case_query = "SELECT * FROM client_core WHERE id = ?";
$case_stmt = $conn->prepare($case_query);
$case_stmt->bind_param('i', $id); // assuming client_id is an integer field
$case_stmt->execute();
$case_result = $case_stmt->get_result();
$case_details = $case_result->fetch_assoc(); // fetches the row as an associative array
$case_stmt->close();

//Message Query
$allMessagesQuery = "SELECT * FROM client_sms WHERE cid = '$id'";
$allResult = mysqli_query($conn, $allMessagesQuery);
$messages = [];

while ($row = mysqli_fetch_assoc($allResult)) {
    $messages[] = $row;
}

?>

<!DOCTYPE html>
<html>
<head>
    <!-- [Bootstrap, jQuery, Popper, Bootstrap JS, and other includes] -->
    <title>SMS | Case <?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?></title>
    <?php include 'layouts/head.php'; ?>
    <?php include 'layouts/head-style.php'; ?>
</head>
<style>
html, body {
    height: 100%;
}

#layout-wrapper, .main-content, .page-content {
    min-height: 100%;
}

.message-container {
    max-width: 100%;
    word-wrap: break-word;
    height: 100%;
}

.left {
    text-align: left;
}

.right {
    text-align: right;
}

.unread {
    background-color: lightyellow; /* Color for unread messages */
}

/* Add a new class for highlighting the message container */
.highlight-container {
    background-color: #00000;
}

/* Add a class for displaying the message status */
.message-status {
    font-weight: bold;
    font-size: 12px;
    color: #00000; /* Change the color as needed */
}

/* Add a class to handle long text messages and make them scrollable */
.message-text {
    max-height: 100px; /* Adjust the height as needed */
    overflow-y: auto;
}
</style>

<body>
    <?php include 'layouts/body.php'; ?>

    <div id="layout-wrapper">
        <?php include 'layouts/vertical-menu.php'; ?>
        <div class="main-content">
            <div class="page-content">
                <button type="button" class="btn btn-primary" data-toggle="modal" data-target="#sendMessageModal">
    Send Free Hand Message
</button>

                 <!-- Modal -->
               <div class="modal fade" id="sendMessageModal" tabindex="-1" role="dialog" aria-labelledby="sendMessageModalLabel" aria-hidden="true">

                    <div class="modal-dialog modal-dialog-centered" role="document">
                        <div class="modal-content">
                            <div class="modal-header">
                                <h5 class="modal-title" id="sendMessageModalLabel">Send Free Hand Message</h5>
                                <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                                    <span aria-hidden="true">&times;</span>
                                </button>
                            </div>
                            <div class="modal-body">
                                <!-- Message input form -->
                                <form id="sendMessageForm">
                                    <div class="form-group">
                                        <label for="messageBody">Message:</label>
                                        <textarea class="form-control" id="messageBody" name="smsbody" rows="3"></textarea>
                                    </div>
                                    <!-- Hidden fields for client ID and user ID -->
                                    <input type="hidden" id="clientId" name="id" value="<?php echo $id; ?>">
                                    <input type="hidden" id="agentId" name="userid" value="<?php echo $userid; ?>">
                                </form>
                            </div>
                            <div class="modal-footer">
                                <button type="button" class="btn btn-danger" data-bs-dismiss="modal">Close</button>
                                <button type="button" class="btn btn-success" id="sendButton">Send</button>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="container">
                    <div class="w-100 user-chat" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                        <div class="card" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                            <div class="p-4 border-bottom " speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                <div class="row" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                    <div class="col-md-4 col-9" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                    </div>
                                    <div speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                        <div class="chat-conversation p-3 message-container">
                                            
                                            <!-- PHP script for displaying messages -->
                                            <?php
                                                // Loop through the messages array and display them
                                                foreach ($messages as $row) {
                                                    // $messageClass = ($row['status'] === 'I') ? 'in-i' : '';
                                                    $textAlignClass = ($row['sms-status'] === 'inbox') ? 'left' : 'right';
                                                    // Apply the highlighting class to the entire <li> element if status is 'I'
                                                    $containerClass = ($row['sms-status'] === 'sent') ? 'highlight-container unread' : ''; // Use 'unread' class for unread messages
                                                    $messageId = htmlspecialchars($row['id']); // Get the message ID
                                                    
                                                    echo "<li class='$textAlignClass'>";
                                                    echo "<div class='conversation-list'>";
                                                    echo "<div class='ctext-wrap $containerClass' data-message-id='$messageId'>"; // Add data-message-id attribute
                                                    echo "<div class='conversation-name'>" . htmlspecialchars($row['sms-to']) . "</div>";
                                                    echo "<p class='message-text'>" . htmlspecialchars($row['sms-body']) . "</p>"; // Add the message-text class here
                                                    echo "<p class='message-status mb-0'>";
                                                    
                                                    // Display the message status based on the 'status' column
                                                    switch ($row['sms-status']) {
                                                        case 'I':
                                                            echo "Unread";
                                                            break;
                                                        case 'S':
                                                            echo "Sent";
                                                            break;
                                                        case 'R':
                                                            echo "Read";
                                                            break;
                                                        default:
                                                            echo "Unknown";
                                                    }
                                                    
                                                    echo "</p>";
                                                    echo "<p class='chat-time mb-0'><i class='bx bx-time-five align-middle me-1'></i> " . htmlspecialchars($row['created-when']) . "</p>";
                                                    echo "</div>";
                                                    
                                                    // Include the messageId in the AJAX call
                                                    echo "<script>";
                                                    echo "document.querySelector('[data-message-id=\"$messageId\"]').addEventListener('click', function () {";
                                                    echo "  markMessageAsRead($messageId);";
                                                    echo "});";
                                                    echo "</script>";
                                                    
                                                    echo "</div>";
                                                    echo "</li>";
                                                }
                                            ?>
                                            <!-- End of PHP script -->
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>




    <!-- Updated JavaScript code with Bootstrap 5 -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.5.0/js/bootstrap.min.js"></script>
<script>
    $(document).ready(function () {
        // Function to mark a message as read
        function markAsRead(messageId) {
            // Make an AJAX request to update the message status
            $.ajax({
                type: 'POST',
                url: '/client/Updates/update_message_status.php', // Create a PHP script to update message status
                data: { messageId: messageId },
                dataType: 'json',
                success: function (response) {
                    if (response.success) {
                        // Update the message status in the UI (e.g., change the background color)
                        $(`[data-message-id="${messageId}"]`).removeClass('unread'); // Remove the 'unread' class
                        location.reload(); // Reload the page
                    } else {
                        console.error('Error updating message status');
                    }
                },
                error: function () {
                    console.error('Error: AJAX request failed');
                }
            });
        }

        // Add a click event listener to each message element
        $('.message-container').on('click', '.unread', function () {
            const messageId = $(this).data('message-id');
            markAsRead(messageId);
        });
    });

$(document).ready(function () {
    // Function to send the message
    function sendMessage() {
        const messageBody = $('#messageBody').val();
        const clientId = $('#clientId').val();
        const agentId = $('#agentId').val();

        // Make an AJAX request to send the message without expecting a response
        $.ajax({
            type: 'POST',
            url: '/client/Updates/send_sms.php',
            data: { clientId: clientId, smsBody: messageBody, agentid: agentId },
            dataType: 'json'
        });

        // Close the modal with a slight delay
        setTimeout(function () {
            
            // Reload the page with another slight delay
            setTimeout(function () {
                location.reload();
            }, 1000); // 1000 milliseconds (1 second) delay for page reload
        }, 500); // 500 milliseconds (0.5 second) delay for modal close
    }

    // Add a click event listener to the "Send" button
    $('#sendButton').click(function () {
        sendMessage();
    });
});




</script>

</body>
</html>


