<?php
session_start();

// If session variable 'username' is not set or is 'Guest', redirect to login page
if (!isset($_SESSION['username']) || $_SESSION['username'] === "Guest") {
    header("Location: /login.php");
    exit();
}

// Check if the session is inactive for more than 10 seconds
if (isset($_SESSION['last_activity']) && (time() - $_SESSION['last_activity'] > 900)) {
    // Session has been inactive for more than 10 seconds
    session_unset();     // Unset $_SESSION variable for the run-time
    session_destroy();   // Destroy the session data on the server
    header("Location: /login.php"); // Redirect to login page
    exit(); // Ensure no further execution of the script
}

// Update last activity time stamp
$_SESSION['last_activity'] = time();

$username = $_SESSION['username']; // Username is already checked above and is not 'Guest'

// Check if 'client_id' is in the URL query parameter
if (isset($_GET['client_id'])) {
    // Store the 'client_id' from the URL in a variable
    $id = $_GET['client_id'];
} else {
    // Set a default value or handle the case where 'client_id' is not provided in the URL
    $id = 'default_value';
}
$username = isset($_SESSION['username']) ? $_SESSION['username'] : "Guest";
include_once '../config_current.php';

/// Get Username
$query = "SELECT nme, job_title FROM account_users WHERE email = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param('s', $username);
$stmt->execute();

$result = $stmt->get_result();
$row = $result->fetch_assoc();

if ($row) {
    $truename = $row['nme'];
    $jobtitle = $row['job_title'];
} else {
    $truename = "Unknown";
}

$stmt->close();

// Suppose 'case_details' is your table name and it contains relevant information about the case
$case_query = "SELECT * FROM client_core WHERE id = ?";
$case_stmt = $conn->prepare($case_query);
$case_stmt->bind_param('i', $id); // assuming client_id is an integer field
$case_stmt->execute();

$case_result = $case_stmt->get_result();
$case_details = $case_result->fetch_assoc(); // fetches the row as an associative array

// print_r($case_details); exit;

$case_stmt->close();


 // Query the Ledger Table

$ledger_query = "
    SELECT
        cl.id,
        ls.name AS rsn,
        au.nme AS user_name,
        cl.`payment-reference` AS pmntRfrnce,
        cl.`amount` AS amnt,
        cl.`type` AS tpe,
        cl.`payment-status`,
        cl.`created-when` AS createdWhen
    FROM client_ledger AS cl
    LEFT JOIN account_users AS au
           ON cl.`created-by` = au.id
    LEFT JOIN `ledger-status` AS ls
           ON cl.`type` = ls.id
    WHERE cl.cid = ?
    ORDER BY cl.`created-when` DESC
";

$ledger_stmt = $conn->prepare($ledger_query);
if (!$ledger_stmt) {
    die("Error preparing statement: " . $conn->error);
}

// We assume $id is an integer from $_GET['client_id'].
$ledger_stmt->bind_param("i", $id);
$ledger_stmt->execute();
$ledger_result = $ledger_stmt->get_result();

// Initialize array and total
$count_success = 0;
$count_refused = 0;
$total_amount = 0;
$ledgerEntries = [];

// Loop through rows and build $ledgerEntries
while ($row = $ledger_result->fetch_assoc()) {

   $paymentStatus = isset($row['payment-status']) ? strtolower(trim($row['payment-status'])) : '';

    // Only add amount to total if payment status is "success"
    if ($paymentStatus === 'success') {
        $count_success++;
        $total_amount += (float) $row['amnt'];
    } elseif ($paymentStatus === 'refused') {
        $count_refused++;
    }

    // Add row to the array
    $ledgerEntries[] = $row;
}

$ledger_stmt->close();

// Calculate authorization percentage
// Only consider rows that are either success or refused
$total_considered = $count_success + $count_refused;
if ($total_considered > 0) {
    $authPercentage = ($count_success / $total_considered) * 100;
} else {
    $authPercentage = 0;
}


// Now you have $ledgerEntries and a numeric $total_amount
// If you want to store them in another array structure:
$data = [
    'TotalAmount' => $total_amount,
    'ledger'      => $ledgerEntries,
];


?>



<!-- HTML and PHP code to display the table -->
<!DOCTYPE html>
<html>
<head>
<script>
    document.addEventListener('DOMContentLoaded', function() {
        var successMessage = localStorage.getItem('ledgerSuccess');
        var errorMessage = localStorage.getItem('ledgerError');
        var alertPlaceholder = document.getElementById('alert-placeholder'); // Ensure this placeholder exists in your HTML

        function refreshPage() {
            // Refresh the page after a 2-second delay
            setTimeout(function() {
                window.location.reload();
            }, 2000);
        }

        if (successMessage) {
            var successAlert = '<div class="alert alert-success" role="alert">' +
                               'Ledger added sucessfully' + successMessage +
                               '</div>';
            alertPlaceholder.innerHTML = successAlert;
            localStorage.removeItem('ledgerSuccess'); // Clear the message after displaying
            refreshPage(); // Call refreshPage after displaying the success message
        }

        if (errorMessage) {
            var errorAlert = '<div class="alert alert-warning" role="alert">' +
                             'Ledger failed to add into the database' + errorMessage +
                             '</div>';
            alertPlaceholder.innerHTML = errorAlert;
            localStorage.removeItem('ledgerError'); // Clear the message after displaying
            refreshPage(); // Call refreshPage after displaying the error message
        }
    });
</script>

    
<!-- Replace the slim jQuery with the full version -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>




    <title>Ledger List | Case <?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?></title>
    <?php include 'layouts/head.php'; ?>
    <?php include 'layouts/head-style.php'; ?>
</head>
<body>
    <style>
/* Add this style in your CSS file or in a <style> tag in the head of your HTML */
.table-container {
    width: 66%;
    margin-right: 0;
}
/* Flex container */
.flex-container {
    display: flex;
    justify-content: space-between;
}
/* Sidebar */
/* Sidebar */
.sidebar {
    width: 18%;
    position: fixed;
    top: 60px;
    right: 0; /* Change 'left' to 'right' */
    bottom: 0;
    padding: 20px;
    overflow-y: auto;
    max-height: 80vh;
    background-color: #f8f9fa;
}




.total-collect {
    /* Styles for total collect */
    margin-bottom: 20px; /* Adjust as needed */
}

.buttons button {
    /* Styles for buttons */
    margin-bottom: 10px; /* Adjust spacing between buttons */
    width: 100%; /* Set the width to full container width */
    /* More button styling */
}
/* CSS for the preloader container */
.preloader {
    display: none;
    position: fixed;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background-color: rgba(255, 255, 255, 0.8); /* Semi-transparent white background */
    z-index: 1000; /* Ensure it's above other elements */
}

/* CSS for the spinner */
.spinner {
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    border: 4px solid #f3f3f3;
    border-top: 4px solid #3498db;
    border-radius: 50%;
    width: 40px;
    height: 40px;
    animation: spin 2s linear infinite;
}

/* Keyframes for spinner animation */
@keyframes spin {
    0% { transform: translate(-50%, -50%) rotate(0deg); }
    100% { transform: translate(-50%, -50%) rotate(360deg); }
}



    </style>
    <?php include 'layouts/body.php'; ?>

    <div id="layout-wrapper">
    <?php include 'layouts/vertical-menu.php'; ?>

    <div class="main-content">
        <!--- Create Ledger Modal ---->
                        
                        <div id="createLedgerModal" class="modal fade" role="dialog">
                            <div class="modal-dialog">
                        
                                <!-- Modal content-->
                                <div class="modal-content">
                                    <div class="modal-header">
                                        <h4 class="modal-title">Create Ledger</h4>
                                                    </div>
                                    <div class="modal-body">
                                        <form id="ledgerForm" action="" method="post">
                                            <div class="form-group">
                                                <label for="pmntRfrnce">Payment Ref:</label>
                                                <input type="text" class="form-control" id="pmntRfrnce" name="pmntRfrnce">
                                            </div>
                                            <div class="form-group">
                                                <label for="rsn">Reason:</label>
                                                <input type="text" class="form-control" id="rsn" name="rsn">

                                            </div>
                                            <div class="form-group">
                                                <label for="amnt">Amount:</label>
                                                <input type="text" class="form-control" id="amnt" name="amnt">

                                            </div>
                                            <div class="form-group">
                                                <label for="tpe">Type:</label>
                                                <select class="form-control" id="type" name="tpe">
                                                <option value="0" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px"> Initial fee (IP1)</option><option value="1" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Full and final paid</option><option value="2" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Fund for full and final</option><option value="3" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Ad-hoc payment for client (eg N245)</option><option value="4" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Other payment received</option><option value="5" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Other payment made</option><option value="6" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Partial Initial Payment</option><option value="7" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Management fee</option><option value="8" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Write-off fund</option><option value="9" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Bond</option><option value="10" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Creditor setup fee</option><option value="11" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Late Payment Fee</option><option value="12" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Fund for token payment</option><option value="14" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Annual review fee</option><option value="16" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Set-up fee instalment</option><option value="13" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Second Initial Payment (IP2)</option><option value="15" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Third Initial Payment (IP3)</option><option value="17" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Fourth Initial Payment (IP4)</option><option value="18" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Fifth Initial Payment (IP5)</option><option value="19" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">FAF Payment</option><option value="20" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Add Creditor Payment</option><option value="21" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">APF Payment</option><option value="22" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">PAYE Rebate Refund</option><option value="23" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Rebate HMRC Funds In</option><option value="24" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Rebate Fee</option>                             </select>
                                            </div>
                                            <div class="form-group">
                                                <label for="notes">Notes:</label>
                                                <textarea class="form-control" id="notes" name="notes"></textarea>

                                            </div>
                                            <div class="modal-footer">
                                                <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                                                <button type="submit" class="btn btn-success">Create</button>
                                            </div>
                                        </form>
                                </div>
                                </div>
                        
                            </div>
                        </div>
                        <!-- One Time Card Payment Modal -->
                            <div id="oneTimeCardPaymentModal" class="modal fade" role="dialog">
                                <div class="modal-dialog">
                                    <!-- Modal content-->
                                    <div class="modal-content">
                                        <div class="modal-header">
                                            <h4 class="modal-title">One Time Card Payment</h4>
                                        </div>
                                        <div class="modal-body">
                                            <!-- Payment Type Selection -->
                                            <label>Select Payment Type</label>
                                            <select class="form-select" id="paymentType" name="paymentType">
                                                <option value="-1" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">-- Please select --</option><option value="0" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px"> Initial fee (IP1)</option><option value="1" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Full and final paid</option><option value="2" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Fund for full and final</option><option value="3" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Ad-hoc payment for client (eg N245)</option><option value="4" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Other payment received</option><option value="5" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Other payment made</option><option value="6" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Partial Initial Payment</option><option value="7" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Management fee</option><option value="8" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Write-off fund</option><option value="9" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Bond</option><option value="10" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Creditor setup fee</option><option value="11" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Late Payment Fee</option><option value="12" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Fund for token payment</option><option value="14" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Annual review fee</option><option value="16" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Set-up fee instalment</option><option value="13" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Second Initial Payment (IP2)</option><option value="15" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Third Initial Payment (IP3)</option><option value="17" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Fourth Initial Payment (IP4)</option><option value="18" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Fifth Initial Payment (IP5)</option><option value="19" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">FAF Payment</option><option value="20" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Add Creditor Payment</option><option value="21" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">APF Payment</option><option value="22" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">PAYE Rebate Refund</option><option value="23" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Rebate HMRC Funds In</option><option value="24" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Rebate Fee</option>  
                                            </select>
                                            <br>
                            

                                            <div id="ipPaymentSelection">
                                                <label>Select IP Payment</label>
                                                <select class="form-select"  id="ipPayment" name="ipPayment">
                                                <option value="#">-- Please select --</option>
                                                <option value="<?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?> Full Payment"><?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?> Full Payment</option>
                                                <option value="<?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?> (1 of 2)"><?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?> (1 of 2)</option>
                                                <option value="<?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?> (2 of 2)"><?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?> (2 of 2)</option>
                                                <option value="<?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?> (1 of 4)"><?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?> (1 of 4)</option>
                                                <option value="<?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?> (2 of 4)"><?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?> (2 of 4)</option>
                                                <option value="<?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?> (3 of 4)"><?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?> (3 of 4)</option>
                                                <option value="<?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?> (4 of 4)"><?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?> (4 of 4)</option>
                                            </select>
                                        </div>
                                        <br>
                                        <div id="paymentDetails">
                                            <div class="form-group">
                                                <label for="cardName">Name on Card:</label>
                                                <input type="text" class="form-control" id="cardName" name="cardName" placeholder="Name on Card">
                                            </div>
                                            <div class="form-group">
                                                <label for="cardNumber">Card Number:</label>
                                                <input type="number" class="form-control" id="cardNumber" name="cardNumber" placeholder="Enter card number">
                                            </div>
                                            <div class="form-group">
                                                <label for="expiryDate">Expiry Date:</label>
                                                <input type="text" class="form-control" id="expiryDate" name="expiryDate" placeholder="MM/YYYY">
                                            </div>
                                            <div class="form-group">
                                                <label for="cvv">CVV:</label>
                                                <input type="number" class="form-control" id="cvv" name="cvv" placeholder="Enter CVV">
                                            </div>
                                            <div class="form-group">
                                                <label for="amount">Payment Amount:</label>
                                                <input type="number" class="form-control" id="amount" name="amount" placeholder="Enter payment amount">
                                            </div>
                                            <div class="form-group">
                                                <label for="cardtype">Card Type:</label>
                                                <select class="form-control" id="cardtype" name="cardtype">
                                                    <option value="#">-- Please select --</option>
                                                    <option value="MASTER">Mastercard</option>
                                                    <option value="VISA">Visa</option>
                                                </select>
                                            </div>

                                        </div>
                                        
                                        <!-- ... (other modal content) ... -->
                                    
                                        <!-- Modal footer with the submit button -->
                                        <div class="modal-footer">
                                            <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
                                            <button type="button" class="btn btn-success" id="submitPaymentInfo">Submit Payment Information</button>
                                        </div>


                                    </div>
                                </div>
                            </div>
                            <div id="preloader" class="preloader">
                                <div class="spinner"></div>
                            </div>



                                        </div>

        <div class="page-content">
            <div class="container-fluid">
                <!-- Flex container for table and sidebar -->
                <div class="d-flex">
                    <!-- Table container -->
                    <div style="width: 80%; float: left;">
                        <!-- Table to display case_ledger entries -->
                        <div id="alert-placeholder"></div>
                        <div id="successMessage"></div>


                        <table class="table table-bordered" style="width: 100%;">
                            <thead>
                                <tr>
                                    <th>ID</th>
                                    <th>Reason</th>
                                    <th>Taken By</th>
                                    <th>Payment Reference</th>
                                    <th>Type</th>
                                    <th>Amount</th>
                                    <th>Created</th>
                                    <th>Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                        <?php foreach ($ledgerEntries as $entry): ?>
                                        <?php
        // Get the amount
        $amnt = isset($entry['amnt']) ? floatval($entry['amnt']) : 0.00;
        
        // Set a default background color based on the amount
        // (green if positive, coral if zero or negative)
        $backgroundColor = $amnt > 0 ? 'lightgreen' : 'lightcoral';

        // Retrieve and normalize the payment status
        $paymentStatus = isset($entry['payment-status']) ? strtolower(trim($entry['payment-status'])) : '';

        // Override the background color based on the payment status value
        if ($paymentStatus === 'success') {
            $backgroundColor = 'lightgreen';
        } elseif ($paymentStatus === 'refused') {
            $backgroundColor = 'lightcoral';
        } elseif ($paymentStatus === 'refund') {
            $backgroundColor = 'lightyellow';
        }
    ?>
                                    <tr style="background-color: <?= htmlspecialchars($backgroundColor) ?>;">
                                        <td><?= htmlspecialchars($entry['id']) ?></td>
                                        <td><?= htmlspecialchars($entry['rsn'] ?? '') ?></td>
                                        <td><?= htmlspecialchars($entry['user_name'] ?? '') ?></td>
                                        <td><?= htmlspecialchars($entry['pmntRfrnce'] ?? '') ?></td>
                                       <td><?= htmlspecialchars($entry['tpe'] == 1 ? "CARD" : "unknown payment") ?></td>
                                        <td>£<?= number_format($amnt, 2, '.', ','); ?></td>

                                        <td>
                                            <?php 
                                                if (isset($entry['createdWhen'])) {
                                                    $date = DateTime::createFromFormat('Y-m-d H:i:s', $entry['createdWhen']);
                                                    if ($date) {
                                                        echo htmlspecialchars($date->format('d/m/Y h:i A'));
                                                    } else {
                                                        echo 'Invalid Date';
                                                    }
                                                } else {
                                                    echo 'Date Not Set';
                                                }
                                            ?>
                                        </td>
                                        <td>
                                          <div class="btn-group" role="group" aria-label="Basic actions group">
                                          <!-- View button -->
                                          <button type="button" class="btn btn-primary view-ledger-details" data-ledger-id="<?= htmlspecialchars($entry['id']) ?>">View</button>



                                          <?php
                                            if ($section === 'Management') {
                                                // Display the buttons only for Management section
                                                echo '
                                                    <!-- Edit button -->
                                                    <button type="button" class="btn btn-warning edit-btn" data-ledger-id="' . htmlspecialchars($entry['id']) . '">Edit</button>

                                                    ';
                                            }
                                            ?> 

                                            <?php
                                            if ($section === 'Management') {
                                                // Display the buttons only for Management section
                                                echo ' 

                                                    <!-- Delete button -->
                                                    <button type="button" class="btn btn-danger delete-btn" data-ledger-id="' . htmlspecialchars($entry['id']) . '">Delete</button>
                                                    ';
                                            }
                                            ?> 

                                                <!-- Modal for Ad-Hoc Payment -->
                                <div class="modal fade" id="adhocPaymentModal" tabindex="-1" role="dialog" aria-labelledby="adhocPaymentModalLabel" aria-hidden="true">
                                    <div class="modal-dialog" role="document">
                                        <div class="modal-content">
                                            <div class="modal-header">
                                                <h5 class="modal-title" id="adhocPaymentModalLabel">Enter Ad-Hoc Payment Amount</h5>
                                                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                                    <span aria-hidden="true">&times;</span>
                                                </button>
                                            </div>
                                            <div class="modal-body">
                                                <div class="form-group">
                                                    <label for="adhocPaymentAmount">Amount:</label>
                                                    <input type="number" class="form-control" id="adhocPaymentAmount" placeholder="Enter amount">
                                                </div>
                                            </div>
                                            <div id="loadingnew" style="display: none;">
                                        <img src="Spinner-1s-200px (1).gif" alt="Loading...">
                                    </div>
                                            <div class="modal-footer">
                                                <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
                                                <button type="button" class="btn btn-success" id="submitAdhocPayment">Submit</button>
                                            </div>
                                        </div>
                                    </div>
                                </div>


                              <!-- Modal for Late PaymentPayment -->
                                <div class="modal fade" id="LatePaymentModal" tabindex="-1" role="dialog" aria-labelledby="LatePaymentModalLabel" aria-hidden="true">
                                    <div class="modal-dialog" role="document">
                                        <div class="modal-content">
                                            <div class="modal-header">
                                                <h5 class="modal-title" id="LatePaymentModalLabel">Enter Late Payment Amount</h5>
                                                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                                    <span aria-hidden="true">&times;</span>
                                                </button>
                                            </div>
                                            <div class="modal-body">
                                                <div class="form-group">
                                                    <label for="LatePaymentAmount">Amount:</label>
                                                    <input type="number" class="form-control" id="LatePaymentAmount" placeholder="Enter amount">
                                                </div>
                                            </div>
                                            <div id="loadingnew" style="display: none;">
                                        <img src="Spinner-1s-200px (1).gif" alt="Loading...">
                                    </div>
                                            <div class="modal-footer">
                                                <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
                                                <button type="button" class="btn btn-success" id="submitLatePayment">Submit</button>
                                            </div>
                                        </div>
                                    </div>
                                </div>


                                <!-- Modal for Full and Final  PaymentPayment -->
                                <div class="modal fade" id="FullandFinalPaymentModal" tabindex="-1" role="dialog" aria-labelledby="FullandFinalPaymentModalLabel" aria-hidden="true">
                                    <div class="modal-dialog" role="document">
                                        <div class="modal-content">
                                            <div class="modal-header">
                                                <h5 class="modal-title" id="FullandFinalPaymentModalLabel">Enter Full and Final Payment Amount</h5>
                                                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                                    <span aria-hidden="true">&times;</span>
                                                </button>
                                            </div>
                                            <div class="modal-body">
                                                <div class="form-group">
                                                    <label for="FullandFinalPaymentAmount">Amount:</label>
                                                    <input type="number" class="form-control" id="FullandFinalPaymentAmount" placeholder="Enter amount">
                                                </div>
                                            </div>
                                            <div id="loadingnew" style="display: none;">
                                        <img src="Spinner-1s-200px (1).gif" alt="Loading...">
                                    </div>
                                            <div class="modal-footer">
                                                <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
                                                <button type="button" class="btn btn-success" id="submitFullandFinalPayment">Submit</button>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            
                             <!-- Request Boodil Link Modal content-->
                            <div id="requestBoodilLinkModal" class="modal fade" role="dialog">
                                <div class="modal-dialog">
                                    <!-- Modal content-->
                                    <div class="modal-content">
                                        <div class="modal-header">
                                            <h4 class="modal-title">Request Boodil Link</h4>
                                        </div>
                                        <form id="requestBoodilLinkForm">
                                            <div class="modal-body">
                                                <div class="form-group">
                                                    <label for="amountbroo">Amount:</label>
                                                    <input type="text" class="form-control" id="amountbroo" name="amountbroo" required>
                                                    <input class="form-control" type="hidden" name="cse" id="cse" value="<?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?>">
                                                </div>
                                            </div>
                                            <div class="modal-footer">
                                                <button type="button" class="btn btn-danger waves-effect waves-light" data-dismiss="modal">Close</button>
                                                <button type="submit" class="btn btn-success" id="requestButton">Request Link</button>
                                            </div>
                                        </form>
                                    </div>
                                </div>
                            </div>



                            <!-- Modal Structure -->
                            <div class="modal fade" id="paylink_card_payment_modal" tabindex="-1" role="dialog" aria-labelledby="modalLabel" aria-hidden="true">
                              <div class="modal-dialog" role="document">
                                <div class="modal-content">
                                  <div class="modal-header">
                                    <h5 class="modal-title" id="modalLabel">Enter Payment Amount</h5>
                                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                      <span aria-hidden="true">&times;</span>
                                    </button>
                                  </div>
                                  <div class="modal-body">
                                    <input type="text" class="form-control" id="payment_amount" onchange="formatAmount()">
                                  </div>
                                  <div class="modal-footer">
                                    <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
                                    <button type="button" class="btn btn-success" onclick="submitPaymentLink()">Submit</button>
                                  </div>
                                </div>
                              </div>
                            </div>
                            <script>
                                function formatAmount() {
                                var amountInput = document.getElementById("payment_amount");
                                var amount = parseFloat(amountInput.value);

                                if (isNaN(amount)) {
                                    alert("Please enter a valid number.");
                                    amountInput.value = "";
                                } else {
                                    amountInput.value = amount.toFixed(2);
                                }
                            }

                            </script>



                                
                                                                                     
                                          
                                          
                        
                        <!-- View Ledger Modal content-->
                            <div id="viewLedgerModal" class="modal fade" role="dialog">
                                <div class="modal-dialog">
                            
                                    <!-- Modal content-->
                                    <div class="modal-content">
                                        <div class="modal-header">
                                            <h4 class="modal-title">Ledger Details</h4>
                                        </div>
                                        <div class="modal-body">
                                            <div class="form-group">
                                                <label for="LedgerID">Ledger ID:</label>
                                                <input type="text" class="form-control" id="LedgerID" readonly>
                                            </div>
                                            <div class="form-group">
                                                <label for="viewPmntRfrnce">Payment Ref:</label>
                                                <input type="text" class="form-control" id="viewPmntRfrnce" readonly>
                                            </div>
                                            <div class="form-group">
                                                <label for="viewRsn">Reason:</label>
                                                <input type="text" class="form-control" id="viewRsn" readonly>
                                            </div>
                                            <div class="form-group">
                                                <label for="viewAmnt">Amount:</label>
                                                <input type="text" class="form-control" id="viewAmnt" readonly>
                                            </div>
                                            <div class="form-group">
                                                <label for="viewTpe">Type:</label>
                                                <input type="text" class="form-control" id="viewTpe" readonly>
                                            </div>
                                            <div class="form-group">
                                                <label for="viewNotes">Notes:</label>
                                                <textarea class="form-control" id="viewNotes" readonly></textarea>
                                            </div>
                                            <div class="form-group">
                                                <label for="viewRefundReason">Refund Reason:</label>
                                                <input type="text" class="form-control" id="viewRefundReason" readonly>
                                            </div>
                                            <div class="form-group">
                                                <label for="viewRefundRequested">Refund Requested:</label>
                                                <input type="text" class="form-control" id="viewRefundRequested" readonly>
                                            </div>
                                            <div class="form-group">
                                                <label for="viewRefundRequestAmount">Refund Requested Amount:</label>
                                                <input type="text" class="form-control" id="viewRefundRequestAmount" readonly>
                                            </div>
                                            <div class="form-group">
                                                <label for="viewRefundApproved">Refund Approved:</label>
                                                <input type="text" class="form-control" id="viewRefundApproved" readonly>
                                            </div>
                                            <div class="form-group">
                                                <label for="viewRefundAmount">Refund Amount:</label>
                                                <input type="text" class="form-control" id="viewRefundAmount" readonly>
                                            </div>
                                            <div id="refundSection" style="display: none;">
                                            <hr>
                                            <h4>Request Refund</h4>
                                            <div class="form-group">
                                                <label for="refundAmount">Enter Refund Amount:</label>
                                                <input type="number" class="form-control" id="refundAmount">
                                            </div>

                                            <div class="form-group">
                                                <label for="refundReason">Enter Refund Reason:</label>
                                                <textarea class="form-control" id="refundReason" rows="3"></textarea>
                                            </div>

                                            <br>
                                            <button type="button" class="btn btn-success" id="submitRefundButton"
                                                data-refund-amount="<?php echo $refundAmount; ?>"
                                                data-refund-reason="<?php echo $refundReason; ?>"
                                                data-ledger-id="<?php echo $LedgerID; ?>"
                                                data-userid="<?php echo $userid; ?>">Submit Refund Request</button>



                                        </div>

                                        </div>
                                        <div class="modal-footer">
                                            <button type="button" class="btn btn-danger waves-effect waves-light" data-dismiss="modal">Close</button>
                                            <button type="button" class="btn btn-info waves-effect waves-light" id="requestRefundButton">Request Refund</button>
                                        </div>

                                    </div>
                            
                                </div>
                            </div>


                            
                            <!-- Edit Ledger Modal content-->
                            <div id="editLedgerModal" class="modal fade" role="dialog">
                                <div class="modal-dialog">
                                    <!-- Modal content-->
                                    <div class="modal-content">
                                        <div class="modal-header">
                                            <h4 class="modal-title">Edit Ledger</h4>
                                        </div>
                                        <form id="editLedgerForm">
                                            <input type="hidden" id="editLedgerId" name="ledgerId"> <!-- Hidden input for ledger ID -->

                                            <div class="modal-body">
                                                <div class="form-group">
                                                    <label for="editPmntRfrnce">Payment Ref:</label>
                                                    <input type="text" class="form-control" id="editPmntRfrnce" name="pmntRfrnce">
                                                </div>
                                                <div class="form-group">
                                                    <label for="editRsn">Reason:</label>
                                                    <input type="text" class="form-control" id="editRsn" name="rsn">
                                                </div>
                                                <div class="form-group">
                                                    <label for="editAmnt">Amount:</label>
                                                    <input type="text" class="form-control" id="editAmnt" name="amnt">
                                                </div>
                                                <div class="form-group">
                                                    <label for="editTpe">Type:</label>
                                                    <select class="form-control" id="editTpe" name="tpe">
                                                    <option value="0" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px"> Initial fee (IP1)</option><option value="1" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Full and final paid</option><option value="2" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Fund for full and final</option><option value="3" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Ad-hoc payment for client (eg N245)</option><option value="4" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Other payment received</option><option value="5" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Other payment made</option><option value="6" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Partial Initial Payment</option><option value="7" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Management fee</option><option value="8" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Write-off fund</option><option value="9" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Bond</option><option value="10" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Creditor setup fee</option><option value="11" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Late Payment Fee</option><option value="12" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Fund for token payment</option><option value="14" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Annual review fee</option><option value="16" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Set-up fee instalment</option><option value="13" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Second Initial Payment (IP2)</option><option value="15" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Third Initial Payment (IP3)</option><option value="17" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Fourth Initial Payment (IP4)</option><option value="18" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Fifth Initial Payment (IP5)</option><option value="19" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">FAF Payment</option><option value="20" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Add Creditor Payment</option><option value="21" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">APF Payment</option><option value="22" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">PAYE Rebate Refund</option><option value="23" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Rebate HMRC Funds In</option><option value="24" speechify-initial-font-family="&quot;Open Sans&quot;, Arial, sans-serif" speechify-initial-font-size="14px">Rebate Fee</option>                             </select>

                                                    </select>
                                                </div>
                                                <div class="form-group">
                                                    <label for="editNotes">Notes:</label>
                                                    <textarea class="form-control" id="editNotes" name="notes"></textarea>
                                                </div>
                                            </div>
                                            <div class="modal-footer">
                                                <button type="button" class="btn btn-danger waves-effect waves-light" data-dismiss="modal">Close</button>
                                                <button type="submit" class="btn btn-success" id="saveButton">Save Changes</button>

                                            </div>
                                        </form>
                                    </div>
                                </div>
                            </div>
                            
                            <!-- Delete Confirmation Modal -->
                            <div id="deleteLedgerModal" class="modal fade" role="dialog">
                                <div class="modal-dialog">
                                    <div class="modal-content">
                                        <div class="modal-header">
                                            <h4 class="modal-title">Confirmation</h4>
                                        </div>
                                        <div class="modal-body">
                                            <p>Are you sure you want to delete this ledger entry?</p>
                                            <!-- Hidden input for ledger ID -->
                                            <input type="hidden" id="deleteLedgerId" value="<?= htmlspecialchars($entry['id']) ?>">

                                        </div>
                                        <div class="modal-footer">
                                            <button type="button" class="btn btn-default" data-dismiss="modal">No</button>
                                            <button type="button" class="btn btn-danger" onclick="deleteLedgerEntry($('#deleteLedgerId').val())">Yes</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            
                            
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                    
                    
                    
                    <!-- Sidebar for total and buttons -->
                    <div class="sidebar">
                        <!-- Total Collect -->
                        <<div class="total-collect">
                            <h2>Total Collected</h2>
                            <style>
                                #totalAmount {
                                    font-size: 28px; /* or you can use a specific size like 1.5em or 24px */
                                    font-weight: bold;
                                }
                            </style>

                            <center><p id="totalAmount">£<?php echo number_format($total_amount, 2); ?></p></center>
                            <!-- Calculating and displaying total amount should be done by PHP script -->
                        </div>

                        <!-- Add this part -->
                        <div class="auth-rate">
                            <h2>Authorization Rate</h2>
                            <style>
                                #authRate {
                                    font-size: 28px; /* or you can use a specific size like 1.5em or 24px */
                                    font-weight: bold;
                                }
                            </style>
                            <center><p id="authRate"><?php echo number_format($authPercentage, 2); ?>%</p></center>
                        </div>

                        <!-- Buttons -->
                        <!-- Buttons -->
                        <div class="buttons">
                            <div class="button-row">
                                <button id="autoPaymentButton" type="button" class="btn btn-success waves-effect waves-light"
                                        onclick="disableButtonTemporarily()">
                                    <i class="bx bx-credit-card font-size-16 align-middle me-2"></i> Auto Payment
                                </button>


                            </div>

                            <div id="loading" style="display: none;">
                                <img src="Spinner-1s-200px (1).gif" alt="Loading...">
                            </div>

                            <?php
                                            if ($section === 'Management') {
                                                // Display the buttons only for Management section
                                                echo '
                            <div class="button-row">
                            <button type="button" class="btn btn-success waves-effect waves-light" data-toggle="modal" data-target="#createLedgerModal">
                                <i class="bx bx-list-plus font-size-16 align-middle me-2"></i> Create Ledger
                            </button>
                        </div>
                        ';
                                            }
                                            ?>                         
                        

                            <div class="button-row">
                                <button id="adhocPaymentButton" type="button" class="btn btn-success waves-effect waves-light">
                                    <i class="bx bxs-credit-card font-size-16 align-middle me-2"></i> Ad-Hoc Payment
                                </button>
                            </div>

                            <div class="button-row">
                                <button id="LatePaymentButton" type="button" class="btn btn-success waves-effect waves-light">
                                    <i class="bx bxs-credit-card font-size-16 align-middle me-2"></i> Late Payment Fee
                                </button>
                            </div>

                            <div class="button-row">
                                <button id="FullandFinalPaymentButton" type="button" class="btn btn-success waves-effect waves-light">
                                    <i class="bx bxs-credit-card font-size-16 align-middle me-2"></i> Full and Final Fee
                                </button>
                            </div>

                            


                            <div class="button-row">
                                <button type="button" class="btn btn-success waves-effect waves-light" data-toggle="modal" data-target="#oneTimeCardPaymentModal">
                                    <i class="bx bxs-credit-card font-size-16 align-middle me-2"></i>One Time Card Payment
                                </button>
                            </div>
                            

                            <div class="button-row">
                                <button type="button" class="btn btn-warning waves-effect waves-light" data-toggle="modal" data-target="#paylink_card_payment_modal">
                                    <i class="bx bx-link-external font-size-16 align-middle me-2"></i> Request Payment Link
                                </button>
                            </div>
                        
                        <div class="button-row">
                                <button type="button" class="btn btn-info waves-effect waves-light" data-toggle="modal" data-target="#requestBoodilLinkModal">
                                    <i class="bx bx-link-external font-size-16 align-middle me-2"></i> Request Boodil Link
                                </button>
                            </div>
                        </div>
                        
                       
                        
                        
                        
                        <div class="col-xl-12" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                        <div class="card" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                            <div class="card-body" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                <h4 class="card-title mb-4" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="15px">IP Workflows</h4>
                                
                                <form id="WorkflowForm" action="/client/Updates/create_workflow.php" method="post">
                                <label>Select Workflow</label>
                                <select class="form-select" name="workflow_nme">
                                            <option value="" speechify-initial-font-family="Arial, sans-serif" speechify-initial-font-size="14px">Choose a workflow</option>
                                            <option value="ldgr.ip1.payed" speechify-initial-font-family="Arial, sans-serif" speechify-initial-font-size="14px">IP1 Workflow</option>
                                            <option value="ldgr.ip2.payed" speechify-initial-font-family="Arial, sans-serif" speechify-initial-font-size="14px">IP2 Workflow</option>
                                            <option value="ldgr.ip3.payed" speechify-initial-font-family="Arial, sans-serif" speechify-initial-font-size="14px">IP3 Workflow</option>
                                            <option value="ldgr.ip4.payed" speechify-initial-font-family="Arial, sans-serif" speechify-initial-font-size="14px">IP4 Workflow</option>
                                            <option value="ldgr.ip5.payed" speechify-initial-font-family="Arial, sans-serif" speechify-initial-font-size="14px">IP5 Workflow</option>
                                            <option value="ldgr.APF.payed" speechify-initial-font-family="Arial, sans-serif" speechify-initial-font-size="14px">APF Workflow</option>
                                            <option value="ldgr.r2.payed" speechify-initial-font-family="Arial, sans-serif" speechify-initial-font-size="14px">Review Workflow</option>
                                        </select>
                                    <br>    
                                        <label>Reference Number</label>
                                        <input class="form-control" type="hidden" name="cse" id="cse" value="<?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?>" readonly>
                                        <br>
                                        <button type="submit" class="btn btn-success">Submit Workflow</button>
                                    </form>
                                    
                                    <br>
                                    <div id="alertPlaceholder"></div>



                                </div>
                            </div>



<!-- Include jQuery -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

<!-- Include Bootstrap JavaScript -->
<script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>

<script>
let ledgerEntries = <?php echo json_encode($ledgerEntries); ?>;


let total = ledgerEntries.reduce((acc, entry) => acc + parseFloat(entry['amnt'] || 0), 0);
document.getElementById('totalAmount').textContent = '£' + total.toFixed(2);


$(document).ready(function() {
    $('#ledgerForm').on('submit', function(e) {
        e.preventDefault();
        
        var formData = $(this).serialize();
        var clientID = '<?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?>'; 
        var userID = <?php echo json_encode($userid); ?>; // PHP code to print the user ID
        
        formData += "&clientID=" + encodeURIComponent(clientID) +
                    "&userID=" + encodeURIComponent(userID);

        $.ajax({
            url: 'Updates/create_ledger.php',
            type: 'POST',
            data: formData,
            dataType: 'json', // Expecting JSON response
            success: function(data) {
                if(data.status === 'success') {
                    // Optionally, use local storage to pass the alert message
                    localStorage.setItem('ledgerSuccess', 'Data saved successfully!');
                    // Redirect to Ledger_List.php
                    window.location.href = 'Ledger_List.php?client_id=<?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?>';
                } else {
                    // Optionally, use local storage to pass the error message
                    localStorage.setItem('ledgerError', data.message);
                    window.location.href = 'Ledger_List.php?client_id=<?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?>';
                }
            },
            error: function(jqXHR, textStatus, errorThrown) {
                console.error('Error occurred: ' + textStatus, errorThrown);
                alert('An error occurred while processing your request.');
            }
        });
    }); // This closes the click event listener
}); 

$(document).ready(function() {
    $('#WorkflowForm').on('submit', function(e) {
        e.preventDefault(); // Prevent the default form submission
        
        var formData = $(this).serialize(); // Serialize the form data
        
        // ... your code to add clientID and userID if necessary
        
        // Perform the Ajax request
        $.ajax({
            url: '/client/Updates/create_workflow.php',
            type: 'POST',
            data: formData,
            dataType: 'json', // Expecting a JSON response
            success: function(data) {
                // Handle the JSON response here
                if(data.status === 'success') {
                    // Display success banner
                    $('#alertPlaceholder').html('<div class="alert alert-success" role="alert">Workflow Accepted</div>');
                } else {
                    // Display error banner
                    $('#alertPlaceholder').html('<div class="alert alert-warning" role="alert">' + data.message + '</div>');
                }
            },
            error: function(jqXHR, textStatus, errorThrown) {
                // Handle any errors here
                console.error('Error occurred: ' + textStatus, errorThrown);
                $('#alertPlaceholder').html('<div class="alert alert-danger" role="alert">An error occurred while processing your workflow.</div>');
            }
        });
    });
});

var typeNames = <?php echo json_encode($typeNames); ?>;

// JavaScript code to handle "View Details" button click
    function viewLedgerDetails(ledgerId) {
        // Find the ledger entry with the matching ID
        const ledgerEntry = ledgerEntries.find(entry => entry.id == ledgerId);

        // Populate the modal fields with ledger details
        $('#LedgerID').val(ledgerEntry.id || '');
        $('#viewPmntRfrnce').val(ledgerEntry.pmntRfrnce || '');
        $('#viewRsn').val(ledgerEntry.rsn || '');
        $('#viewAmnt').val('£' + parseFloat(ledgerEntry.amnt || 0).toFixed(2));
        $('#viewTpe').val(typeNames[ledgerEntry.tpe] || 'Unknown Type');
        $('#viewNotes').val(ledgerEntry.notes || '');
        $('#viewRefundReason').val(ledgerEntry.rfnd_rqst_rsn || '');
        $('#viewRefundRequested').val(ledgerEntry.rfnd_rqst_whn || '');
        $('#viewRefundApproved').val(ledgerEntry.rfnd_rqst_aprvd_whn || '');
        $('#viewRefundAmount').val(ledgerEntry.rfnd_rqst_aprvd_amnt || '');
        $('#viewRefundRequestAmount').val(ledgerEntry.rfnd_rqst_amount || '');

        // Show the modal
        $('#viewLedgerModal').modal('show');
    }

    // Attach click event handlers to "View Details" buttons
    $('.view-ledger-details').click(function() {
        const ledgerId = $(this).data('ledger-id');
        viewLedgerDetails(ledgerId);
    });



// JavaScript code to handle "View Details" button click
function editLedgerDetails(ledgerId) {
    // Find the ledger entry with the matching ID
    const ledgerEntry = ledgerEntries.find(entry => entry.id == ledgerId);

    // Populate the modal fields with ledger details
    $('#editLedgerId').val(ledgerId); // Set the hidden input field with the ledger ID
    $('#editPmntRfrnce').val(ledgerEntry.pmntRfrnce || '');
    $('#editRsn').val(ledgerEntry.rsn || '');
    $('#editAmnt').val('£' + parseFloat(ledgerEntry.amnt || 0).toFixed(2));
    
    // Set the selected option in the 'editTpe' select element
    const selectedType = typeNames[ledgerEntry.tpe] || 'Unknown Type';
    $('#editTpe option').each(function () {
        if ($(this).text() === selectedType) {
            $(this).prop('selected', true);
        } else {
            $(this).prop('selected', false);
        }
    });
    
    $('#editNotes').val(ledgerEntry.notes || '');

    // Show the modal
    $('#editLedgerModal').modal('show');
}


// Attach click event handlers to "View Details" buttons
$('.edit-btn').click(function() {
    const ledgerId = $(this).data('ledger-id');
    editLedgerDetails(ledgerId);
});

// JavaScript code to handle "Save" button click
function saveLedgerDetails() {
    // Get the updated values from the modal
    const updatedLedgerId = $('#editLedgerId').val(); // Get the ledger ID from the hidden input field
    const updatedPmntRfrnce = $('#editPmntRfrnce').val();
    const updatedRsn = $('#editRsn').val();
    const updatedAmnt = parseFloat($('#editAmnt').val().replace('£', '')); // Remove '£' and parse as float
    const updatedTpe = $('#editTpe').val();
    const updatedNotes = $('#editNotes').val();

    // Create a data object to send in the POST request
    const data = {
        ledgerId: updatedLedgerId, // Include the ledger ID
        pmntRfrnce: updatedPmntRfrnce,
        rsn: updatedRsn,
        amnt: updatedAmnt,
        tpe: updatedTpe,
        notes: updatedNotes,
        
    };

    $.ajax({
        url: '/client/Updates/update_ledger.php', // Replace with the actual URL of your script
        type: 'POST',
        data: data,
        success: function(response) {
            // Handle the success response from the server
            console.log('Data saved successfully:', response);
            // Close the modal or perform any other actions as needed
            $('#editLedgerModal').modal('hide');
            
            // Reload the page to reflect the changes
            location.reload();
        },
        error: function(xhr, status, error) {
            // Handle errors, if any
            console.error('Error:', error);
        }
    });
}

// Attach click event handler to the "Save" button
$('#saveButton').click(function() {
    saveLedgerDetails();
});

//// Delete Modal

// JavaScript code to handle "View Details" button click
function deleteLedgerDetails(ledgerId) {
    // Find the ledger entry with the matching ID
    const ledgerEntry = ledgerEntries.find(entry => entry.id == ledgerId);

    // Populate the modal fields with ledger details
    $('#deleteLedgerId').val(ledgerId); // Set the hidden input field with the ledger ID

    // Show the modal
    $('#deleteLedgerModal').modal('show');
}

// Attach click event handlers to "View Details" buttons
$('.delete-btn').click(function() {
    const ledgerId = $(this).data('ledger-id');
    deleteLedgerDetails(ledgerId);
});

function deleteLedgerEntry(ledgerId) {
    // Find the ledger entry with the matching ID
    const deleteLedgerId = $('#deleteLedgerId').val();
    
    // Create a FormData object and append any form data you want to send
    var formData = new FormData();
    formData.append('deleteLedgerId', deleteLedgerId); // Add the deleteLedgerId
    formData.append('clientID', <?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?>); // Add clientID using PHP
    formData.append('userID', <?php echo json_encode($userid); ?>); // Add userID using PHP

    $.ajax({
        url: '/client/Updates/delete_ledger.php', // Replace with the actual URL of your script
        type: 'POST',
        data: formData, // Send the FormData object as data
        processData: false, // Prevent jQuery from processing the data
        contentType: false, // Set the content type to false to let jQuery set it based on the FormData
        success: function(response) {
            // Handle the success response from the server (e.g., reload the page or update the UI)
            console.log('Ledger entry deleted successfully:', response);

            // Optionally, remove the deleted entry from the UI
            // For example, you can find the corresponding DOM element and remove it from the list
            // Example:
            // $('#ledgerEntry' + ledgerId).remove();

            // Close the delete confirmation modal
            $('#deleteLedgerModal').modal('hide');
        },
        error: function(xhr, status, error) {
            // Handle errors, if any
            console.error('Error:', error);
        }
    });
}
//// End Delete Modal

$(document).ready(function () {
        $('#paymentType').change(function () {
            $('#ipPaymentSelection').show();
        });

        $('#submitPayment').click(function () {
            // Retrieve selected values and perform the payment process
            var paymentType = $('#paymentType').val();
            var ipPayment = $('#ipPayment').val();

            // Implement your payment logic here
            // You can send the selected values to your server for processing
            // Example: $.post('process_payment.php', { paymentType: paymentType, ipPayment: ipPayment }, function(response) { /* handle response */ });
        });
    });

    document.getElementById('submitPaymentInfo').addEventListener('click', function() {
    // Get the form data
    var paymentType = document.getElementById('paymentType').value;
    var ipPayment = document.getElementById('ipPayment').value;
    var cardName = document.getElementById('cardName').value;
    var cardNumber = document.getElementById('cardNumber').value;
    var expiryDate = document.getElementById('expiryDate').value;
    var cvv = document.getElementById('cvv').value;
    var amount = document.getElementById('amount').value;
    
    // Capture the cardtype from the form
    var cardtype = document.getElementById('cardtype').value;

    // You can perform any necessary validation here

    // Create an object to hold the form data
    var clientID = '<?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?>'; 
    var userID = <?php echo json_encode($userid); ?>; // PHP code to print the user ID
    
    var formData = {
        paymentType: paymentType,
        ipPayment: ipPayment,
        cardName: cardName,
        cardNumber: cardNumber,
        expiryDate: expiryDate,
        cvv: cvv,
        amount: amount,
        cardtype: cardtype,
        clientID: clientID,
        userID: userID
    };


    // Perform AJAX request to submit the form data
    // You can use XMLHttpRequest or a library like jQuery.ajax here
    // Example with jQuery.ajax:
    $.ajax({
        type: 'POST',
        url: '/client/Updates/process-payment',
        data: formData,
        success: function(response) {
            // Handle the response here (e.g., display a message to the user)
            console.log(response);
        },
        error: function() {
            // Handle any errors if needed
        }
    });
});

// Define or set the 'id' variable here
var id = <?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?>; // Echo the PHP variable

// JavaScript code to add a click event listener to the button
document.addEventListener('DOMContentLoaded', function () {
    var autoPaymentButton = document.getElementById('autoPaymentButton');
    
    if (autoPaymentButton) {
        autoPaymentButton.addEventListener('click', function () {
            // Call the makePayment function or add the payment logic here
            makePayment();
        });
    }
});
// Function to display the modal
function showModal(message, waitTime) {
    // Remove any existing modal to avoid duplicates
    let existingModal = document.getElementById('paymentModal');
    if (existingModal) {
        existingModal.remove();
    }

    // Create the modal content dynamically
    let modalContent = `
        <div id="paymentModal" class="modal fade" role="dialog" tabindex="-1" aria-hidden="true">
            <div class="modal-dialog">
                <!-- Modal content -->
                <div class="modal-content">
                    <div class="modal-header">
                        <h4 class="modal-title">Unable to Process</h4>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close" onclick="closeModal()">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                    <div class="modal-body">
                        <p>${message}</p>
                        <p>Wait time: ${waitTime}</p>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-danger" data-dismiss="modal" onclick="closeModal()">Close</button>
                    </div>
                </div>
            </div>
        </div>
    `;

    // Append the modal content to the body
    document.body.insertAdjacentHTML('beforeend', modalContent);

    // Initialize and show the Bootstrap modal
    $('#paymentModal').modal('show');
}

// Function to close the modal
function closeModal() {
    $('#paymentModal').modal('hide'); // Hide the Bootstrap modal
    let modal = document.getElementById('paymentModal');
    if (modal) {
        modal.remove(); // Remove modal from DOM after hiding
    }
}


function makePayment() {
    // Display the loading spinner
    document.getElementById('loading').style.display = 'block';

    let userId = '<?php echo isset($_SESSION['id']) ? $_SESSION['id'] : 0; ?>';

    // First, check if payment can be processed
    $.ajax({
        type: "GET",
        url: `https://cmlpay.co.uk/Check_v3.php?case_id=${id}`,
        dataType: "json", // Ensure response is handled as JSON
        success: function(data) {
            if (data.status === 'Yes') {
                // If the status is Yes, proceed to PaymentsDueV3.php
                $.ajax({
                    type: "POST",
                    url: `https://cmlpay.co.uk/PaymentsDueV3.php?id=${id}&userId=${userId}`,
                    success: function(response) {
                        // Handle the response if needed
                        console.log("Payment successful", response);

                        // Hide the loading spinner
                        document.getElementById('loading').style.display = 'none';

                        // Refresh the current screen after the delay
                        setTimeout(function() {
                            location.reload(true);
                        }, 4000); // Adjust the delay time as needed
                    },
                    error: function(error) {
                        // Handle the error if needed
                        console.error("Payment error", error);

                        // Hide the loading spinner
                        document.getElementById('loading').style.display = 'none';
                    }
                });
            } else {
                // If status is No, display a modal with the message and wait_time
                document.getElementById('loading').style.display = 'none';
                showModal(data.message, data.wait_time);
            }
        },
        error: function(error) {
            console.error("Error checking payment eligibility", error);

            // Hide the loading spinner
            document.getElementById('loading').style.display = 'none';

            // Optionally, handle this error (e.g., display an error modal or message)
        }
    });
}




// Define or set the 'id' variable here
var id = <?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?>; // Echo the PHP variable

// JavaScript code to add a click event listener to the button
document.addEventListener('DOMContentLoaded', function () {
    var adhocPaymentButton = document.getElementById('adhocPaymentButton');
    
    if (adhocPaymentButton) {
        adhocPaymentButton.addEventListener('click', function () {
            // Call the makePayment function or add the payment logic here
            adhocmakePayment();
        });
    }
});

$(document).ready(function() {
    // Event handler for opening the modal when the button is clicked
    $('#adhocPaymentButton').click(function() {
        $('#adhocPaymentModal').modal('show');
    });

    // Event handler for submitting the ad-hoc payment
    $('#submitAdhocPayment').click(function() {
        const amount = $('#adhocPaymentAmount').val(); // Get the entered amount from the input field
        adhocmakePayment(amount);
    });

    function adhocmakePayment(amount) {
        // Display the loading spinner
        document.getElementById('loadingnew').style.display = 'block';

        // Simulate a delay of 4 seconds (4000 milliseconds)
        setTimeout(function() {
            // Make an AJAX request to the payment URL with the amount as a POST parameter
            $.ajax({
                type: "POST",
                url: `https://cmlpay.co.uk/Ad-HocV3.php?id=${id}&amount=${amount}`,
                data: { amount: amount }, // Include the amount as a POST parameter
                success: function(response) {
                    // Handle the response if needed
                    console.log("Payment successful", response);

                    // Hide the loading spinner
                    document.getElementById('loadingnew').style.display = 'none';

                    // Refresh the current screen after the delay
                    location.reload(); // Refresh the page
                },
                error: function(error) {
                    // Handle the error if needed
                    console.error("Payment error", error);

                    // Hide the loading spinner
                    document.getElementById('loadingnew').style.display = 'none';
                     location.reload(); // Refresh the page
                }
            });
        }, 4000); // Adjust the delay time as needed

    }
});


// Define or set the 'id' variable here
var id = <?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?>; // Echo the PHP variable

// JavaScript code to add a click event listener to the button
document.addEventListener('DOMContentLoaded', function () {
    var LatePaymentButton = document.getElementById('LatePaymentButton');
    
    if (LatePaymentButton) {
        LatePaymentButton.addEventListener('click', function () {
            // Call the makePayment function or add the payment logic here
            adhocmakePayment();
        });
    }
});

$(document).ready(function() {
    // Event handler for opening the modal when the button is clicked
    $('#LatePaymentButton').click(function() {
        $('#LatePaymentModal').modal('show');
    });

    // Event handler for submitting the ad-hoc payment
    $('#submitLatePayment').click(function() {
        const amount = $('#LatePaymentAmount').val(); // Get the entered amount from the input field
        LatemakePayment(amount);
    });

    function LatemakePayment(amount) {
        // Display the loading spinner
        document.getElementById('loadingnew').style.display = 'block';

        // Simulate a delay of 4 seconds (4000 milliseconds)
        setTimeout(function() {
            // Make an AJAX request to the payment URL with the amount as a POST parameter
            $.ajax({
                type: "POST",
                url: `https://cmlpay.co.uk/LatePaymentV3.php?id=${id}&amount=${amount}`,
                data: { amount: amount }, // Include the amount as a POST parameter
                success: function(response) {
                    // Handle the response if needed
                    console.log("Payment successful", response);

                    // Hide the loading spinner
                    document.getElementById('loadingnew').style.display = 'none';

                    // Refresh the current screen after the delay
                    location.reload(); // Refresh the page
                },
                error: function(error) {
                    // Handle the error if needed
                    console.error("Payment error", error);

                    // Hide the loading spinner
                    document.getElementById('loadingnew').style.display = 'none';
                     location.reload(); // Refresh the page
                }
            });
        }, 4000); // Adjust the delay time as needed

    }
});


// Define or set the 'id' variable here
var id = <?php echo isset($_GET['client_id']) ? htmlspecialchars($_GET['client_id']) : ''; ?>; // Echo the PHP variable

// JavaScript code to add a click event listener to the button
document.addEventListener('DOMContentLoaded', function () {
    var FullandFinalPaymentButton = document.getElementById('FullandFinalPaymentButton');
    
    if (FullandFinalPaymentButton) {
        FullandFinalPaymentButton.addEventListener('click', function () {
            // Call the makePayment function or add the payment logic here
            adhocmakePayment();
        });
    }
});

$(document).ready(function() {
    // Event handler for opening the modal when the button is clicked
    $('#FullandFinalPaymentButton').click(function() {
        $('#FullandFinalPaymentModal').modal('show');
    });

    // Event handler for submitting the ad-hoc payment
    $('#submitFullandFinalPayment').click(function() {
        const amount = $('#FullandFinalPaymentAmount').val(); // Get the entered amount from the input field
        FullandFinalmakePayment(amount);
    });

    function FullandFinalmakePayment(amount) {
        // Display the loading spinner
        document.getElementById('loadingnew').style.display = 'block';

        // Simulate a delay of 4 seconds (4000 milliseconds)
        setTimeout(function() {
            // Make an AJAX request to the payment URL with the amount as a POST parameter
            $.ajax({
                type: "POST",
                url: `https://cmlpay.co.uk/FullandFinalV3.php?id=${id}&amount=${amount}`,
                data: { amount: amount }, // Include the amount as a POST parameter
                success: function(response) {
                    // Handle the response if needed
                    console.log("Payment successful", response);

                    // Hide the loading spinner
                    document.getElementById('loadingnew').style.display = 'none';

                    // Refresh the current screen after the delay
                    location.reload(); // Refresh the page
                },
                error: function(error) {
                    // Handle the error if needed
                    console.error("Payment error", error);

                    // Hide the loading spinner
                    document.getElementById('loadingnew').style.display = 'none';
                     location.reload(); // Refresh the page
                }
            });
        }, 4000); // Adjust the delay time as needed

    }
});





// JavaScript code
document.getElementById('requestRefundButton').addEventListener('click', function() {
    // Show the refund section
    document.getElementById('refundSection').style.display = 'block';
});

// Add an event listener for the "Submit Refund Request" button here, and handle the database update.

$(document).ready(function() {
    $('#submitRefundButton').click(function() {
        // Retrieve the data attributes from the button
        var refundAmount = $(this).data('refund-amount');
        var refundReason = $(this).data('refund-reason');
        var LedgerID = $(this).data('ledger-id');
        var userid = $(this).data('userid');
        
        // Retrieve the refund amount from the input field within the modal
        var refundAmountInput = $('#refundAmount').val();
        var refundReasonInput = $('#refundReason').val();
        var ledgerIdInput = $('#LedgerID').val();
        
        // Create a data object to send with the POST request
        var data = {
            refundAmount: refundAmountInput,
            refundReason: refundReasonInput,
            LedgerID: ledgerIdInput,
            userid: userid
        };

        // Send a POST request to your PHP script
        $.ajax({
            type: 'POST',
            url: '/client/Updates/refund_request.php', // Replace with the actual URL of your PHP script
            data: data,
            success: function(response) {
                // Handle the response from the server
                console.log(response); // You can remove this line or use it for debugging
                
                // Close the modal
                $('#viewLedgerModal').modal('hide');
                
                // Display the success message
                $('#successMessage').html('<div class="alert alert-success" role="alert">Refund Requested</div>');
            },
            error: function(xhr, status, error) {
                // Handle errors if the POST request fails
                console.error(xhr.responseText);
            }
        });
    });
});

function submitPaymentLink() {
    // Extract $id from the URL query parameters
    var searchParams = new URLSearchParams(window.location.search);
    var idParam = <?php echo $id; ?>;
    
    // Validate $id (optional)
    if (!idParam) {
        alert("Invalid or missing $id in the URL.");
        return;
    }
    
    var amount = document.getElementById("payment_amount").value;

    // Validate amount
    if (!/^\d+(\.\d{1,2})?$/.test(amount)) {
        alert("Invalid amount format. Please enter a valid amount up to 2 decimal places.");
        return;
    }

    // Send a new payment link without checking if it was sent today
    var url = "https://hooks.zapier.com/hooks/catch/13770498/3ozt76q/?submit&ref=" + idParam + "&amount=" + amount;
    fetch(url)
        .then(function(response) {
            if(response.ok) {
                alert("Payment link sent successfully!");
            } else {
                throw new Error("Failed to send payment link");
            }
        })
        .catch(function(error) {
            alert(error.message);
        });

    $('#paylink_card_payment_modal').modal('hide');

    // Reload the page
    window.location.reload();
}

$(document).ready(function () {
    $("#requestBoodilLinkForm").submit(function (event) {
        event.preventDefault();

        var formData = {
            amount: $("#amountbroo").val(),
            cse: $("#cse").val()
        };

        // Show the success message immediately
        $(".alert-success").text("A Boodil Link has been sent to the client").show();

        // Submit the AJAX request in the background
        $.ajax({
            type: "POST",
            url: "/client/Updates/Send_Boodil_Link.php", // Replace with your server-side script URL
            data: formData,
            dataType: "json",
            success: function (response) {
                // Handle the response from the server here
                console.log(response);

                // You can still handle the server response if needed, but it won't affect the success message and page reload
            },
            error: function (xhr, status, error) {
                console.error(xhr.responseText);
                // Handle the error here if needed
            }
        });

        // Reload the page after a 2-second delay
        setTimeout(function () {
            window.location.reload();
        }, 1000); // 2000 milliseconds = 2 seconds
    });
});




</script>

</body>
</html>
