<?php
session_start();

// If session variable 'username' is not set or is 'Guest', redirect to login page
if (!isset($_SESSION['username']) || $_SESSION['username'] === "Guest") {
    header("Location: /login.php");
    exit();
}

// Check if the session is inactive for more than 10 seconds
if (isset($_SESSION['last_activity']) && (time() - $_SESSION['last_activity'] > 900)) {
    // Session has been inactive for more than 10 seconds
    session_unset();     // Unset $_SESSION variable for the run-time
    session_destroy();   // Destroy the session data on the server
    header("Location: /login.php"); // Redirect to login page
    exit(); // Ensure no further execution of the script
}

// Update last activity time stamp
$_SESSION['last_activity'] = time();

$username = $_SESSION['username']; // Username is already checked above and is not 'Guest'

// Check if 'client_id' is in the URL query parameter
if (isset($_GET['client_id'])) {
    // Store the 'client_id' from the URL in a variable
    $id = $_GET['client_id'];
} else {
    // Set a default value or handle the case where 'client_id' is not provided in the URL
    $id = 'default_value';
}
$username = isset($_SESSION['username']) ? $_SESSION['username'] : "Guest";
include_once '../config_current.php';

/// Get Username
$query = "SELECT nme, job_title FROM account_users WHERE email = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param('s', $username);
$stmt->execute();

$result = $stmt->get_result();
$row = $result->fetch_assoc();

if ($row) {
    $truename = $row['nme'];
    $jobtitle = $row['job_title'];
} else {
    $truename = "Unknown";
}

$stmt->close();

// Suppose 'case_details' is your table name and it contains relevant information about the case
$case_query = "SELECT * FROM client_core WHERE id = ?";
$case_stmt = $conn->prepare($case_query);
$case_stmt->bind_param('i', $id); // assuming client_id is an integer field
$case_stmt->execute();

$case_result = $case_stmt->get_result();
$case_details = $case_result->fetch_assoc(); // fetches the row as an associative array

// print_r($case_details); exit;

$case_stmt->close();

?>

<!DOCTYPE html>
<html>

<head>
    <title>Applicants | Case <?php echo $case_details['id']; ?></title>
    <?php include '../layouts/head.php'; ?>
    <?php include '../layouts/head-style.php'; ?>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.3.1/jquery.min.js"></script>
    <style>
        .container-card {
            display: flex;
            flex-wrap: wrap;
            /* Allow items to wrap on smaller screens */
            gap: 10px;
            /* Align items to the left */
            width: 100%;
        }

        /* Make both main container children flexible */
        .left-card,
        .column {
            flex: 1 1 600px;
            /* Grow and shrink with a minimum width */
        }

        /* Remove centering from the left card */
        .left-card {
            display: flex;
            justify-content: flex-start;
        }

        /* Use responsive card widths with a max-width limit */
        .card {
            background: white;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
            width: 100%;
            /* Card takes full width of its container */
        }

        /* Wide card: full width up to 700px */
        .wide-card {
            width: 100%;
        }

        /* Small cards: full width up to 450px */
        .small-card {
            width: 100%;
        }

        .card h2 {
            font-size: 18px;
            margin-bottom: 10px;
            padding-bottom: 5px;
            border-bottom: 2px solid #ddd;
        }

        .info {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 10px 0;
            border-bottom: 1px solid #ddd;
            font-size: 14px;
        }

        .info:last-child {
            border-bottom: none;
        }

        .error {
            color: red;
            font-weight: bold;
        }
    </style>
</head>

<body>
    <?php include '../layouts/body.php'; ?>
    <div id="layout-wrapper">
        <?php include 'layouts/vertical-menu.php'; ?>
        <div class="main-content">
            <div class="page-content">
                <div class="container-fluid">
                    <?php
                    // Assuming the value is stored in $client['alrt']
                    $alertMessage = $case_details['alert-client'] ?? ''; // Get the alert message from the database
                    ?>

                    <?php if (!empty($alertMessage)) : ?>
                        <div class="alert alert-danger alert-dismissible fade show" role="alert">
                            <i class="mdi mdi-alert-outline me-2"></i>
                            <?php echo htmlspecialchars($alertMessage); ?>
                            <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                        </div>
                    <?php endif; ?>
                    <div class="container-card">
                        <div class="left-card">
                            <div class="card wide-card">
                                <h2>Plan Details</h2>
                                <div class="info"><span style="font-weight:600;">CCR ID</span><span><?php echo htmlspecialchars($case_details['id'] ?? ''); ?></span></div>
                                    <div class="info"><span style="font-weight:600;">Client ID</span><span><?php echo htmlspecialchars($case_details['other-id'] ?? ''); ?></span></div>
                                <div class="info"><span style="font-weight:600;">Applicant 1</span><span><?php
                                                                                                            $fullname = trim(
                                                                                                                ($case_details['title-1'] ?? '') . ' ' .
                                                                                                                    ($case_details['forename-1'] ?? '') . ' ' .
                                                                                                                    ($case_details['surname-1'] ?? '')
                                                                                                            );
                                                                                                            echo htmlspecialchars($fullname) ?>
                                    </span></div>
                                <div class="info"><span style="font-weight:600;">Applicant 2</span><span> <?php
                                                                                                            $fullname = trim(
                                                                                                                ($case_details['title-2'] ?? '') . ' ' .
                                                                                                                    ($case_details['forename-2'] ?? '') . ' ' .
                                                                                                                    ($case_details['surname-2'] ?? '')
                                                                                                            );
                                                                                                            echo htmlspecialchars($fullname) ?></span></div>
                                <div class="info">
                                    <span style="font-weight:600;">Address</span>
                                    <span>
                                        <?php
                                        $address = $case_details['fulladdress'] ?? '';
                                        $address_without_postcode = preg_replace('/,\s*\b[A-Z]{1,2}\d{1,2}[A-Z]?\s?\d[A-Z]{2}\b/', '', $address);
                                        $address_without_postcode = preg_replace('/,\s*,/', ',', $address_without_postcode);
                                        $address_without_postcode = preg_replace('/,\s*$/', '', $address_without_postcode);
                                        echo htmlspecialchars($address_without_postcode);
                                        ?>
                                    </span>
                                </div>
                                <div class="info"><span style="font-weight:600;">Postcode</span><span><?php echo htmlspecialchars($case_details['pstCde'] ?? ''); ?></span></div>
                                <div class="info">
                                    <span style="font-weight:600;">Date Of Birth</span>
                                    <span>
                                        <?php
                                        $dob = $case_details['dteOfBrth-1'] ?? '';
                                        if ($dob) {
                                            // Create a DateTime object from the stored date (adjust 'Y-m-d' if your format is different)
                                            $dateObject = DateTime::createFromFormat('Y-m-d', $dob);
                                            if ($dateObject) {
                                                // Format the date as day/month/year, e.g. 03/02/2025
                                                echo htmlspecialchars($dateObject->format('d F, Y'));

                                                // Calculate the age
                                                $currentDate = new DateTime();
                                                $age = $currentDate->diff($dateObject)->y;
                                                echo " (Age: " . htmlspecialchars($age) . ")";
                                            } else {
                                                // Fallback: if the date does not match the expected format, output it unchanged.
                                                echo htmlspecialchars($dob);
                                            }
                                        }
                                        ?><br><?php
                                                $dob = $case_details['dteOfBrth-2'] ?? '';
                                                if ($dob) {
                                                    // Create a DateTime object from the stored date (adjust 'Y-m-d' if your format is different)
                                                    $dateObject = DateTime::createFromFormat('Y-m-d', $dob);
                                                    if ($dateObject) {
                                                        // Format the date as day/month/year, e.g. 03/02/2025
                                                        echo htmlspecialchars($dateObject->format('d F, Y'));

                                                        // Calculate the age
                                                        $currentDate = new DateTime();
                                                        $age = $currentDate->diff($dateObject)->y;
                                                        echo " (Age: " . htmlspecialchars($age) . ")";
                                                    } else {
                                                        // Fallback: if the date does not match the expected format, output it unchanged.
                                                        echo htmlspecialchars($dob);
                                                    }
                                                }
                                                ?>
                                    </span>
                                </div>
                                <div class="info"><span style="font-weight:600;">Contact Numbers</span><span><? echo htmlspecialchars($case_details['mblePhone-1'] ?? ''); ?><br><? echo htmlspecialchars($case_details['mblePhone-2'] ?? ''); ?></span></div>
                                <div class="info"><span style="font-weight:600;">Emails</span><span><? echo htmlspecialchars($case_details['emlAddrss-1'] ?? ''); ?><br><? echo htmlspecialchars($case_details['emlAddrss-2'] ?? ''); ?></span></div>
                                <div class="info"><span style="font-weight:600;">Plan Type</span><span><? echo htmlspecialchars($case_details['plan-type'] ?? ''); ?> Months</span></div>
                                <div class="info"><span style="font-weight:600;">Monthly Fee</span><span>£<? echo htmlspecialchars($case_details['monthly-fee'] ?? ''); ?></span></div>
                                <?
                                // Ensure values exist and are numeric to prevent calculation errors
                                $monthlyFee = isset($case_details['monthly-fee']) ? (float)$case_details['monthly-fee'] : 0;
                                $planType   = isset($case_details['plan-type']) ? (int)$case_details['plan-type'] : 0;

                                // Fetch Ledger Total Amount (Total Payments Taken)
                                $query = " SELECT SUM(`amount`) AS Ledger_totalAmount FROM `client_ledger` WHERE `cid` = ? AND `payment-status` = 'success' ";

                                $stmt = $conn->prepare($query);
                                $stmt->bind_param("i", $case_details['id']);
                                $stmt->execute();
                                $result = $stmt->get_result()->fetch_assoc();
                                $ledgerTotalAmount = $result['Ledger_totalAmount'] ?? 0; // Default to 0 if NULL
                                $stmt->close();

                                // Calculate expected due payment
                                $expecteddue = $monthlyFee * $planType;

                                // Calculate amount left to pay
                                $Left2PayPlan = $expecteddue - $ledgerTotalAmount;

                                ?>
                                <div class="info"><span style="font-weight:600;">Expected Payments Due (<? echo htmlspecialchars($case_details['plan-type'] ?? ''); ?> Months)</span><span>£<?= number_format($expecteddue, 2) ?? '0.00' ?></span></div>
                                <div class="info">
                                    <span style="font-weight:600;">Plan Payments Taken</span>
                                    <span>£<?= number_format($ledgerTotalAmount, 2) ?></span>
                                </div>
                                <div class="info"><span style="font-weight:600;">Left to Pay</span><span>£<?= number_format($Left2PayPlan, 2) ?></span></div>
                            </div>
                        </div>
                        <div class="column">
                            <div class="card small-card">
                                <h2>Payment Status</h2>
                                <div class="info">
                                    <span>Next Payment Date</span>
                                    <span>
                                        <?php
                                        echo !empty($case_details['nxt-py-dte'])
                                            ? htmlspecialchars(date("d F, Y", strtotime($case_details['nxt-py-dte'])))
                                            : 'N/A';
                                        ?>
                                    </span>
                                </div>
                                <div class="info"><span>Review Date</span><span> <?php
                                                                                    echo !empty($case_details['review-dte'])
                                                                                        ? htmlspecialchars(date("d F, Y", strtotime($case_details['review-dte'])))
                                                                                        : 'N/A';
                                                                                    ?></span></div>
                                <div class="info"><span>Welcome Call</span><span> <?php
                                                                                    echo !empty($case_details['courtesy-dte'])
                                                                                        ? htmlspecialchars(date("d F, Y", strtotime($case_details['courtesy-dte'])))
                                                                                        : 'N/A';
                                                                                    ?></span></div>
                                <div class="info"><span>Client Status</span><span>
                                        <?php
                                        $status = $case_details['clint-stts'] ?? '';
                                        switch ($status) {
                                            case 1:
                                                echo 'New';
                                                break;
                                            case 2:
                                                echo 'InReview';
                                                break;
                                            case 4:
                                                echo 'Cancelled';
                                                break;
                                            case 6:
                                                echo 'Completed';
                                                break;
                                            case 7:
                                                echo 'InProcess';
                                                break;
                                            default:
                                                echo htmlspecialchars($status);
                                                break;
                                        }
                                        ?>
                                    </span></div>
                            </div>
                            <div class="card small-card">
                                <table class="table table-bordered" style="width: 100%;">
                            <thead>
                                <tr>
                                    <th>Creditor</th>
                                    <th>Amount</th>
                                    <th>Status</th>
                                </tr>
                            </thead>
                            <tbody>
                                      <td></td>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

        </div>
</body>

</html>