<?php
// Enable full error reporting and on-screen error display
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Include your configuration file here
include_once '../config.php';

try {
    // Check if connection to the database was successful
    if ($conn->connect_error) {
        throw new Exception("Connection failed: " . $conn->connect_error);
    }

    // Query to select IDs from clients where Current_Status is 'Awaiting AML'
    $query = "SELECT id FROM clients WHERE Current_Status ='Awaiting AML'";
    $stmt = $conn->prepare($query);
    if (!$stmt) {
        throw new Exception("Prepare failed: (" . $conn->errno . ") " . $conn->error);
    }
    if (!$stmt->execute()) {
        throw new Exception("Execute failed: (" . $stmt->errno . ") " . $stmt->error);
    }
    $result = $stmt->get_result();

    while ($row = $result->fetch_assoc()) {
        $caseId = $row['id'];

        echo "Processing case ID: $caseId\n"; // Debugging output

        // Check if the ID exists in Veriphy_AML's cse column
        $veriphyQuery = "SELECT * FROM Veriphy_AML WHERE cse = ?";
        $stmtVeriphy = $conn->prepare($veriphyQuery);
        $stmtVeriphy->bind_param('s', $caseId);
        $stmtVeriphy->execute();
        $resultVeriphy = $stmtVeriphy->get_result();

        if ($resultVeriphy->num_rows == 0) {
            // ID not found in Veriphy_AML, run your Veriphy API code here

            // Separate mysqli_stmt object for the new prepared statement
            $stmtAPI = $conn->stmt_init();

            // Retrieve necessary data from the clients table
            $query = "SELECT * FROM clients WHERE id = ?";
            $stmtAPI->prepare($query);
            $stmtAPI->bind_param('i', $caseId);
            $stmtAPI->execute();
            $resultAPI = $stmtAPI->get_result();
            $caseData = $resultAPI->fetch_assoc();

            // Construct the API request payload
            $requestPayload = [
             "applicationTO" => [
                        "applicants" => [
                            [
                                "addresses" => [
                                    [
                                        "address1" => $caseData['Address_1'],
                                        "address2" => $caseData['Address_2'],
                                        "address3" => "",
                                        "address4" => "",
                                        "postTown" => $caseData['Town'],
                                        "county" => "",
                                        "postCode" => $caseData['Postcode'],
                                        "country" => "GB",
                                    ],
                                ],
                                "applicantId" => "",
                                "bankTO" => [
                                    "accountNumber" => "",
                                    "sortCode" => "",
                                ],
                                "contactTO" => [
                                    "telephoneNumber" => "",
                                    "alternativeTelephoneNumber" => "",
                                    "mobileTelephoneNumber" => "",
                                    "faxNumber" => "",
                                    "emailAddress" => "",
                                ],
                                "dateOfBirth" => $caseData['Date_Of_Birth'],
                                "driversLicenceTO" => [
                                    "licenceNumber1" => "",
                                    "licenceNumber2" => "",
                                    "licenceNumber3" => "",
                                    "licenceNumber4" => "",
                                ],
                                "gender" => "M",
                                "idCardTO" => [
                                    "line10" => "",
                                    "line1" => "",
                                    "line2" => "",
                                    "line3" => "",
                                    "line4" => "",
                                    "line5" => "",
                                    "line6" => "",
                                    "line7" => "",
                                    "line8" => "",
                                    "line9" => "",
                                ],
                                "internationalPassportTO" => [
                                    "passportNumber1" => "",
                                    "passportNumber2" => "",
                                    "passportNumber3" => "",
                                    "passportNumber4" => "",
                                    "passportNumber5" => "",
                                    "passportNumber6" => "",
                                    "passportNumber7" => "",
                                    "passportNumber8" => "",
                                    "passportNumber9" => "",
                                ],
                                "mothersMaidenName" => "",
                                "names" => [
                                    [
                                        "title" => $caseData['Title'],
                                        "forename" => $caseData['First_Name'],
                                        "otherNames" => "",
                                        "surname" => $caseData['Surname'],
                                    ],
                                ],
                                "nationalInsuranceNumber" => "",
                                "travelVisaTO" => [
                                    "line1" => "",
                                    "line2" => "",
                                    "line3" => "",
                                    "line4" => "",
                                    "line5" => "",
                                    "line6" => "",
                                    "line7" => "",
                                    "line8" => "",
                                    "line9" => "",
                                ],
                            ],
                        ],
                        "reference" => "Veriphy API Test",
                    ],
                    "authenticationTO" => [
                        "password" => "Un.89ah!jjob", // Replace with your Veriphy API password
                        "username" => "Clear_Start_LiveAPI", // Replace with your Veriphy API username
                    ],
                    "veriphyServiceTO" => [
                        "returnPDF" => true,
                        "serviceCode" => "IDAMLNOCRED",
                    ],
                ];

            // Convert the request payload to JSON
            $requestPayloadJson = json_encode($requestPayload);

            // Initialize cURL session
            $ch = curl_init();

            // Set cURL options
            curl_setopt($ch, CURLOPT_URL, 'https://secure.veriphy.co.uk/api/IDAML'); // Replace with the actual API endpoint
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $requestPayloadJson);
            curl_setopt($ch, CURLOPT_HTTPHEADER, [
                'Content-Type: application/json',
            ]);

            // Execute cURL request
            $response = curl_exec($ch);

            // Close cURL session
            curl_close($ch);

            // Save the response to the specified file path
            $responseFilePath = '/home/tpscmlsystemsco/public_html/logs/AMLresponse.txt';
            file_put_contents($responseFilePath, $response);

            // Output a message indicating the response was saved
            echo 'Response saved to ' . $responseFilePath;

            try {
                // Decode the JSON response
                $responseDataArray = json_decode($response, true);

                // Debugging: Output the decoded JSON for inspection
                echo '<pre>';
                print_r($responseDataArray);
                echo '</pre>';

                // Extract the data to be inserted
                $smartscore = isset($responseDataArray['responseResult']['Summary']['Smartscore']) ? $responseDataArray['responseResult']['Summary']['Smartscore'] : null;
                $resultText = isset($responseDataArray['responseResult']['Summary']['ResultText']) ? $responseDataArray['responseResult']['Summary']['ResultText'] : null;
                $veriphyCheckId = isset($responseDataArray['veriphyCheckId']) ? $responseDataArray['veriphyCheckId'] : null;
                $requestDateTime = date('Y-m-d H:i:s'); // Current date and time

                // Insert the data into the "Veriphy_AML" table
                $insertQuery = "INSERT INTO Veriphy_AML (Requested, Smartscore, ResultText, cse, veriphyCheckId) VALUES (?, ?, ?, ?, ?)";
                $stmtInsert = $conn->prepare($insertQuery);
                $stmtInsert->bind_param('sssss', $requestDateTime, $smartscore, $resultText, $caseId, $veriphyCheckId);

                if ($stmtInsert->execute()) {
                    echo 'Row inserted successfully.';
                } else {
                    echo 'Error inserting row: ' . $stmtInsert->error;
                }

                $stmtInsert->close();
            } catch (Exception $e) {
                echo 'Error decoding JSON: ' . $e->getMessage();
                error_log('Error decoding JSON: ' . $e->getMessage());
            }
        } else {
            echo "ID $caseId already exists in Veriphy_AML, no action needed.\n";
        }

        $stmtVeriphy->close();
    }

    $stmt->close();
    $conn->close();
} catch (Exception $e) {
    // Handle any exceptions here
    echo 'Error: ' . $e->getMessage();
}
?>
