<?php
session_start();
if (!isset($_SESSION['username']) || $_SESSION['username'] === "Guest") {
    header("Location: /login.php");
    exit();
}

// inactivity check ...
// set $start_date, $end_date from POST ...
// connect DB, etc.

include 'config_current.php';

// If we have a report_id, determine which query to run
if (isset($_GET['report_id'])) {
    $reportId   = $conn->real_escape_string($_GET['report_id']);
    $start_date = !empty($_POST['start']) ? $_POST['start'] : date('Y-m-d');
    $end_date   = !empty($_POST['end'])   ? $_POST['end']   : date('Y-m-d');

    // Convert to datetime ranges
    $startParam = date('Y-m-d 00:00:00', strtotime($start_date));
    $endParam   = date('Y-m-d 23:59:59', strtotime($end_date));

    $dynamicSql = "";
    $useCustom  = false; // Flag we’ll toggle if we use a manual query

    switch ($reportId) {
        // ─────────────────────────────────────────────────────────────────
        // EXAMPLE: Back Book - Agents
        // Suppose your old code used something like:
        //   SELECT ... FROM client_core AS Core
        //   LEFT JOIN account_users ...
        //   WHERE Core.cc-advisor = :MainID
        //   AND (optional date conditions)
        // ─────────────────────────────────────────────────────────────────
        case '12': // e.g. "Muhammad Mian" back book
            $useCustom = true;

            // Suppose '12' means advisor id = 101 in your real DB, or you have some logic
            // Possibly you map these “report IDs” to “advisor IDs.”
            $advisorId = 101; // example mapping

            $dynamicSql = "
                SELECT 
                    Core.id AS `Client-ID`,
                    CONCAT_WS(' ', Core.`title-1`, Core.`forename-1`, Core.`surname-1`) AS `Client-Name`,
                    CONCAT_WS(' ', Core.`HmePhone-1`, Core.`HmePhone-2`, Core.`mblePhone-1`, Core.`mblePhone-2`) AS `Client-Phone`,
                    stts.name AS `Status`,
                    Core.`monthly-fee`,
                    Core.`created-when` AS `Pack-Sent`,
                    Core.`authority`    AS `Pack-Back`,
                    Core.`nxt-py-dte`   AS `Next-Payment-Date`,
                    Core.`review-dte`   AS `ReviewDate`,
                    Core.`migration_agent` AS `Migration-Agent`,
                    advisor.nme AS `Client-Handler`
                FROM client_core AS Core
                LEFT JOIN account_users AS advisor
                    ON Core.`cc-advisor` = advisor.`id`
                LEFT JOIN `system-status` AS stts
                    ON Core.`clint-stts` = stts.`id`
                WHERE Core.`cc-advisor` = '$advisorId'
                -- Example: If you also want to filter by date range, you can do:
                -- AND Core.`nxt-py-dte` BETWEEN '$startParam' AND '$endParam'
                ORDER BY Core.`nxt-py-dte` ASC
            ";
            break;

        // ─────────────────────────────────────────────────────────────────
        // EXAMPLE: Payment Reports (e.g. Paid)a
        // ─────────────────────────────────────────────────────────────────
        case '24': // “Paid” 
            $useCustom = true;
            // Possibly your old code uses a ledger table:
            $status = 'Paid'; // might map from ID => 'Paid'
            $dynamicSql = "
                SELECT 
                    Ledger.`payment-reference`,
                    Core.id AS `Client-ID`,
                    CONCAT_WS(' ', Core.`title-1`, Core.`forename-1`, Core.`surname-1`) AS `Client-Name`,
                    CONCAT_WS(' ', Core.`HmePhone-1`, Core.`HmePhone-2`, Core.`mblePhone-1`, Core.`mblePhone-2`) AS `Client-Phone`,
                    stts.name AS `Status`,
                    Core.`nxt-py-dte` AS `Next-Payment-Date`,
                    Core.`monthly-fee`,
                    Ledger.amount,
                    advisor.nme AS `Client-Handler`,
                    Ledger.`payment-type`
                FROM client_ledger AS Ledger
                LEFT JOIN client_core AS Core 
                    ON Ledger.`cid` = Core.`id`
                LEFT JOIN account_users AS advisor 
                    ON Core.`cc-advisor` = advisor.`id`
                LEFT JOIN `system-status` AS stts
                    ON Core.`clint-stts` = stts.`id`
                WHERE Ledger.`payment-status` = '$status'
                AND Ledger.`created-when` BETWEEN '$startParam' AND '$endParam'
                ORDER BY Ledger.`created-when` DESC
            ";
            break;

        // ─────────────────────────────────────────────────────────────────
        // EXAMPLE: Default
        // If none of the above cases match, let’s try pulling from your 
        // "report_adhocs" table for a fully dynamic approach (like you do now).
        // ─────────────────────────────────────────────────────────────────
        default:
            // We'll do the original approach from your code:
            $sql = "SELECT * FROM report_adhocs WHERE id = '$reportId' LIMIT 1";
            $reportResult = $conn->query($sql);

            if ($reportResult && $reportResult->num_rows > 0) {
                $report      = $reportResult->fetch_assoc();
                $whereClause = $report['where_from'];

                // replace placeholders
                $whereClause = str_replace("[start]", "'$startParam'", $whereClause);
                $whereClause = str_replace("[end]",   "'$endParam'",   $whereClause);

                // get columns
                $columnIds = json_decode($report['columns']);
                $columnNames = [];
                foreach ($columnIds as $id) {
                    $id = $conn->real_escape_string($id);
                    $columnNameSql = "SELECT sql_com FROM report_column_names WHERE id = '$id'";
                    $columnNameResult = $conn->query($columnNameSql);
                    if ($columnNameResult && $columnNameResult->num_rows > 0) {
                        $row = $columnNameResult->fetch_assoc();
                        $columnNames[] = $row['sql_com'];
                    }
                }
                $selectedColumns = implode(", ", $columnNames);
                $tableName = $report['table_name'];

                $dynamicSql = "SELECT $selectedColumns FROM $tableName WHERE $whereClause";
            } else {
                echo "<p>Report not found.</p>";
            }
            break;
    } // end switch

    // ─────────────────────────────────────────────────────────────────
    // Execute your $dynamicSql (whether from custom or from the default approach)
    // ─────────────────────────────────────────────────────────────────
    if (!empty($dynamicSql)) {
        // If you’re using mysqlnd / mysqli in procedural style:
        $result = $conn->query($dynamicSql);
        if (!$result) {
            echo "<p>Error fetching data: " . $conn->error . "</p>";
        }
    }
}
?>

<!DOCTYPE html>
<html>
<head>
    <title>Display Report</title>
    <?php include 'layouts/head.php'; ?>
    <?php include 'layouts/head-style.php'; ?>
</head>
<body>
    <?php include 'layouts/body.php'; ?>
    <div id="layout-wrapper">
        <?php include 'layouts/menu.php'; ?>
        <div class="main-content">
            <div class="page-content">
                <div class="container-fluid">

                    <!-- Filter Form -->
                    <form method="post">
                        <label for="start">Start date:</label>
                        <input type="date" id="start" name="start" value="<?php echo $start_date; ?>">
                    
                        <label for="end">End date:</label>
                        <input type="date" id="end" name="end" value="<?php echo $end_date; ?>">
                    
                        <input type="submit" class="btn btn-primary waves-effect waves-light" value="Filter">
                    </form>

                    <!-- Export Form -->
                    <form method="post" action="export_to_excel.php">
                        <input type="hidden" name="dynamic_sql" 
                               value="<?php echo htmlspecialchars($dynamicSql ?? ''); ?>">
                        <input type="submit" class="btn btn-warning waves-effect waves-light" 
                               name="export_to_excel" value="Export to Excel">
                    </form>

                    <!-- Table Display -->
                    <div class="responsive-table-container">
                        <?php
                        if (!empty($dynamicSql) && isset($result) && $result) {
                            echo "<table>";
                            // Headers
                            echo "<tr>";
                            $headers = $result->fetch_fields();
                            foreach ($headers as $header) {
                                echo "<th>" . htmlspecialchars($header->name) . "</th>";
                            }
                            echo "</tr>";
                            
                            // Data rows
                            while ($row = $result->fetch_assoc()) {
                                echo "<tr>";
                                foreach ($row as $col => $val) {
                                    echo "<td>" . htmlspecialchars($val ?? '') . "</td>";
                                }
                                echo "</tr>";
                            }
                            echo "</table>";
                        }
                        ?>
                    </div> <!-- End responsive-table-container -->
                    
                </div><!-- end container -->
            </div><!-- end page-content -->
        </div><!-- end main-content -->
    </div><!-- end layout-wrapper -->
</body>
</html>