<?php
include 'config.php';

// Get the email ID from the query string
$email_id = isset($_GET['emailId']) ? (int)$_GET['emailId'] : 0;

if ($email_id) {
    // Fetch the email details
    $query = "SELECT * FROM emails WHERE id = ?";
    $stmt = $conn->prepare($query);
    $stmt->bind_param("i", $email_id);
    $stmt->execute();
    $result = $stmt->get_result();
    $email = $result->fetch_assoc();

    if ($email) {
        // Mark the email as read
        $update_query = "UPDATE emails SET is_read = 1 WHERE id = ?";
        $update_stmt = $conn->prepare($update_query);
        $update_stmt->bind_param("i", $email_id);
        $update_stmt->execute();

        // Fetch attachments
        $attachments_query = "SELECT * FROM attachments WHERE email_id = ?";
        $attachments_stmt = $conn->prepare($attachments_query);
        $attachments_stmt->bind_param("i", $email_id);
        $attachments_stmt->execute();
        $attachments_result = $attachments_stmt->get_result();
        $attachments = $attachments_result->fetch_all(MYSQLI_ASSOC);

        // Define $body and $date
        $body = decodeMessage($email['body']);
        $date = $email['date'];

        ?>
        <!DOCTYPE html>
        <html>
        <head>
            <title>View Email</title>
            <?php include 'layouts/head.php'; ?>
            <?php include 'layouts/head-style.php'; ?>
        </head>
        <body>
            <?php include 'layouts/body.php'; ?>
            <div id="layout-wrapper">
                <?php include 'layouts/menu.php'; ?>
                <div class="main-content">
                    <div class="page-content">
                        <div class="container-fluid">
                            <h3><?php echo htmlspecialchars($email['subject']); ?></h3>
                            <p><strong>From:</strong> <?php echo htmlspecialchars($email['sender']); ?></p>
                            <p><strong>Date:</strong> <?php echo htmlspecialchars($email['date']); ?></p>
                            <div><strong>Message:</strong><br><?php echo nl2br($body); ?></div>
                            <?php if (!empty($attachments)): ?>
                                <h4>Attachments:</h4>
                                <ul>
                                    <?php foreach ($attachments as $attachment): ?>
                                        <li><a href="download_attachment.php?id=<?php echo $attachment['id']; ?>" target="_blank"><?php echo htmlspecialchars($attachment['filename']); ?></a></li>
                                    <?php endforeach; ?>
                                </ul>
                            <?php endif; ?>
                            <!-- Form to assign case ID to the email -->
                            <form method="post" action="">
                                <label for="case_id">Assign Case ID:</label>
                                <input type="text" name="case_id" id="case_id" required>
                                <input type="submit" class="btn btn-success waves-effect waves-light" name="assign_case" value="Assign">
                            </form>
                            <?php
                            // Handle form submission to assign case ID
                            if (isset($_POST['assign_case'])) {
                                $case_id = (int)$_POST['case_id'];
                                assignCaseToEmail($conn, $email_id, $case_id, $body, $date);
                                // Update AssignedId
                                updateAssignedId($conn, $email_id, $case_id);
                            }
                            ?>
                        </div>
                    </div>
                </div>
            </div>
        </body>
        </html>
        <?php
    } else {
        echo 'Email not found.';
    }
} else {
    echo 'No email selected.';
}

function decodeMessage($message) {
    // Check for base64 encoding
    if (base64_decode($message, true) !== false) {
        return base64_decode($message);
    }
    // Check for quoted-printable encoding
    return quoted_printable_decode($message);
}

function assignCaseToEmail($conn, $email_id, $case_id, $body, $date) {
    // Insert into client_correspondance
    $insert_query = "INSERT INTO client_correspondance (Type, Note_Body, Direction, Date, UserId, inbound_emails, ClientId) VALUES ('Email Inbound', 'Inbound email to PCP', 'In', ?, 0, ?, ?)";
    $insert_stmt = $conn->prepare($insert_query);
    if (!$insert_stmt) {
        echo "Prepare failed: (" . $conn->errno . ") " . $conn->error;
        return;
    }
    $insert_stmt->bind_param("sii", $date, $email_id, $case_id);
    if ($insert_stmt->execute()) {
        echo "Email assigned to case successfully.";
    } else {
        echo "Error executing statement: (" . $insert_stmt->errno . ") " . $insert_stmt->error;
    }
}

function updateAssignedId($conn, $email_id, $case_id) {
    // Update AssignedId in emails table
    $update_query = "UPDATE emails SET AssignedId = ? WHERE id = ?";
    $update_stmt = $conn->prepare($update_query);
    if (!$update_stmt) {
        echo "Prepare failed: (" . $conn->errno . ") " . $conn->error;
        return;
    }
    $update_stmt->bind_param("ii", $case_id, $email_id);
    if ($update_stmt->execute()) {
        echo "AssignedId updated successfully.";
    } else {
        echo "Error executing statement: (" . $update_stmt->errno . ") " . $update_stmt->error;
    }
}
?>
