<?php
session_start();
require_once 'functions.php';
require_once 'config.php'; // Include your config file

// Function to get the real IP address
function getRealIpAddr()
{
    if (!empty($_SERVER['HTTP_CLIENT_IP'])) { // Check IP from shared internet
        $ip = $_SERVER['HTTP_CLIENT_IP'];
    } elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) { // Check IP passed from proxy
        $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
    } else {
        $ip = $_SERVER['REMOTE_ADDR'];
    }
    return $ip;
}

// Validate and capture necessary audit data
$user_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;
$ipaddress = getRealIpAddr();
$timestamp = date("Y-m-d H:i:s");
$page = 'logout.php';
$action = 'User Logout';
$clientid = isset($_SESSION['clientid']) ? $_SESSION['clientid'] : null;

// Check if user_id exists
if (is_null($user_id)) {
    die("Error: User ID is not available in the session. Cannot proceed with logging the audit record.");
}

// Prepare the audit query
$audit_query = "INSERT INTO system_audit (user_id, page, action, clientid, ipaddress, TimeStamp) VALUES (?, ?, ?, ?, ?, ?)";
$audit_stmt = $conn->prepare($audit_query);
if (!$audit_stmt) {
    die("Error preparing statement: " . $conn->error);
}

// Bind parameters and execute
$audit_stmt->bind_param("ississ", $user_id, $page, $action, $clientid, $ipaddress, $timestamp);
if (!$audit_stmt->execute()) {
    die("Error executing statement: " . $audit_stmt->error);
}

// Destroy the session
session_destroy();
?>

<head>
    <title>Login | Taylor Price Solicitors</title>
    <?php include 'layouts/head.php'; ?>
    <?php include 'layouts/head-style.php'; ?>
</head>

<body>
    <div class="account-pages my-5 pt-sm-5">
        <div class="container">
            <div class="row justify-content-center">
                <div class="col-md-8 col-lg-6 col-xl-5">
                    <div class="card overflow-hidden">
                        <div class="bg-primary bg-soft">
                            <div class="row">
                                <div class="col-7">
                                    <div class="text-primary p-4">
                                        <h5 class="text-primary">Thanks for using PCP Claims</h5>
                                    </div>
                                </div>
                                <div class="col-5 align-self-end">
                                    <img src="assets/images/profile-img.png" alt="" class="img-fluid">
                                </div>
                            </div>
                        </div>
                        <div class="card-body pt-0">
                            <div class="auth-logo">
                                <a href="index.php" class="auth-logo-light">
                                    <div class="avatar-md profile-user-wid mb-4">
                                        <span class="avatar-title rounded-circle bg-light">
                                            <img src="assets/images/logo-light.svg" alt="" class="rounded-circle" height="34">
                                        </span>
                                    </div>
                                </a>

                                <a href="index.php" class="auth-logo-dark">
                                    <div class="avatar-md profile-user-wid mb-4">
                                        <span class="avatar-title rounded-circle bg-light">
                                            <img src="/logos/tps.png" alt="" class="rounded-circle" height="34">
                                        </span>
                                    </div>
                                </a>
                            </div>
                            <div class="p-2">
                                <div class="alert alert-danger" role="alert" >
                                                You have safely logged out
                                            </div>
                                            <centre><a href="login.php" align="center" class="btn btn-success btn-lg waves-effect waves-light" role="button">Login</a></centre>

                        </div>
                    </div>
                    <div class="mt-5 text-center">

                        <div>
                             <p>© <script>
                                    document.write(new Date().getFullYear())
                                </script>  <?php echo "ClientMaster&trade;. Version " . get_latest_version(); ?></p>
                        </div>
                    </div>

                </div>
            </div>
        </div>
    </div>
    <!-- end account-pages -->

    <!-- JAVASCRIPT -->
  

<!-- App js -->
<script src="assets/js/app.js"></script>
</body>
</html>
