<?php
session_start();

// If session variable 'username' is not set or is 'Guest', redirect to login page
if (!isset($_SESSION['username']) || $_SESSION['username'] === "Guest") {
    header("Location: /login.php");
    exit();
}

// Check if the session is inactive for more than 10 seconds
if (isset($_SESSION['last_activity']) && (time() - $_SESSION['last_activity'] > 9000)) {
    // Session has been inactive for more than 10 seconds
    session_unset();     // Unset $_SESSION variable for the run-time
    session_destroy();   // Destroy the session data on the server
    header("Location: /login.php"); // Redirect to login page
    exit(); // Ensure no further execution of the script
}

// Update last activity time stamp
$_SESSION['last_activity'] = time();

$username = $_SESSION['user_id']; // Username is already checked above and is not 'Guest'

include_once 'config.php';

if (!function_exists('get_latest_version')) {
    function get_latest_version() {
        // Your existing function code here
    }
}

//// Diary Information Pull Request

// Get the current page number from the URL
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;

// Number of results to display per page
$resultsPerPage = 100;

// Calculate the offset based on the page number
$offset = ($page - 1) * $resultsPerPage;

// Diary Information Pull Request
// Modify the query to include pagination
$taskQuery = "SELECT * FROM case_tasks WHERE whm = ? AND stts = 0 LIMIT ? OFFSET ?";
$taskStmt = $conn->prepare($taskQuery);
$taskStmt->bind_param('iii', $username, $resultsPerPage, $offset); // Assuming 'whm' is an integer
$taskStmt->execute();



$taskResult = $taskStmt->get_result();
$tasks = [];
while ($taskRow = $taskResult->fetch_assoc()) {
    $tasks[] = $taskRow;
}

$taskStmt->close();


// Function to format tasks by date
function formatTasksByDate($tasks) {
    $formattedTasks = [];
    foreach ($tasks as $task) {
        $date = date('Y-m-d', strtotime($task['whn']));
        $formattedTasks[$date][] = $task;
    }
    return $formattedTasks;
}

$formattedTasks = formatTasksByDate($tasks);

// Calculate the total number of pages based on the number of records
$totalRecordsQuery = "SELECT COUNT(*) as total FROM case_tasks WHERE whm = ?";
$totalRecordsStmt = $conn->prepare($totalRecordsQuery);
$totalRecordsStmt->bind_param('i', $userid); // Assuming 'whm' is an integer
$totalRecordsStmt->execute();
$totalRecordsResult = $totalRecordsStmt->get_result();
$totalRecords = $totalRecordsResult->fetch_assoc()['total'];
$totalPages = ceil($totalRecords / $resultsPerPage);
?>

<!-- HTML Content starts here -->
<!DOCTYPE html>
<html>
<head>
    <title>Administration | Diary</title>
    <?php include 'layouts/head.php'; ?>
    <?php include 'layouts/head-style.php'; ?>
</head>
<body>
    <?php include 'layouts/body.php'; ?>

    <div id="layout-wrapper">
        <?php include 'layouts/vertical-menu.php'; ?>
        <div class="main-content">
            <div class="page-content">
                <div class="container-fluid">

                    <table class="table mb-0" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                        <thead class="table-light" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                            <tr speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                                <th>Diary ID</th>
                                <th>Client ID</th>
                                <th>Summary of Task</th>
                                <th>Diary Due</th>
                                <th>Who For</th>
                                <th>Status</th>
                                <th>Action</th>
                            </tr>
                        </thead>
                        <tbody>
                        <?php foreach ($tasks as $task): ?>
                            <?php
                            $userQuery = "SELECT username FROM users WHERE id = ?";
                            $userStmt = $conn->prepare($userQuery);
                            $userStmt->bind_param('i', $task['whm']); // assuming 'whm' is an integer
                            $userStmt->execute();
                            $userResult = $userStmt->get_result();
                            $user = $userResult->fetch_assoc();
                            $userStmt->close();

                            

                            // Fetch diary details from the database
                            $diaryDetails = htmlspecialchars($task['id']);
                            ?>
                            <tr class="<?php echo getStatusClass($task['stts']); ?>">
                                <td><?= htmlspecialchars($task['id']) ?></td>
                                <td><?= htmlspecialchars($task['cse']) ?></td>
                                <td><?= htmlspecialchars(substr($task['smmry'], 0, 20)) ?></td>
                                <td><?= htmlspecialchars((new DateTime($task['whn']))->format('d/m/Y h:i A')) ?></td>
                                <td><?= htmlspecialchars($user ? $user['username'] : 'Unknown') ?></td>
                                <td>
                                    <?php
                                    $status = $task['stts'];
                                    $statusText = '';
                                
                                    switch ($status) {
                                        case 0:
                                            $statusText = 'New';
                                            break;
                                        case 1:
                                            $statusText = 'In Process';
                                            break;
                                        case 2:
                                            $statusText = 'Completed';
                                            break;
                                        case 3:
                                            $statusText = 'Cancelled';
                                            break;
                                        default:
                                            $statusText = 'Unknown';
                                            break;
                                    }
                                
                                    echo htmlspecialchars($statusText);
                                    ?>
                                </td>
                                <td>
                                    <button
                                        type="button"
                                        class="btn btn-warning open-diary"
                                        data-diary-id="<?= $task['id'] ?>"
                                        data-diaryid="<?= $task['id'] ?>"
                                        data-summary="<?= htmlspecialchars($task['smmry']) ?>"
                                        data-due="<?= htmlspecialchars($task['whn']) ?>"
                                        data-who="<?= htmlspecialchars($user['username']) ?>"
                                        data-status="<?= htmlspecialchars($task['stts']) ?>"
                                        data-id="<?= htmlspecialchars($task['cse']) ?>"
                                        onclick="openDiary(this)"
                                    >
                                        Open Diary
                                    </button>

                                    <script>
                                        function openDiary(button) {
                                            var clientId = button.getAttribute('data-id');
                                            var url = 'https://tps.cml-systems.co.uk/client/Diary?client_id=' + clientId;
                                            window.open(url, '_blank');
                                        }
                                    </script>

                                </td>
                            </tr>
                        <?php endforeach; ?>
                        </tbody>
                    </table>

                    <!-- Pagination -->
<div class="dataTables_paginate paging_simple_numbers" id="datatable_paginate" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
    <ul class="pagination" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
        <?php if ($page > 1): ?>
            <li class="paginate_button page-item" id="datatable_previous" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                <a href="?page=<?php echo $page - 1; ?>" aria-controls="datatable" aria-disabled="false" aria-role="link" data-dt-idx="previous" tabindex="0" class="page-link" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">Previous</a>
            </li>
        <?php endif; ?>

        <?php
        // Define how many page links to display before and after the current page
        $numPageLinksToShow = 15; // You can adjust this value as needed

        for ($i = 1; $i <= $totalPages; $i++): ?>
            <?php if ($i === 1 || $i === $totalPages || abs($i - $page) <= $numPageLinksToShow || $i === 15 || $i === $totalPages - 1): ?>
                <li class="paginate_button page-item <?php if ($i === $page) echo 'active'; ?>" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                    <a href="?page=<?php echo $i; ?>" aria-controls="datatable" aria-role="link" aria-current="<?php if ($i === $page) echo 'page'; ?>" data-dt-idx="<?php echo $i - 1; ?>" tabindex="0" class="page-link" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px"><?php echo $i; ?></a>
                </li>
            <?php elseif ($i === 1206 || $i === $totalPages - 15): ?>
                <li class="paginate_button page-item disabled" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                    <span class="page-link">...</span>
                </li>
            <?php endif; ?>
        <?php endfor; ?>

        <?php if ($page < $totalPages): ?>
            <li class="paginate_button page-item next" id="datatable_next" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">
                <a href="?page=<?php echo $page + 1; ?>" aria-controls="datatable" aria-disabled="false" aria-role="link" data-dt-idx="next" tabindex="0" class="page-link" speechify-initial-font-family="Poppins, sans-serif" speechify-initial-font-size="13px">Next</a>
            </li>
        <?php endif; ?>
    </ul>
</div>



<!-- Display Total Pages -->
<p>Total Pages: <?php echo $totalPages; ?></p>


                    <style>
                        .status-new {
                            background-color: lightyellow;
                        }

                        .status-in-process {
                            background-color: lightblue;
                        }

                        .status-completed {
                            background-color: lightgreen;
                        }

                        .status-cancelled {
                            background-color: lightcoral;
                        }
                    </style>

                    <?php
                    function getStatusClass($status) {
                        switch ($status) {
                            case 0:
                                return 'status-new';
                            case 1:
                                return 'status-in-process';
                            case 2:
                                return 'status-completed';
                            case 3:
                                return 'status-cancelled';
                            default:
                                return '';
                        }
                    }
                    ?>

                    <!-- Modal for displaying diary details -->
                    <div class="modal fade" id="diaryModal" tabindex="-1" aria-labelledby="diaryModalLabel" aria-hidden="true">
                        <div class="modal-dialog modal-lg">
                            <div class="modal-content">
                                <div class="modal-header">
                                    <h5 class="modal-title" id="diaryModalLabel">Diary Details</h5>
                                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                        <span aria-hidden="true">&times;</span>
                                    </button>
                                </div>
                                <div class="modal-body">
                                    <!-- Display diary details here -->
                                    <div id="diaryDetails">

                                    </div>

                                    <!-- Additional Information Section -->
                                    <div id="additionalInformation">

                                    </div>

                                    <!-- Buttons to mark as In Process and Completed -->
                                    <div class="text-center mt-3">
                                        <button
                                            type="button"
                                            class="btn btn-warning mark-in-process"
                                            data-diaryid="<?= $task['id'] ?>" 
                                            data-summary="<?= htmlspecialchars($task['smmry']) ?>"
                                            data-due="<?= htmlspecialchars($task['whn']) ?>"
                                            data-who="<?= htmlspecialchars($user['nme']) ?>"
                                            data-cred="<?= isset($credname['nme']) ? htmlspecialchars($credname['nme']) : '' ?>"
                                            data-status="<?= htmlspecialchars($task['stts']) ?>"
                                        >
                                            Mark In Process
                                        </button>
                                        <button
                                            type="button"
                                            class="btn btn-success mark-completed"
                                            data-diaryid="<?= $task['id'] ?>" 
                                            data-summary="<?= htmlspecialchars($task['smmry']) ?>"
                                            data-due="<?= htmlspecialchars($task['whn']) ?>"
                                            data-who="<?= htmlspecialchars($user['nme']) ?>"
                                            data-cred="<?= isset($credname['nme']) ? htmlspecialchars($credname['nme']) : '' ?>"
                                            data-status="<?= htmlspecialchars($task['stts']) ?>"
                                            
                                        >
                                            Mark Completed
                                        </button>
                                            <div class="text-center mt-3">
                                                <button
                                                    type="button"
                                                    class="btn btn-primary open-case"
                                                    data-dismiss="modal"
                                                    onclick="fetchCaseAndOpen()"
                                                >
                                                    Open Case
                                                </button>
                                            </div>
                                            <script>
                                                function fetchCaseAndOpen() {
                                                    var idElement = document.querySelector('#additionalInformation p b');
                                                    if (idElement) {
                                                        var id = idElement.nextSibling.nodeValue.trim();
                                                        
                                                        // Send an AJAX request to your server to fetch the "case" value
                                                        var xhr = new XMLHttpRequest();
                                                        xhr.open('GET', '/get/fetch_case.php?id=' + encodeURIComponent(id), true);
                                                        xhr.onreadystatechange = function() {
                                                            if (xhr.readyState === 4 && xhr.status === 200) {
                                                                var caseValue = xhr.responseText;
                                                                window.open('/client/home.php?client_id=' + encodeURIComponent(caseValue), '_blank');
                                                            }
                                                        };
                                                        xhr.send();
                                                    }
                                                }
                                            </script>
                                </div>
                                <div class="modal-footer">
                                    <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Modal for creating a new diary -->
                    <div class="modal fade" id="createDiaryModal" tabindex="-1" aria-labelledby="createDiaryModalLabel" aria-hidden="true">
                        <div class="modal-dialog modal-lg">
                            <div class="modal-content">
                                <div class="modal-header">
                                    <h5 class="modal-title" id="createDiaryModalLabel">Create New Diary</h5>
                                </div>
                                <div class="modal-body">
                                    <!-- Form for entering diary information -->
                                    <form id="createDiaryForm">
                                        <div class="form-group">
                                            <label for="diarySummary">Summary</label>
                                            <input type="text" class="form-control" id="diarySummary" name="summary" required>
                                            <label for="CaseID">Case ID</label>
                                            <input type="text" class="form-control" id="CaseID" name="id" required>
                                        </div>
                                        <div class="form-group">
                                            <label for="diaryDue">Due Date</label>
                                            <input type="datetime-local" class="form-control" id="diaryDue" name="due" required>
                                        </div>
                                       <!-- Inside the modal form -->
                                        <div class="form-group">
                                            <label for="diaryFor">For Who</label>
                                            <select class="form-control" id="diaryFor" name="forWho" required>
                                                <!-- Add the default "Please select" option -->
                                                <option value="">Please select</option>
                                                <!-- PHP code to generate dropdown options -->
                                                <?php
                                                // Query to get user ID and name from account_users
                                                $userQuery = "SELECT id, nme FROM account_users";
                                                $userResult = $conn->query($userQuery);

                                                if ($userResult->num_rows > 0) {
                                                    while ($userRow = $userResult->fetch_assoc()) {
                                                        $userId = $userRow['id'];
                                                        $userName = $userRow['nme'];
                                                        echo '<option value="' . $userId . '">' . $userName . '</option>';
                                                    }
                                                }
                                                ?>
                                            </select>
                                        </div>
                                        <!-- Inside the modal form -->
                                        <div class="form-group">
                                            <label for="diaryLiability">Liability</label>
                                            <select class="form-control" id="diaryLiability" name="liability">
                                                <!-- Add the default "Please select" option -->
                                                <option value="">Please select</option>
                                                <!-- PHP code to generate dropdown options -->
                                                <?php
                                                // Query to get liability IDs based on the value of $id
                                                $liabilityQuery = "SELECT id, crdtr FROM case_debts WHERE cse = ?";
                                                $liabilityStmt = $conn->prepare($liabilityQuery);
                                                $liabilityStmt->bind_param('i', $CaseID);
                                                $liabilityStmt->execute();
                                                $liabilityResult = $liabilityStmt->get_result();

                                                if ($liabilityResult->num_rows > 0) {
                                                    while ($liabilityRow = $liabilityResult->fetch_assoc()) {
                                                        $liabilityId = $liabilityRow['id'];
                                                        $creditorId = $liabilityRow['crdtr'];
                    
                                    // Query to get the "nme" value from the "creditor_maintenance" table based on "crdtr" value
                                    $creditorQuery = "SELECT nme FROM creditor_maintenance WHERE id = ?";
                                    $creditorStmt = $conn->prepare($creditorQuery);
                                    $creditorStmt->bind_param('i', $creditorId);
                                    $creditorStmt->execute();
                                    $creditorResult = $creditorStmt->get_result();
                                    $creditorData = $creditorResult->fetch_assoc();
                                    $creditorName = $creditorData['nme'];
                                    $creditorStmt->close();
                    
                                    echo '<option value="' . $liabilityId . '">' . $creditorName . '</option>';
                                }
                            }
                    
                            $liabilityStmt->close();
                            ?>
                        </select>
                    </div>

                        </div>
                    
                        <div class="modal-footer">
                            <button type="submit" class="btn btn-success">Create</button>
                            </form>
                            <button type="button" class="btn btn-danger" data-dismiss="modal">Close</button>
                        </div>
                    </div>
                </div>
            </div>


        <!-- Include jQuery -->
        <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
        
        <!-- Include Bootstrap JavaScript -->
        <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>

        <script>
    // Function to map numeric status to text
    function getStatusText(status) {
        switch (status) {
            case 0:
                return 'New';
            case 1:
                return 'In Process';
            case 2:
                return 'Completed';
            case 3:
                return 'Cancelled';
            default:
                return 'Unknown';
        }
    }

$(document).ready(function () {
    // Variable to store the current diaryid
    var currentDiaryId;

    // Handle the click event for the "Open Diary" button
    $(".open-diary").click(function () {
        var summary = $(this).data("summary");
        currentDiaryId = $(this).data("diaryid"); // Capture the current diaryid
        var due = $(this).data("due");
        var who = $(this).data("who");
        var cred = $(this).data("cred");
        var id = $(this).data("id");
        var status = getStatusText($(this).data("status")); // Map numeric status to text

        // Display additional information in the modal
        $("#additionalInformation").html(
            '<p><b>Diary ID:</b> ' + currentDiaryId + '</p>' +
            '<p><b>Client ID:</b> ' + id + '</p>' +
            '<p><b>Diary Summary:</b> ' + summary + '</p>' +
            '<p><b>Due:</b> ' + due + '</p>' +
            '<p><b>Who:</b> ' + who + '</p>' +
            '<p><b>Liability:</b> ' + cred + '</p>' +
            '<p><b>Status:</b> ' + status + '</p>'
        );

        // Show the modal
        $("#diaryModal").modal("show");
    });

    // Handle the click event for "Mark In Process" button
    $(".mark-in-process").click(function () {
        // Send an AJAX request to mark the task as In Process using the current diaryid
        $.ajax({
            url: "/client/Updates/mark_task.php", // Replace with the actual URL for marking as In Process
            method: "POST",
            data: { diaryid: currentDiaryId, status: 1 }, // 1 represents In Process status
            success: function (response) {
                // Handle the response, e.g., show a success message
                alert("Task marked as In Process");
            },
            error: function () {
                // Handle errors if the request fails
                alert("Failed to mark task as In Process");
            }
        });

        // Close the modal
        $("#diaryModal").modal("hide");
    });

    // Handle the click event for "Mark Completed" button
    $(".mark-completed").click(function () {
        // Send an AJAX request to mark the task as Completed using the current diaryid
        $.ajax({
            url: "/client/Updates/mark_task.php", // Replace with the actual URL for marking as Completed
            method: "POST",
            data: { diaryid: currentDiaryId, status: 2 }, // 2 represents Completed status
            success: function (response) {
                // Handle the response, e.g., show a success message
                alert("Task marked as Completed");
            },
            error: function () {
                // Handle errors if the request fails
                alert("Failed to mark task as Completed");
            }
        });

        // Close the modal
        $("#diaryModal").modal("hide");
    });

    // Handle the hidden.bs.modal event to reload the page when the modal is hidden
    $('#diaryModal').on('hidden.bs.modal', function () {
        // Reload the page
        location.reload();
    });
});
$(document).ready(function () {
    // Handle the click event for the "Create Diary" button
    $(".create-diary").click(function () {
        // Clear the form fields when the modal is opened
        $("#createDiaryForm")[0].reset();
    });

    // Handle the form submission for creating a new diary
    $("#createDiaryForm").submit(function (event) {
        event.preventDefault();

        // Get the form data
        var formData = $(this).serialize();

        // Send an AJAX request to create a new diary entry
        $.ajax({
            url: "/client/Updates/create_diary.php", // Replace with the actual URL for creating a diary entry
            method: "POST",
            data: formData,
            success: function (response) {
                // Hide the modal
                $("#createDiaryModal").modal("hide");

                // Reload the page
                location.reload();
            }
        });
    });

    // Handle the hidden.bs.modal event to reload the page when the modal is hidden
    $('#createDiaryModal').on('hidden.bs.modal', function () {
        // Reload the page
        location.reload();
    });
});



$(document).ready(function () {
    // Add an event listener to the "CaseID" input field
    $("#CaseID").on("input", function () {
      // Retrieve the entered value
      var caseIDValue = $(this).val();

      // Check if the entered value is not empty
      if (caseIDValue.trim() !== "") {
        // Send an AJAX request to the server (PHP script) to fetch liability options
        $.ajax({
          type: "POST", // You can change this to "GET" if your server-side script handles GET requests
          url: "/get/fetch_liabilities.php", // Replace with the URL of your PHP script
          data: { caseID: caseIDValue }, // Send the entered value to the server
          success: function (response) {
            // Update the "Liability" dropdown with the fetched options
            $("#diaryLiability").html(response);
          },
          error: function (xhr, status, error) {
            // Handle any errors here
            console.error(error);
          },
        });
      } else {
        // If the "CaseID" input is empty, reset the "Liability" dropdown
        $("#diaryLiability").html('<option value="">Please select</option>');
      }
    });
  });





</script>
    </div>
</body>
</html>