<?php
session_start();

// If session variable 'username' is not set or is 'Guest', redirect to login page
if (!isset($_SESSION['username']) || $_SESSION['username'] === "Guest") {
    header("Location: /login.php");
    exit();
}

// Check if the session is inactive for more than 10 seconds
if (isset($_SESSION['last_activity']) && (time() - $_SESSION['last_activity'] > 9000)) {
    // Session has been inactive for more than 10 seconds
    session_unset();     // Unset $_SESSION variable for the run-time
    session_destroy();   // Destroy the session data on the server
    header("Location: /login.php"); // Redirect to login page
    exit(); // Ensure no further execution of the script
}

// Update last activity time stamp
$_SESSION['last_activity'] = time();

$username = $_SESSION['username']; // Username is already checked above and is not 'Guest'
include_once 'config_current.php';

function getClientStatusText($status)
{
    // Cast to integer in case the DB returns a string
    switch ((int)$status) {
        case 1:
            return 'New';
        case 2:
            return 'InReview';
        case 4:
            return 'Cancelled';
        case 6:
            return 'Completed';
        case 7:
            return 'InProcess';
        case 8:
            return 'InReview 15';
        case 9:
            return 'InProcess 15';
        case 10:
            return 'InReview 12';
        case 11:
            return 'InProcess 12';
        case 12:
            return 'Account on Hold';
        case 13:
            return 'Overdue';
        case 14:
            return 'Returned - No Contact';
        case 15:
            return 'Returned - DNQ';
        case 16:
            return 'Pending Completion';
        case 17:
            return 'InProcess 24';
        case 18:
            return 'InReview 24';
        case 19:
            return 'In Process - 6 Month Extension';
        default:
            return htmlspecialchars($status, ENT_QUOTES, 'UTF-8');
    }
}

// Get Username
$query = "SELECT nme, job_title FROM account_users WHERE email = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param('s', $username);
$stmt->execute();

$result = $stmt->get_result();
$row = $result->fetch_assoc();

if ($row) {
    $truename = $row['nme'];
    $jobtitle = $row['job_title'];
} else {
    $truename = "Unknown";
    $jobtitle = "Unknown";
}
$stmt->close();

// Initialize an empty array for search results
$searchResults = [];

// Check if the search term was sent via GET (from the search form)

if ($_SERVER["REQUEST_METHOD"] === "GET" && !empty($_GET['search'])) {
    $searchTerm = trim($_GET['search']);

    $query = "SELECT * FROM client_core WHERE id = ? OR `other-id` = ?";
    $stmt = $conn->prepare($query);
    $stmt->bind_param('ii', $searchTerm,$searchTerm);
    $stmt->execute();
    if ($stmt->error) {
        die("Statement error on ID query: " . $stmt->error);
    }
    $result = $stmt->get_result();

    
    if ($result->num_rows > 0) {
        // ID match found
        $searchResults = $result->fetch_all(MYSQLI_ASSOC);
    } else {
        // No exact ID match, do a LIKE search on name, phone, email, etc.
        $query = "
          SELECT * FROM client_core
          WHERE `forename-1` LIKE ? 
             OR `surname-1` LIKE ? 
             OR `mblePhone-1` LIKE ? 
             OR `emlAddrss-1` LIKE ?
             OR `pstCde` LIKE ?
             OR `dteOfBrth-1` LIKE ?
        ";
        $stmt = $conn->prepare($query);
        $likeTerm = "%" . $searchTerm . "%";
        $stmt->bind_param('ssssss', $likeTerm, $likeTerm, $likeTerm, $likeTerm, $likeTerm, $likeTerm);
        $stmt->execute();

        if ($stmt->error) {
            die("Statement error on LIKE query: " . $stmt->error);
        }

        $result = $stmt->get_result();
        $searchResults = $result->fetch_all(MYSQLI_ASSOC);
    }
    $stmt->close();
}

?>

<!-- HTML and PHP code to display the search form and table -->
<!DOCTYPE html>
<html>

<head>
    <!-- [Bootstrap, jQuery, Popper, Bootstrap JS, and other includes] -->
    <title>Search Results | Case</title>
    <?php include 'layouts/head.php'; ?>
    <?php include 'layouts/head-style.php'; ?>
</head>

<body>
    <?php include 'layouts/body.php'; ?>

    <div id="layout-wrapper">
        <?php include 'layouts/vertical-menu.php'; ?>
        <div class="main-content">
            <div class="page-content">
                <div class="container-fluid">

                    <!-- [The rest of your HTML before the table] -->
                    <div class="search-results">
                        <?php if (!empty($searchResults)): ?>
                            <table class="table table-bordered">
                                <thead>
                                    <tr>
                                        <th>CCR ID</th>
                                        <th>Client ID</th>
                                        <th>First Name</th>
                                        <th>Last Name</th>
                                        <th>Next Payment Date</th>
                                        <th>Mobile Phone Number</th>
                                        <th>Email Address</th>
                                        <th>Current Status</th>
                                        <th>Actions</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($searchResults as $row): ?>
                                        <?php
                                        // Check if the ID has a value. If not, skip this row.
                                        if (empty($row['id'])) {
                                            continue;
                                        }
                                        ?>
                                        <tr>
                                            <td><?= htmlspecialchars((string)$row['id']) ?></td>
                                            <td><?= htmlspecialchars((string)$row['other-id']) ?></td>
                                            <td><?= htmlspecialchars((string)$row['forename-1']) ?></td>
                                            <td><?= htmlspecialchars((string)$row['surname-1']) ?></td>
                                            <td><?= htmlspecialchars(date("d M y", strtotime($row['nxt-py-dte']))) ?></td>
                                            <td><?= htmlspecialchars((string)$row['mblePhone-1']) ?></td>
                                            <td><?= htmlspecialchars((string)$row['emlAddrss-1']) ?></td>
                                            <td><?= getClientStatusText($row['clint-stts']) ?></td>



                                            <form action="client/home.php" method="get" target="_blank">
                                                <input type="hidden" name="client_id" value="<?= htmlspecialchars((string)$row['id']) ?>">
                                                <td>
                                                    <button type="submit" class="btn btn-success">Open Case</button>
                                                </td>
                                            </form>



                                            </td>
                                            <!-- [Other columns] -->
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        <?php else: ?>
                            <p>No search results found.</p>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- [Other includes or scripts] -->
</body>

</html>