<?php
session_start();
include_once 'config_current.php';

if (!isset($_SESSION['user_id'])) {
  header('Location: login.php');
  exit();
}

$query = "SELECT nme, job_title FROM account_users WHERE id = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $_SESSION['user_id']);
$stmt->execute();
$result = $stmt->get_result();

if ($stmt->error) {
  die("Database error: " . $stmt->error);
}

$user = $result->fetch_object();

if (!$user) {
  die("No user found with ID: " . $_SESSION['user_id']);
}

require_once 'config_current.php'; // Include your config file
function getRealIpAddr()
{
  if (!empty($_SERVER['HTTP_CLIENT_IP'])) // Check ip from share internet
  {
    $ip = $_SERVER['HTTP_CLIENT_IP'];
  } elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) // To check ip is passed from proxy
  {
    $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
  } else {
    $ip = $_SERVER['REMOTE_ADDR'];
  }
  return $ip;
}

$sql = "SELECT `id`, `name`, `grouped` FROM `system-status` ORDER BY `id` ASC";

$resultTemplates = $conn->query($sql);
if (!$resultTemplates) {
  die("Query error: " . $conn->error);
}

$templates = [];
while ($row = $resultTemplates->fetch_assoc()) {
  $templates[] = $row;
}
$resultTemplates->free();
?>

<?php
// Helper function to map the status value to a human-readable text
function getClientStatusText($status) {
  // Cast to integer in case the DB returns a string
  switch ((int)$status) {
    case 1:
      return 'New';
    case 2:
      return 'InReview';
    case 4:
      return 'Cancelled';
    case 6:
      return 'Completed';
    case 7:
      return 'InProcess';
    case 8:
      return 'InReview 15';
    case 9:
      return 'InProcess 15';
    case 10:
      return 'InReview 12';
    case 11:
      return 'InProcess 12';
    case 12:
      return 'Account on Hold';
    case 13:
      return 'Overdue';
    case 14:
      return 'Returned - No Contact';
    case 15:
      return 'Returned - DNQ';
    case 16:
      return 'Pending Completion';
    case 17:
      return 'InProcess 24';
    case 18:
      return 'InReview 24';
    case 19:
      return 'In Process - 6 Month Extension';    
    default:
      return htmlspecialchars($status ?? 'null', ENT_QUOTES, 'UTF-8');
}
}
?>

<!DOCTYPE html>
<html>

<head>
  <title>Templates</title>
  <?php include 'layouts/head.php'; ?>
  <?php include 'layouts/head-style.php'; ?>
  <script>
    function filterTable(inputId, tableId) {
      var input, filter, table, tr, td, i, j, txtValue;
      input = document.getElementById(inputId);
      filter = input.value.toLowerCase();
      table = document.getElementById(tableId);
      tr = table.getElementsByTagName("tr");

      for (i = 1; i < tr.length; i++) {
        tr[i].style.display = "none";
        td = tr[i].getElementsByTagName("td");
        for (j = 0; j < td.length; j++) {
          if (td[j]) {
            txtValue = td[j].textContent || td[j].innerText;
            if (txtValue.toLowerCase().indexOf(filter) > -1) {
              tr[i].style.display = "";
              break;
            }
          }
        }
      }
    }
  </script>
</head>
<?php include 'layouts/body.php'; ?>

<body>
  <div id="layout-wrapper">
    <?php include 'layouts/menu.php'; ?>
    <div class="main-content">
      <div class="page-content">
        <div class="container-fluid">
          <div class="row">
            <style>
              .pagination-button {
                position: relative;
                cursor: pointer;
                display: inline-block;
                overflow: hidden;
                user-select: none;
                -webkit-tap-highlight-color: transparent;
                padding: 10px 20px;
                background-color: #556ee6;
                color: white;
                text-decoration: none;
                border-radius: 5px;
                transition: background-color 0.2s ease;
              }

              .pagination-button:hover {
                background-color: #0056b3;
              }

              .pagination-button .waves-ripple {
                position: absolute;
                border-radius: 50%;
                width: 20px;
                height: 20px;
                margin-top: -10px;
                margin-left: -10px;
                background: rgba(255, 255, 255, 0.3);
                transition: all 0.5s ease-out;
                transition-property: transform, opacity;
                transform: scale(0) translate(0, 0);
                pointer-events: none;
              }
            </style>
            <div class="row">
              <!-- Client Card -->
              <div class="col">
                <div class="card mini-stats-wid">
                  <div class="card-header">
                    <div class="avatar-sm bg-primary rounded-circle">
                      <span class="avatar-title rounded-circle">
                        <i class="bx bx-user font-size-24"></i>
                      </span>
                    </div>
                    <h3 class="fs-4 mt-2">Client Status</h3>
                  </div>
                  <div class="card-body">
                    <input type="text" id="searchClient" class="form-control search-input" placeholder="Search Client..." onkeyup="filterTable('searchClient', 'clientTable')">
                    <div class="table-responsive mt-2">
                      <table id="clientTable" class="table table-bordered">
                        <thead>
                          <tr>
                            <th>Name</th>
                            <th>Grouped By</th>
                          </tr>
                        </thead>
                        <tbody>
                          <?php if (count($templates) > 0): ?>
                            <?php foreach ($templates as $template): ?>
                              <tr>
                                <td><a href="document.php?id=<?php echo $template['id']; ?>"><?php echo htmlspecialchars($template['name'] ?? ''); ?></a></td>
                                <td><?php echo htmlspecialchars(getClientStatusText($template['grouped']) ?? 'null'); ?></td>
                              </tr>
                            <?php endforeach; ?>
                          <?php else: ?>
                            <tr>
                              <td colspan="3">No record found</td>
                            </tr>
                          <?php endif; ?>
                        </tbody>
                      </table>
                    </div>
                 </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</body>

</html>
