<?php
session_start();
include_once 'config_current.php';

if (!isset($_SESSION['user_id'])) {
  header('Location: login.php');
  exit();
}

$query = "SELECT nme, job_title FROM account_users WHERE id = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $_SESSION['user_id']);
$stmt->execute();
$result = $stmt->get_result();

if ($stmt->error) {
  die("Database error: " . $stmt->error);
}

$user = $result->fetch_object();

if (!$user) {
  die("No user found with ID: " . $_SESSION['user_id']);
}

require_once 'config_current.php'; // Include your config file
function getRealIpAddr()
{
  if (!empty($_SERVER['HTTP_CLIENT_IP'])) // Check ip from share internet
  {
    $ip = $_SERVER['HTTP_CLIENT_IP'];
  } elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) // To check ip is passed from proxy
  {
    $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
  } else {
    $ip = $_SERVER['REMOTE_ADDR'];
  }
  return $ip;
}

$userSession = "SELECT `id`, ip, isp, os, browser, city, region, whn FROM account_sessions 
  WHERE `user_id` = ? ORDER BY `whn` DESC";
$stmtSession = $conn->prepare($userSession);
$user_id = base64_decode($_GET['user_id']);
$stmtSession->bind_param("i", $user_id);
$stmtSession->execute();
$userResult = $stmtSession->get_result();
if ($stmtSession->error) {
  die("Query error: " . $stmtSession->error);
}

?>

<!DOCTYPE html>
<html>

<head>
  <title>Templates | Users</title>
  <?php include 'layouts/head.php'; ?>
  <?php include 'layouts/head-style.php'; ?>
<script>
  function paginateTable(tableId, itemsPerPage) {
    var table = document.getElementById(tableId);
    var tr = table.getElementsByTagName("tr");
    var pageCount = Math.ceil((tr.length - 1) / itemsPerPage);
    var currentPage = 1;

    // Show only the rows for the specified page
    function showPage(page) {
      // Hide all rows except the header row
      for (var i = 1; i < tr.length; i++) {
        tr[i].style.display = "none";
      }
      // Show rows for the current page
      for (var i = (page - 1) * itemsPerPage + 1; i <= page * itemsPerPage && i < tr.length; i++) {
        tr[i].style.display = "";
      }
    }

    // Create the pagination controls with ellipses
    function createPagination() {
      var pagination = document.getElementById(tableId + "-pagination");
      pagination.innerHTML = "";

      // Create a container to hold both info text and buttons
      var container = document.createElement("div");
      container.className = "pagination-container";

      // Left side: info text
      var leftText = document.createElement("div");
      leftText.className = "pagination-info";

      // Right side: pagination buttons
      var rightButtons = document.createElement("div");
      rightButtons.className = "pagination-buttons";

      // Helper to build a single page link
      function addPageLink(pageNum) {
        var pageLink = document.createElement("a");
        pageLink.href = "#";
        pageLink.textContent = pageNum;
        pageLink.onclick = function(e) {
          e.preventDefault();
          currentPage = pageNum;
          showPage(currentPage);
          updateInfo();
          createPagination(); // Re-render the pagination to update ellipses
        };
        rightButtons.appendChild(pageLink);
      }

      // If total pages are fewer than or equal to a certain threshold, just show all
      var visibleWindow = 5; // how many pages to show around current
      if (pageCount <= (2 * visibleWindow + 1)) {
        // Show all pages
        for (var i = 1; i <= pageCount; i++) {
          addPageLink(i);
        }
      } else {
        // Always show page 1
        addPageLink(1);

        // Determine start and end of the window around currentPage
        var start = currentPage - 2;
        var end = currentPage + 2;

        // If currentPage is near the beginning
        if (start < 2) {
          start = 2;
          end = start + (visibleWindow - 1);
        }

        // If currentPage is near the end
        if (end >= pageCount) {
          end = pageCount - 1;
          start = end - (visibleWindow - 1);
        }

        // If there's a gap between page 1 and start, show ellipses
        if (start > 2) {
          var ellipses = document.createElement("span");
          ellipses.textContent = "...";
          rightButtons.appendChild(ellipses);
        }

        // Add the page links for [start..end]
        for (var i = start; i <= end; i++) {
          addPageLink(i);
        }

        // If there's a gap between end and the last page, show ellipses
        if (end < pageCount - 1) {
          var ellipses2 = document.createElement("span");
          ellipses2.textContent = "...";
          rightButtons.appendChild(ellipses2);
        }

        // Always show the last page
        addPageLink(pageCount);
      }

      // Function to update the "Showing ..." text
      function updateInfo() {
        var totalRows = tr.length - 1;
        var startRow = (currentPage - 1) * itemsPerPage + 1;
        var endRow = Math.min(currentPage * itemsPerPage, totalRows);
        leftText.textContent = "Showing " + startRow + " to " + endRow + " of " + totalRows + " rows";
      }
      updateInfo();

      // Append left and right parts to the container
      container.appendChild(leftText);
      container.appendChild(rightButtons);
      pagination.appendChild(container);
    }

    // Show the first page initially
    showPage(currentPage);
    // Build pagination controls
    createPagination();
  }

  document.addEventListener("DOMContentLoaded", function () {
    paginateTable("clientTable", 20);
    paginateTable("creditorTable", 20);
  });
</script>
</head>
<?php include 'layouts/body.php'; ?>

<body>
  <div id="layout-wrapper">
    <?php include 'layouts/menu.php'; ?>
    <div class="main-content">
      <div class="page-content">
        <div class="container-fluid">
          <div class="row">
            <style>
  .pagination-container {
      display: flex;
      justify-content: space-between;
      align-items: center;
      margin-top: 20px;
      margin-bottom:20px;
  }
  .pagination-info {
      font-size: 14px;
      color: #333;
  }
  .pagination-buttons a {
      cursor: pointer;
      padding: 10px 15px;
      background-color: #556ee6;
      color: white;
      text-decoration: none;
      border-radius: 5px;
      transition: background-color 0.2s ease;
      margin: 0 3px;
  }
  .pagination-buttons a:hover {
      background-color: #0056b3;
  }
</style>
    <div class="row">
        <!-- Left: User Info Form -->
        <div class="col-lg-8">
            <div class="card">
          <div class="card-body">
              <h5 class="card-title">User Information</h5>
              <form class="mt-3">
            <div class="mb-2">
                <label class="form-label">Name:</label>
                <input type="text" class="form-control" value="Jake Kitchen">
            </div>
            <div class="mb-2">
                <label class="form-label">Job Title:</label>
                <input type="text" class="form-control" value="Administrator">
            </div>
            <div class="mb-2">
                <label class="form-label">Permission:</label>
                <select class="form-select">
              <option selected>Administrator</option>
                </select>
            </div>
            <div class="mb-2">
                <label class="form-label">Email:</label>
                <input type="email" class="form-control" value="jake@clearstartaccountants.co.uk">
            </div>
            <div class="mb-2">
                <label class="form-label">DDI:</label>
                <input type="text" class="form-control" value="01617682537">
            </div>
            <div class="mb-2">
                <label class="form-label">IP Address:</label>
                <input type="text" class="form-control" value="---.---.---.---">
            </div>
            <div class="form-check">
                <input class="form-check-input" type="checkbox" id="disabled">
                <label class="form-check-label" for="disabled">Account Disabled</label>
            </div>
              </form>
          </div>
            <!-- Buttons -->
    <div class="row mb-4 ms-2">
        <div class="col-12 card-buttons">
            <button class="btn btn-primary">Password Request</button>
            <button class="btn btn-danger">Remove Account</button>
            <button class="btn btn-success">Update Profile</button>
        </div>
    </div>
            </div>
        </div>

        <!-- Right: Profile Card -->
        <div class="col-lg-4 mt-3">
            <div class="profile-card text-center">
                <img src="https://via.placeholder.com/100" class="profile-avatar" alt="User Image">
                <h5 class="mt-2">Jake Kitchen</h5>
                <p class="text-muted">Administrator</p>
                <p class="text-muted">jake@clearstartaccountants.co.uk</p>
                <hr>
                <p><strong>Account Status:</strong> <span class="status-enabled">Enabled</span></p>
                <p><strong>Last Active:</strong> 2 minutes ago</p>
            </div>
        </div>
    </div>
</div>

    <!-- Data Table -->
             <div class="row mt-3">
              <!-- Client Card -->
              <div class="col-md-7">
                <div class="card mini-stats-wid">
             
                  <div class="card-body">
                    <input type="text" id="searchClient" class="form-control search-input" placeholder="Search Client..." onkeyup="filterTable('searchClient', 'clientTable')">
                    <div class="table-responsive mt-2">
                      <table id="clientTable" class="table table-bordered">
                        <thead>
                          <tr>
                            <th>City</th>
                            <th>OS</th>
                            <th>Browser</th>
                            <th>ISP</th>
                            <th>IP Address</th>
                            <th>When</th>
                          </tr>
                        </thead>
                        <tbody>
                        <?php
                        
                        if($userResult->num_rows > 0) {
                          while ($row = $userResult->fetch_assoc()):
                        ?>
                          <tr>
                            <td><?php echo htmlspecialchars($row['city']); ?></td>
                            <td><?php echo htmlspecialchars($row['os']); ?></td>
                            <td><?php echo htmlspecialchars($row['browser']); ?></td>
                          <td><?php echo htmlspecialchars($row['isp']); ?></td>
                             <td><?php echo htmlspecialchars($row['ip']); ?></td>
                                      <td>
                                      <?php 
                                        $whn = strtotime($row['whn']);
                                        $diff = time() - $whn;
                                        if ($diff < 60) {
                                          echo htmlspecialchars($diff . ' ' . ($diff == 1 ? 'sec' : 'secs') . ' ago');
                                        } elseif ($diff < 3600) {
                                          $minutes = round($diff / 60);
                                          echo htmlspecialchars($minutes . ' ' . ($minutes == 1 ? 'minute' : 'minutes') . ' ago');
                                        } elseif ($diff < 86400) {
                                          $hours = round($diff / 3600);
                                          echo htmlspecialchars($hours . ' ' . ($hours == 1 ? 'hour' : 'hours') . ' ago');
                                        } else {
                                          echo htmlspecialchars(date('d/m/Y h:ia', $whn));
                                        }
                                      ?>
                                    </td>
                          </tr>
                        <?php 
                          endwhile;
                        } else {
                          echo "<tr><td colspan='6'>No users found</td></tr>";
                        }
                        ?>
                      </tbody>
                      </table>
                      <div id="clientTable-pagination"></div>
                    </div>
                  </div>
                </div>
              </div>
              <!-- Creditor Card -->
              <div class="col-md-5 mb-4">
                <div class="card mini-stats-wid">
                  <div class="card-body">
                    <input type="text" id="searchCreditor" class="form-control search-input" placeholder="Search Creditor..." onkeyup="filterTable('searchCreditor', 'creditorTable')">
                    <div class="table-responsive mt-2">
                      <table id="creditorTable" class="table table-bordered">
                        <thead>
                          <tr>
                            <th>Description</th>
                            <th>Created</th>
                          </tr>
                        </thead>
                        <tbody>
                          <?php if (isset($templatesByType['creditor']) && count($templatesByType['creditor']) > 0): ?>
                            <?php foreach ($templatesByType['creditor'] as $template): ?>
                              <tr>
                                <td><a href="document.php?id=<?php echo $template['id']; ?>"><?php echo htmlspecialchars($template['name']); ?></a></td>
                                <td><?php echo htmlspecialchars($template['updated-by']); ?></td>
                                <td><?php echo date('d-m-Y h:ia', strtotime($template['updated-when'])); ?></td>
                              </tr>
                            <?php endforeach; ?>
                          <?php else: ?>
                            <tr>
                              <td colspan="3">No record found</td>
                            </tr>
                          <?php endif; ?>
                        </tbody>
                      </table>
                      <div id="creditorTable-pagination"></div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
        </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</body>

</html>
