<?php
session_start();
include_once 'config_current.php';

if (!isset($_SESSION['user_id'])) {
  header('Location: login.php');
  exit();
}

$query = "SELECT nme, job_title FROM account_users WHERE id = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $_SESSION['user_id']);
$stmt->execute();
$result = $stmt->get_result();

if ($stmt->error) {
  die("Database error: " . $stmt->error);
}

$user = $result->fetch_object();

if (!$user) {
  die("No user found with ID: " . $_SESSION['user_id']);
}

require_once 'config_current.php'; // Include your config file
function getRealIpAddr()
{
  if (!empty($_SERVER['HTTP_CLIENT_IP'])) // Check ip from share internet
  {
    $ip = $_SERVER['HTTP_CLIENT_IP'];
  } elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) // To check ip is passed from proxy
  {
    $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
  } else {
    $ip = $_SERVER['REMOTE_ADDR'];
  }
  return $ip;
}

$userList = "SELECT `id`, nme, email, job_title, disabled FROM account_users 
          WHERE id NOT IN (-1, -2, -3, -4, 1, 2, 100)";
$userResult = $conn->query($userList);
if (!$userResult) {
    die("Query error: " . $conn->error);
}

?>

<!DOCTYPE html>
<html>

<head>
  <title>Templates | Users</title>
  <?php include 'layouts/head.php'; ?>
  <?php include 'layouts/head-style.php'; ?>
 <script>
    function filterTable(inputId, tableId) {
      var input, filter, table, tr, td, i, j, txtValue;
      input = document.getElementById(inputId);
      filter = input.value.toLowerCase();
      table = document.getElementById(tableId);
      tr = table.getElementsByTagName("tr");

      for (i = 1; i < tr.length; i++) {
        tr[i].style.display = "none";
        td = tr[i].getElementsByTagName("td");
        for (j = 0; j < td.length; j++) {
          if (td[j]) {
            txtValue = td[j].textContent || td[j].innerText;
            if (txtValue.toLowerCase().indexOf(filter) > -1) {
              tr[i].style.display = "";
              break;
            }
          }
        }
      }
    }
  </script>
</head>
<?php include 'layouts/body.php'; ?>

<body>
  <div id="layout-wrapper">
    <?php include 'layouts/menu.php'; ?>
    <div class="main-content">
      <div class="page-content">
        <div class="container-fluid">
          <div class="row">
            <style>
              .pagination-button {
                position: relative;
                cursor: pointer;
                display: inline-block;
                overflow: hidden;
                user-select: none;
                -webkit-tap-highlight-color: transparent;
                padding: 10px 20px;
                background-color: #556ee6;
                color: white;
                text-decoration: none;
                border-radius: 5px;
                transition: background-color 0.2s ease;
              }

              .pagination-button:hover {
                background-color: #0056b3;
              }
-
              .pagination-button .waves-ripple {
                position: absolute;
                border-radius: 50%;
                width: 20px;
                height: 20px;
                margin-top: -10px;
                margin-left: -10px;
                background: rgba(255, 255, 255, 0.3);
                transition: all 0.5s ease-out;
                transition-property: transform, opacity;
                transform: scale(0) translate(0, 0);
                pointer-events: none;
              }
            </style>
            <div class="row">
              <!-- Client Card -->
                   <div class="col">
                <div class="card mini-stats-wid">
                  <div class="card-header">
                    <div class="avatar-sm bg-primary rounded-circle">
                      <span class="avatar-title rounded-circle">
                        <i class="bx bx-user font-size-24"></i>
                      </span>
                    </div>
                    <h3 class="fs-4 mt-2">User List</h3>
                  </div>
                  <div class="card-body">
                    <input type="text" id="searchClient" class="form-control search-input" placeholder="Search Client..." onkeyup="filterTable('searchClient', 'clientTable')">
                    <div class="table-responsive mt-2">
                      <table id="clientTable" class="table table-bordered">
                        <thead>
                          <tr>
                            <th>Name</th>
                            <th>Email</th>
                            <th>Permissions</th>
                            <th>Last Login</th>
                            <th>Disabled</th>
                            <th>Actions</th>
                          </tr>
                        </thead>
                       <tbody>
                        <?php
                        
                        if($result->num_rows > 0) {
                          while ($row = $userResult->fetch_assoc()):
                        ?>
                          <tr>
                            <td><?php echo htmlspecialchars($row['nme']); ?></td>
                            <td><?php echo htmlspecialchars($row['email']); ?></td>
                            <td><?php echo htmlspecialchars($row['job_title']); ?></td>
                            <!-- Last Login is not selected, so use a placeholder -->
                            <td><?php echo '-'; ?></td>
                          <td><?php echo ($row['disabled'] == 1 ? 'Yes' : 'No'); ?></td>
                             <td>
                              <?php
                              $encrypted_id = base64_encode($row['id']);
                              ?>
                              <a href="setting_user_single.php?user_id=<?php echo ($encrypted_id); ?>" class="btn btn-primary">
                              <i class="bx bx-right-arrow-alt"></i>
                              </a>
                            </td>
                          </tr>
                        <?php 
                          endwhile;
                        } else {
                          echo "<tr><td colspan='6'>No users found</td></tr>";
                        }
                        ?>
                      </tbody>
                      </table>
                    </div>
                 </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</body>

</html>
